library(datalibaba)
library(tidyverse)
library(googlesheets4)

#  une fonction pour récupérer les métadonnées postées dans la datamart IT
get_metadata_it <- function(table_it = "indicateur_captage_prioritaire_protection_action") {
 com <- get_table_comment(table = table_it, schema = "portrait_territoires", db = "datamart", user = "does")
 com_dat_auteur <- stringr::str_extract(com$commentaire, "Commentaire posté le .*, par .*$")
 date_maj <- gsub("Commentaire posté le |, par .*$", "", com_dat_auteur) %>% 
   lubridate::dmy()
 auteur_maj <- gsub("Commentaire posté le .*, par |\\.$", "", com_dat_auteur)
 metadata_table <- tibble::tribble(
   ~table, ~mise_a_jour, ~auteur, 
   table_it, date_maj, auteur_maj
   )
 metadata_table
}

# Découverte des tables du datamart
con <- connect_to_db(db = "datamart", user = "does")
tables <- list_tables(con, "portrait_territoires")

# Sélection des tables d'intérêt
tables_filtre <- data.frame(tables) %>% 
  filter(grepl("^cogifiee_|^indicateur_|^specifique_|^secretise_", tables)) %>% 
  arrange(tables) %>% 
  filter(tables != "cogifiee_ecln") %>% # données ne sont pas secrétisées à ce stade
  filter(tables != "cogifiee_eptb") %>% # données ne sont pas secrétisées à ce stade
  filter(tables != "indicateur_etalement_urbain_old") %>%  # traité dans une autre application (it_conso_espace)
  filter(tables != "indicateur_ff_etalement_urbain") %>%  # traité dans une autre application (it_conso_espace)
  filter(tables != "cogifiee_filocom") %>% # abandon source filocom
  filter(tables != "secretise_filocom") %>% # abandon source filocom
  filter(tables != "cogifiee_ocsge_auran") %>% # alternative à cogifiee_ocsge non mise en oeuvre en l'occurrence
  filter(tables != "indicateur_prio_bois_energie") %>% # à cause de valeur non numériques (table)
  filter(tables != "specifique_table_passage_territoire_sage") # n'est pas un indicateur

# Tableau des mise à jour brut
metadata <- tables_filtre$tables %>%  map_dfr(~ get_metadata_it(.x))


# Chargement des metadonnees des sources 
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()
source_ref <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                sheet = "sources") %>%
  filter(a_charger == "oui", !is.na(source)) %>% 
  select(source, referent)

# Tableau des mise à jour enrichi
metadata_ref <- metadata %>%  
  mutate(source_propre = stringr::str_replace(table, "chargement_|ref_|specifique_", "") %>%
           stringr::str_replace("indicateur_|cogifiee_", "") %>%
           stringr::str_replace("_cogiter|_cog$", "") %>%
           stringr::str_replace("secret_|secretise_", "")) %>% 
  left_join(source_ref, by = c("source_propre" = "source")) %>% 
  select("table", "referent", "mise_a_jour", "auteur") %>% 
  arrange(mise_a_jour)

# Export
write.csv2(metadata_ref, file = paste0("../../", Sys.Date(), "_suivi_maj_datamart_IT.csv"))
