library(datalibaba)
library(googlesheets4)

poster_documenter_it <- function(df = pop10, nom_table_sgbd = "source_pop_rgp_insee", 
                                 comm_source_en_plus = "T\u00e9l\u00e9chargement depuis...") {
  
  # Vérif clé primaire : une ligne par commune et par date
  doublons <- df %>% 
    dplyr::count(depcom, date) %>% 
    dplyr::filter(n>1) %>% 
    nrow()
  attempt::stop_if(doublons > 0, msg =  glue::glue("La table df contient plusieurs lignes qui ont \u00e0 la fois le m\u00eame code commune et la m\u00eame date m\u00eame date"))
  
  
  # CHARGEMENT de la table dans le SGBD
  datalibaba::poster_data(data = df,
              db = "datamart",
              schema = "portrait_territoires", 
              table = nom_table_sgbd,
              post_row_name = FALSE, 
              overwrite = TRUE,
              droits_schema = TRUE,
              pk = c("depcom", "date"), # déclaration d'une clé primaire sur la table postée : on ne doit pas avoir deux lignes avec à la fois le même code commune et la meme date
              user = "does") 
  
  
  # RECUPERATION DES METADONNEES
  
  ## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
  var <- dplyr::setdiff(names(df), c("depcom", "date"))
  
  ## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
  nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
    basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
    gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'
  message("nom_script_sce détecté ", nom_script_sce)
  ## authentification google sheet grâce au .Renviron
  googlesheets4::gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
  googlesheets4::gs4_deauth()
  
  ## chargement du référentiel indicateurs google sheet
  metadata_indicateur <- googlesheets4::read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                    sheet = "indicateurs") %>%
    # on ne garde que les variables concernées par le présent script de chargement
    dplyr::filter(source == nom_script_sce) %>% 
    # on ajoute l'unité dans le libellé de la variable
    dplyr::mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
    dplyr::select(variable, libelle_variable) %>% 
    # ajout des libellés pour depcom et date
    dplyr::bind_rows(
      tidyr::tribble(
        ~variable, ~libelle_variable,
        "depcom", "Code INSEE de la commune",
        "date", "Millesime"
      )
    )
  
  ## Vérification que la documentation des indicateurs est complète
  var_mq <- dplyr::setdiff(var, metadata_indicateur$variable) %>% paste(collapse = "\n")
  var_en_trop <- dplyr::setdiff(metadata_indicateur$variable, c("depcom", "date", var)) %>% paste(collapse = "\n")
  attempt::stop_if_not(all(var %in% metadata_indicateur$variable),
                       msg = glue::glue("La table df contient des variables non document\u00e9es dans le r\u00e9f\u00e9rentiel google sheet : \n{var_mq}\n"))
  attempt::stop_if_not(all(metadata_indicateur$variable %in% c("depcom", "date", var)),
                       msg = glue::glue("Le r\u00e9f\u00e9rentiel google sheet des indicateurs contient des variables absentes de la table df :\n{var_en_trop}\n",
                                        "V\u00e9rifier si df contient bien toutes les variables attendues et adpatez le r\u00e9f\u00e9rentiel des indicateurs au besoin."))
  
  
  ## Envoi des libellés de variable dans le SGBD
  datalibaba::post_dico_attr(dico = metadata_indicateur, table = nom_table_sgbd, schema = "portrait_territoires",
                 db = "datamart", user = "does")
  
  ## Récupération des métadonnées de la source
  nom_sce <- stringr::str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
    stringr::str_replace("indicateur_", "") %>%
    stringr::str_replace("_cogiter|_cog$", "")
  
  metadata_source <- googlesheets4::read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                sheet = "sources") %>%
    dplyr::filter(source == nom_sce) %>% 
    dplyr::mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
    dplyr::pull(com_table) %>% 
    # ajout de complement sur la généalogie
    paste0("\n", comm_source_en_plus)
  
  
  ## commentaires de la table
  
  datalibaba::commenter_table(comment = metadata_source,
                  db = "datamart",
                  schema = "portrait_territoires",
                  table = nom_table_sgbd, 
                  user = "does")
  
}



