
# chargement_aom_epci

# chargement des autorités organisatrices de la mobilité (AOM) à partir du site Banatic
# https://www.banatic.interieur.gouv.fr/V5/fichiers-en-telechargement/fichiers-telech.php# dans fichiers en télechargement, fichier "France"-"compétence des groupements"
# fichier excel , transformé en csv
# données au 01/04/2022
# valeur des codes de compétence disponibles sur 
# https://www.banatic.interieur.gouv.fr/V5/ressources/documents/document_reference/Banatic_Metadonnees2019.xlsx
# le code correspondant aux AOM est le C4530 "Organisation de la mobilité, au sens des articles L.1231-1 et suivants du code des transports"

# Controle fait en amont sur le fichier qu'aucun autre organisme (SIVU, SIVOM,SMF,SMO...) , 
# à cheval sur plusieurs EPCI, n'avait un plan de mobilité dans la région.

# Sortie à l'EPCI des Pays de la Loire


# librairies ------------
library(tidyverse)
library(COGiter)
library(lubridate)
library(dplyr)
library(COGiter)
library(DBI)
library(RPostgreSQL)

rm(list = ls())


# chargement des données --------
aom <- read.csv2("extdata/AOM_Compétences des groupements - France entière.csv",
                 dec='.', 
                 header = TRUE, 
                 sep=";",
                 stringsAsFactors = FALSE)


# calcul -----------------

# liste des EPCI de la région 52
epci_interreg <- epci %>%
  filter( grepl("52", REGIONS_DE_L_EPCI)) %>%
  select(EPCI) %>%
  mutate(EPCI=as.character(EPCI))%>% 
  pull(EPCI)

date = 2022

aom <- aom %>%
  mutate(N..SIREN = as.character(N..SIREN)) %>%
  filter(C4530 == 1 , N..SIREN %in% epci_interreg)%>%
  rename(epci = N..SIREN) %>% 
  select("epci") %>%
  mutate(date = make_date(date,04,01), AOM ="TRUE") %>% 
  mutate(epci = fct_expand(epci, epci_interreg)) %>%  
  complete(epci,date,fill = list(AOM = "FALSE"))

# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = aom,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "ref_aom_epci",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("epci", "date"), # déclaration d'une clé primaire sur la table postée : on ne doit pas avoir deux lignes avec à la fois le même code commune et la meme date
            user = "does")

# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(aom), c("epci", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- "ref_aom_epci"

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()



## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "epci", "Code INSEE de l'EPCI",
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, table = "ref_aom_epci", schema = "portrait_territoires",
               db = "datamart", user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table) %>%
  # ajout de complement sur la généalogie
  paste0(".\n", "Chargement des donn\u00e9es sur banatic.interieur.gouv.fr")

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "source_ptz", 
                user = "does")

