
# chargement_basemis

# Consommation d'énergie et émissions de GES BASEMIS v5

# librairies ------------
library(dplyr)
library(tidyr)
library(purrr)
library(lubridate)
library(readxl)
library(tricky)
library(readODS)
library(readr)
library(forcats)
library(datalibaba)
library(googlesheets4)
library(stringr)

rm(list = ls())


# paramètres ---------
vbasemis <- "5"
fic <- "airpl - donnees BASEMIS v5 - TEO -integral.xlsx"
source("R/levels_facteurs_com.R") # pour obtenir tous les levels de DEPCOM (périm région seule ou avec EPCI à cheval)


# lecture dimension, modalités ---------
dim_basemis <- read_ods("metadata/Basemis.ods", sheet = "lib_modalites_dim", 
                        col_names = T, col_types = cols(.default = "f")) %>%
  mutate_all(~ fct_inorder(.))

dim_secteur <- filter(dim_basemis, variable=="secteur") %>% 
  mutate_all(~ fct_drop(.))

dim_nrj <- filter(dim_basemis, variable=="nrj") %>% 
  mutate_all(~ fct_drop(.))

# lecture data ---------
basemis0 <- read_xlsx(path=paste0("extdata/", fic), sheet=2, na="na") 


# calcul --------
basemis1 <- basemis0 %>% 
  set_standard_names() %>%
  mutate_at(vars(-starts_with("ges"), -starts_with("energie")), ~as.character(.)  %>% as.factor(.)) %>%
  select(date=annee, depcom=code_insee, secteur, nrj=type_energie, conso_ktep=energie_finale_ktep_, 
         ges_sc1_teqco2=ges_scope_1_teqco2_, ges_sc2_teqco2=ges_scope_2_teqco2_) %>% 
  left_join(select(dim_secteur, secteur_mod = modalites, secteur=lib)) %>%
  left_join(select(dim_nrj, nrj_mod = modalites, nrj=lib)) %>%
  select(-nrj, -secteur) %>% 
  pivot_longer(cols=c(starts_with("conso"), starts_with("ges")), names_to = "variable", values_to = "valeur") %>%
  mutate(valeur=replace_na(valeur,0))

# ### Pour mettre à jour la liste des variables et les ordonner dans data/metadata/Basemis.ods
# liste_var <- tibble(var_deb="secteur", variable=NA, lib_var=levels(basemis$secteur)) %>%
#   bind_rows(tibble(var_deb="nrj", variable=NA, lib_var=levels(basemis$type_energie)))

mod_variables <- expand.grid(Var1 = dim_nrj$modalites,
                             Var2 = dim_secteur$modalites,
                             Var3 = unique(basemis1$variable)) %>% 
  unite(col= variable,Var3,Var2,Var1, sep=".") %>%
  pull(variable) %>% 
  as_factor()

basemis2 <- basemis1 %>% 
  unite(col= variable, variable, secteur_mod, nrj_mod, sep=".") %>%
  mutate(variable=factor(variable)) %>%
  filter(!is.na(valeur)) %>%
  mutate(variable = fct_drop(variable), 
         date = make_date(as.character(date), 12, 31)) %>%
  mutate_if(is_character, as.factor) %>%
  mutate(depcom = fct_expand(depcom, com_reg)) %>%
  complete(depcom, date, variable, fill = list(valeur = 0)) %>%
  mutate(depcom = fct_expand(depcom, com_reg_et_vois)) %>%
  complete(depcom, date, variable, fill = list(valeur = NA)) %>% 
  
  pivot_wider(names_from = variable, values_from = valeur)

variables_d_interet <- summarise(basemis, across(where(is.numeric), sum, na.rm = TRUE)) %>% 
  select_if(~.x != 0) %>% names() 

basemis <- basemis2 %>% 
  select(depcom, date, all_of(variables_d_interet)) %>% 
  mutate(depcom = as.character(depcom))

# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = basemis,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "source_basemis",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("depcom", "date"), # déclaration d'une clé primaire sur la table postée : on ne doit pas avoir deux lignes avec à la fois le même code commune et la meme date
            user = "does")


# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(basemis), c("depcom", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce, variable %in% variables_d_interet) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "depcom", "Code INSEE de la commune",
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, table = "source_basemis", schema = "portrait_territoires",
               db = "datamart", user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table) %>% 
  # ajout de complement sur la généalogie
  paste0(".\n", "BASEMIS version", vbasemis)

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "source_basemis", 
                user = "does")


rm(list=ls())
