
# chargement_copro_fragiles

# librairies --------
library(dplyr)
library(tidyr)
library(sf)
library(lubridate)
library(datalibaba)
library(forcats)

rm(list = ls())

# Fixation de la borne à partir de laquelle les copro sont considérées comme fragiles
# Si elles font partie des X % plus grandes valeurs
X = 5

# mise à jour dans le SGBD 2e trimestre 2022
# date = 2022
# mise à jour dans le SGBD 2e trimestre 2023
date = 2023

# liste des communes de la région et des EPCI limitrophes
source("R/levels_facteurs_com.R")

# chargement fichier
n_copro_fragilite_s_r52 <- importer_data(table = "n_copro_fragilite_s_r52",
                                         schema = "habitat_politique_de_la_ville",
                                         db = "consultation") 

copro_fragiles0 <- n_copro_fragilite_s_r52 %>% 
  select(commune, c_total_classes) %>%
  st_drop_geometry()

valeurs <- copro_fragiles0 %>% 
  pull(c_total_classes) %>% 
  as.numeric()

borne <- as.numeric(quantile(valeurs, 1-(X/100)))

copro_fragiles <- copro_fragiles0 %>%
  mutate (valeur = 1, variable = if_else(c_total_classes <= borne, "nb_copro_non_fragile", "nb_copro_fragile")) %>%
  group_by(commune, variable) %>% 
  summarise(valeur = sum(valeur, na.rm = TRUE), .groups = "drop") %>%
  pivot_wider(names_from = variable, values_from = valeur, values_fill = 0) %>% 
  mutate(nb_copro_total = nb_copro_non_fragile + nb_copro_fragile) %>% 
  pivot_longer(names_to = "variable", values_to = "valeur", cols = contains("_copro_")) %>%
  rename(depcom = commune) %>%
  mutate(date = make_date(date, 06, 30))%>%
  mutate_if(is.character, as.factor) %>%
  select(depcom, date, variable, valeur) %>%
  ungroup() %>%
  mutate(depcom = fct_expand(depcom, com_reg)) %>%
  complete(depcom, date, variable, fill = list(valeur = 0)) %>%
  unique() %>% 
  mutate(depcom = fct_expand(depcom, com_reg_et_vois) %>% fct_inseq()) %>%
  complete(depcom, date, variable, fill = list(valeur = NA)) %>% 
  pivot_wider(names_from = variable, values_from = valeur)

  
# versement dans le sgbd/datamart.portrait_territoires et metadonnee -------------
source("R/poster_documenter_data.R")
poster_documenter_it(df = copro_fragiles,
                     nom_table_sgbd = "source_copro_fragiles",
                     comm_source_en_plus = "")

