
# chargement_couverture_sage

library(magrittr)

rm(list = ls())


# chargement SAGE ------------
n_sage_r52 <- datalibaba::importer_data(
  db = "si_eau",
  schema = "zonages_de_gestion",
  table = "n_sage_r52"
  ) %>% 
  dplyr::mutate(
    lb_etat = dplyr::case_when(
      lb_etat == "Mis en oeuvre"~"mis_en_oeuvre",
      lb_etat == "Élaboration"~"elaboration",
      lb_etat == "Première révision"~"premiere_revision"
      )
    )
# mapview::mapview(n_sage_r52, zol = c("nom"), color = "blue", alpha.regions = 0.5, legend = T)
# la couche géographique est de mauvaise qualité, car des limites de SAGE intersectent entre elles !
# idem pour la table disponible sur sigloire !


# limites administratives ----------

# chargement de la liste des depcom COGiter région PDL et région PDL + epci
source("R/levels_facteurs_com.R")

com <- COGiter::communes_geo %>% 
  dplyr::filter(DEPCOM %in% com_reg_et_vois)


# intersection entre SAGE et communes ------------------
intersection_sage_communes <- sf::st_intersection(
  sf::st_buffer(n_sage_r52, 0), 
  sf::st_buffer(com, 0)
  )
# mapview::mapview(intersection_sage_communes)
# cette carte montre la mauvaise qualité géométrique de la table n_sage_r52

intersection_sage_communes <- intersection_sage_communes %>% 
  dplyr::mutate(surf_sage_intersect = sf::st_area(the_geom)) %>% 
  sf::st_drop_geometry() %>%
  dplyr::select(
    DEPCOM,
    AREA, 
    nom_sage = nom, 
    code_sage = code, 
    lb_etat, 
    surf_sage_intersect
  ) %>% 
  dplyr::mutate(
    pourcentage = round(surf_sage_intersect/AREA *100, digits = 0)
  ) 
intersection_sage_communes$pourcentage <- units::drop_units(intersection_sage_communes$pourcentage)


# détermination des communes HORS SAGE ---------- 
sage <- dplyr::summarise(sf::st_buffer(n_sage_r52, 0), do_union = TRUE)
# mapview::mapview(sage)
# cette carte montre la mauvaise qualité géométrique de la table n_sage_r52

communes_hors_sage_0 <- sf::st_difference(sf::st_buffer(com, 0), sf::st_buffer(sage, 0))
# mapview::mapview(communes_hors_sage_0)
# cette carte montre la mauvaise qualité géométrique de la table n_sage_r52

communes_hors_sage_1 <- communes_hors_sage_0 %>%
  dplyr::mutate(
    nom_sage = "HORS SAGE",
    code_sage = "SAGE00000",
    lb_etat = "hors_sage",
    surf_sage_intersect = sf::st_area(geometry)
  ) %>%
  sf::st_drop_geometry() %>% 
  dplyr::mutate(
    pourcentage = round(surf_sage_intersect/AREA *100, digits = 0)
  )
communes_hors_sage_1$pourcentage <- units::drop_units(communes_hors_sage_1$pourcentage)

pourcentage_com_sage <- dplyr::bind_rows(
  communes_hors_sage_1,
  intersection_sage_communes
) %>% 
  dplyr::arrange(DEPCOM) %>% 
  dplyr::select(
    DEPCOM,
    nom_sage,
    pourcentage
  ) # 2157 obs

pourcentage_com_sage_filtre <- pourcentage_com_sage %>% 
  dplyr::filter(nom_sage == "HORS SAGE") %>% # 451 obs
  # dplyr::filter(pourcentage > 3) # 70 obs
  dplyr::filter(pourcentage >= 5) # 68 obs
  # dplyr::filter(pourcentage > 10) # 64 obs

pourcentage_com_sage_filtre_geom <- dplyr::left_join(
  com, 
  pourcentage_com_sage_filtre
  ) %>% 
  dplyr::filter(!is.na(nom_sage))

mapview::mapview(
  pourcentage_com_sage_filtre_geom,
  color = "blue", col.regions = "blue", alpha.regions = 0.5,
  legend = T, layer.name = "communes"
  ) +
    mapview::mapview(
      n_sage_r52,
      color = "red", col.regions = "red", alpha.regions = 0.2, 
      legend = T, layer.name = "SAGE")

# affinage à la main
`%notin%` <- Negate(`%in%`)
pourcentage_com_sage_filtre_geom_2 <- pourcentage_com_sage_filtre_geom %>%
  dplyr::filter(
    DEPCOM %notin% c("44020", "44203", "44136", "85106", "85011", "85222",
                     "85045", "85001", "85128", "85073", "85233", "85290",
                     "85281", "85126", "85092")
  )
mapview::mapview(
  pourcentage_com_sage_filtre_geom_2, 
  color = "blue", col.regions = "blue", alpha.regions = 0.5, 
  legend = T, layer.name = "communes_hors_SAGE"
  ) +
  mapview::mapview(
    n_sage_r52, 
    color = "red", col.regions = "red", alpha.regions = 0.2, 
    legend = T, layer.name = "SAGE"
    )

liste_com_hors_sage <-  pourcentage_com_sage_filtre_geom_2$DEPCOM %>% unique()
pourcentage_com_sage_filtre_geom_2$AREA <- units::drop_units(pourcentage_com_sage_filtre_geom_2$AREA)
intersection_sage_communes$AREA <- units::drop_units(intersection_sage_communes$AREA)
intersection_sage_communes$surf_sage_intersect <- units::drop_units(intersection_sage_communes$surf_sage_intersect)

communes_hors_sage_2 <- pourcentage_com_sage_filtre_geom_2 %>% 
  sf::st_drop_geometry() %>% 
  dplyr::full_join(intersection_sage_communes) %>% 
  dplyr::filter(DEPCOM %in% liste_com_hors_sage) %>% 
  dplyr::mutate(
    code_sage = ifelse(is.na(code_sage), "SAGE00000", code_sage),
    lb_etat = ifelse(is.na(lb_etat), "hors_sage", lb_etat),
    surf_sage_intersect = ifelse(is.na(surf_sage_intersect), 0, surf_sage_intersect)
  ) %>% 
  dplyr::group_by(DEPCOM) %>% 
  dplyr::mutate(
    somme_surf_sage_intersect = sum(surf_sage_intersect),
    surf_sage_intersect = ifelse(surf_sage_intersect == 0, AREA - somme_surf_sage_intersect, surf_sage_intersect)
      ) %>% 
  dplyr::ungroup() %>% 
  dplyr::select(-somme_surf_sage_intersect)
  

# calcul de l'indicateur----------
indicateur_couverture_sage_1 <- dplyr::bind_rows(
  intersection_sage_communes %>% dplyr::filter(DEPCOM %notin% liste_com_hors_sage),
  communes_hors_sage_2
  ) %>% 
  dplyr::group_by(DEPCOM, lb_etat) %>% 
  dplyr::summarise(surf_etat_sage = sum(surf_sage_intersect)) %>% 
  dplyr::ungroup() %>% 
  dplyr::filter(!is.na(lb_etat)) %>% 
  # lib_etat du SAGE "VIENNE TOURANGELLE"(SAGE04058) n'est pas renseigné et touche peu la seule commune de Montsoreau
  tidyr::spread(lb_etat, surf_etat_sage)

indicateur_couverture_sage_1 <- dplyr::mutate_all(indicateur_couverture_sage_1, ~replace(., is.na(.), 0))

indicateur_couverture_sage_2 <- indicateur_couverture_sage_1 %>% 
  dplyr::left_join(
    com %>%
      sf::st_drop_geometry() %>%
      dplyr::select(DEPCOM, AREA)
    ) %>% 
  dplyr::rename(depcom = DEPCOM) %>% 
  dplyr::mutate(date = as.Date("2024-02-01")) %>% 
  dplyr::select(depcom, date, tidyselect::everything()) %>% 
  dplyr::mutate_if(is.character, as.factor) %>% 
  dplyr::rename(surf_calculee_en_m2 = AREA)
indicateur_couverture_sage_2$surf_calculee_en_m2 <- units::drop_units(indicateur_couverture_sage_2$surf_calculee_en_m2)

# selon SIGLOIRE, mise à jour en continue (tâche planifiée se déclenche tous les 1er du mois), donc 2024-02-01
# Zones d'application des Schémas d'aménagement et de gestion des eaux (SAGE) en Pays de la Loire
# https://catalogue.sigloire.fr/geonetwork/srv/fre/catalog.search;jsessionid=4BFDBE635A3699F7CC8151B1827679CE#/metadata/98864cf0-d06b-11de-b18a-00004f6210c3


# versement dans le sgbd/datamart.portrait_territoires et metadonnées --------
source("R/poster_documenter_data.R", encoding = "UTF-8")
poster_documenter_it(
  df = indicateur_couverture_sage_2 ,
  nom_table_sgbd = "source_couverture_sage", 
  comm_source_en_plus = ""
  )



