# chargement_dph_reno_lls

# rénovation du parc public - données suivi DPH


# librairies ----
library(dplyr)
library(tidyr)
library(purrr)
library(stringr)
library(forcats)
library(lubridate)
library(tricky)
library(readxl)
library(datalibaba)
library(googlesheets4)


rm(list=ls())


# fonctions --------

# découverte nom fichier
nom_fich <- list.files(path = "extdata", pattern = "Suivi réhab" , ignore.case = TRUE)[2] # "0802H21JA suivi réhab bilan 2020.xls"

# fonctions utilitaires
is_not_empty <- function(x) any(!is.na(x) & x != "")
is_pas_zero  <- function(x) {
  if(is.numeric(x)) {any(x!=0)}
  else {TRUE}
}

source("R/levels_facteurs_com.R") # pour obtenir tous les levels de DEPCOM (périm région seule)


# chargement des données -----------
LS_renov <- read_excel(paste0("extdata/", nom_fich), 1, skip= 10) %>%
  set_standard_names() %>%
  rename_with(~gsub("²","2", .x)) %>%
  rename_with(~gsub("°","o", .x)) %>%
  rename_with(~gsub("^_|_$","", .x)) %>%
  filter(!is.na(code_commune), !is.na(nb_logts))  %>%  #  25 opérations non affectées à une commune ! Dans les débuts
  select(depcom = code_commune, everything(), -dept, -c(commune:nom_epci), -c(eco_pret_cdc:sources_financeurs), 
         -cdc_2015_a_2019, -annee_de_construction_ou_d_acquisition, -gain_estime_en_tonnes_de_co2_an, -starts_with("feder_")) %>%
  select_if(is_not_empty) %>% 
  mutate(across(c(calcul_automatique_du_gain_energetique_economise_kwhep_an, gain_energetique_apres_travaux), as.numeric)) %>%
  mutate(across(c(starts_with("surf"), starts_with("classe_dpe"), starts_with("perf"), nb_logts, gain_energetique_apres_travaux,
                  calcul_automatique_du_gain_energetique_economise_kwhep_an), ~ na_if(.x, 0))) %>%
  mutate(across(c(classe_dpe_avant_travaux, classe_dpe_apres_travaux), .fn = list(calcul = ~ case_when(.x %in% c("A","A (BBC)") ~ 40,
                                                                                           .x =="B" ~ 71,
                                                                                           .x =="C" ~ 121,
                                                                                           .x =="D" ~ 191,
                                                                                           .x =="E" ~ 281,
                                                                                           .x =="F" ~ 391,
                                                                                           .x =="G" ~ 600,
                                                                                           .x =="C ou D" ~ 150,
                                                                                           .x =="D/E" ~ 230,
                                                                                           .x =="F à G" ~ 450,
                                                                                           .x =="0" ~ NA_real_)
                                                                                  )
                )) %>% 
  mutate(gain_energ_m2 = coalesce(gain_energetique_apres_travaux, perf_nrj_avant_travaux-perf_nrj_apres_travaux, classe_dpe_avant_travaux_calcul - classe_dpe_apres_travaux_calcul)) %>%
  mutate(gain_energ_m2 = na_if(gain_energ_m2, 0)) %>%
  mutate(id = row_number(), ecart_DPE = classe_dpe_apres_travaux_calcul - classe_dpe_avant_travaux_calcul,
         depcom = case_when(operation=="1/11 rue des Planches"& depcom %in% c("72094", "72095", "72093") ~ "72093", # une erreur de saisie tiré-collé
                            depcom=="49400" ~ "49016", # ancienne commune de Bagneux 49400 correspond au code postal, opération 1, 5, 7, 18 rue des menhirs
                            TRUE ~ depcom), 
         nb_logts_redr=case_when(operation == "Lotissement du Rocher" & nb_logts==88 ~ 8,  # erreur de saisie manifeste, la commune déléguée comprend 300 ménages
                                 operation == "RUE TRAVOT RESIDENCE LES HORTENSIAS" & perf_nrj_avant_travaux == 346.00 ~ 7, # recherche web https://www.vendeehabitat.fr/vendee-habitat/nos-grands-projets/la-renovation-du-patrimoine/
                                 operation == "RUE TRAVOT RESIDENCE LES HORTENSIAS" & perf_nrj_avant_travaux == 343.00 ~ 7, # https://www.vendeehabitat.fr/je-suis-locataire/carte-interactive-locations/residences/residence-des-hortensias/
                                 operation == "RUE TRAVOT RESIDENCE LES HORTENSIAS" & perf_nrj_avant_travaux == 350.00 ~ 8, # 14+8 logements rénovés dans cette résidence
                                 operation == "ROUTE DU STADE" & perf_nrj_avant_travaux == 188.00 ~ 5, # https://www.vendeehabitat.fr/vendee-habitat/nos-grands-projets/la-renovation-du-patrimoine/
                                 operation == "ROUTE DU STADE" & perf_nrj_avant_travaux == 188.00 ~ 4, # recherche web (bois foucaud) 9 lgt rénovés au lieu de 1 
                                 TRUE ~ nb_logts),
         surface_utile_ou_corrigee_apres_travaux_cdc = if_else(organisme == "Vendée Logement" & surface_utile_ou_corrigee_apres_travaux_cdc == 1255, NA_real_, surface_utile_ou_corrigee_apres_travaux_cdc),
         surface = coalesce(surface_de_l_operation_m2_shab, surface_utile_ou_corrigee_apres_travaux_cdc),
         surface_redr = case_when(operation == "6-10-12-14-16 Place de l'Europe - 3-4-5-6- Rue Amélie de la Robrie" | grepl("Cité de Bourgogne", operation) | nb_logts <50 & surface_utile_ou_corrigee_apres_travaux_cdc > 30000  ~ surface/10, # erreur de saisie de la virgule (logt de 900m² sinon)
                                  operation == "ROUTE DU STADE" ~ 70, # calculé par calcul_automatique_du_gain_energetique_economise_kwhep_an/gain_energetique_apres_travaux
                                  TRUE ~ surface),
         surf_moy = surface_redr / nb_logts_redr) %>%
  mutate(surf_moy = if_else(operation == "BAUGE", 108.33, surf_moy)) %>%
  select(depcom:nb_logts, everything(), -c(perf_nrj_avant_travaux:classe_dpe_apres_travaux_calcul), starts_with("surf")) %>% 
  arrange(operation)


## correction des surfaces : les surfaces eco pret cdc sont souvent globales, le nb de logements doit comporter des doublons
doublons_surf <- filter(LS_renov, !is.na(surface)) %>%
  group_by(paste0(organisme, surface_utile_ou_corrigee_apres_travaux_cdc)) %>%
  mutate(nb_ligne = n(), surf_moy_max_group = max(surf_moy), surf_moy_redressee = surface_redr/sum(nb_logts_redr)) %>%
  mutate(surf_retenue = if_else(surf_moy <= 75 | (surf_moy <= 130 & surf_moy_redressee <= 15) | 
                                  surf_moy <= 150 & surf_moy_redressee <= 60 & grepl("lotisse", tolower(operation)), 
                                surf_moy, surf_moy_redressee)) %>% 
  select(depcom:nb_logts, starts_with("surf"), everything()) %>% 
  filter(nb_ligne > 1) %>%
  arrange(operation) %>% ungroup() %>%
  select(id, surf_retenue)

LS_renov2 <- left_join(LS_renov, doublons_surf) %>%
  mutate(surf = coalesce(surf_retenue, surf_moy)) %>%
  mutate(surf = if_else(surf > 260 | surf < 12, NA_real_, surf))%>%
  select(everything(), -starts_with("surf"), -nb_logts, nb_logts = nb_logts_redr, surf) 

surf_moy <- filter(LS_renov2, !is.na(surf) & surf != 0) %>%
  summarise(surface = weighted.mean(surf, nb_logts)) %>% pull(surface)

LS_renov3 <- mutate(LS_renov2, surf_moy_corr_na = coalesce(surf, surf, surf_moy))

gain_surf_moy <- filter(LS_renov3, !is.na(gain_energ_m2)) %>%
  summarise(gain_energ_m2 = weighted.mean(gain_energ_m2, surf_moy_corr_na)) %>% 
  pull(gain_energ_m2)

LS_renov4 <- mutate(LS_renov3, gain_nrj_m2_corr_na = coalesce(gain_energ_m2, gain_surf_moy)) %>%
  select(annee = annee_financement_retenu, id, organisme, everything(), -gain_energ_m2, -surf, -ecart_DPE, -operation) %>% 
  rename_with( ~ gsub("_corr_na$", "", .x)) %>%
  mutate(typemo = if_else(typemo == "OPAC", "OPH", typemo)) %>%
  mutate_if(is.character, as.factor) %>%
  mutate_if(is.factor, ~ fct_explicit_na(., "inconnu"))

renov_lls <- group_by(LS_renov4, annee, depcom, typemo) %>%
  mutate(gain_nrj = nb_logts * surf_moy * gain_nrj_m2, surf = nb_logts * surf_moy) %>%
  summarise(n_org = n_distinct(organisme), nb_ope = n(),
            gain_nrj = sum(gain_nrj), surf = sum(surf), nb_logts = sum(nb_logts), .groups = "drop") %>%
  select(annee:nb_ope, nb_logts, everything()) %>%
  pivot_longer(names_to = "variable", values_to = "valeur", cols = n_org:surf) %>%
  mutate(variable = paste(variable, typemo, sep = ".")) %>%
  mutate_if(is.character, as.factor) %>% 
  mutate(depcom = fct_expand(depcom, com_reg)) %>%
  complete(depcom, annee, variable, fill = list(valeur = 0)) %>%
  mutate(date = make_date(as.character(annee), 12, 31),
         variable = tolower(variable)) %>%
  select(-typemo, -annee) %>%
  mutate_if(is.factor, as.character)


# # Calculs des données de synthese pour validation DPH ------------
# nom_des_communes <- select(communes, DEPCOM, nom_commune=NOM_DEPCOM) %>%
#   mutate_if(is.factor, as.character)
# 
# indic_reno_LLS <- filter(renov_lls, grepl("nb_logts|surf", variable)) %>%
#   separate(variable, into=c("indic", "type_org"), sep="\\.") %>%
#   group_by(depcom, indic) %>%
#   summarise(valeur=sum(valeur))%>%
#   ungroup() %>%
#   spread(indic, value = valeur) %>%
#   mutate_if(is.factor, as.character) %>%
#   cogifier(code_commune = depcom, communes = T, epci = F, departements = T, regions = T, metro = F, metrodrom = F, as_df = T ) %>%
#   mutate_if(is.factor, as.character) %>%
#   left_join(nom_des_communes, by=c("CodeZone"="DEPCOM")) %>%
#   select(depcom=CodeZone, nom_commune, nb_logts, surf)
# 
# write.csv2(indic_reno_LLS, file="extdata/indic_reno_LLS_20201231.csv", row.names = FALSE)

renov_lls <- renov_lls %>% 
  complete(depcom, date, variable, fill = list(valeur = 0)) %>% # Ajout des communes de la régions à 0
  mutate(depcom = fct_expand(depcom, com_reg_et_vois)) %>% # Ajout des communes hors régions des EPCI de la région, à mettre à NA
  complete(depcom, date, variable, fill = list(valeur = NA)) %>%
  pivot_wider(names_from = variable, values_from = valeur)


# versement dans le sgbd/datamart.portrait_territoires -------------

poster_data(data = renov_lls,
               db = "datamart",
               schema = "portrait_territoires", 
               table = "source_dph_reno_lls",
               post_row_name = FALSE, 
               overwrite = TRUE,
               droits_schema = TRUE,
               pk = c("depcom", "date"), # déclaration d'une clé primaire sur la table postée : on ne doit pas avoir deux lignes avec à la fois le même code commune et la meme date
               user = "does")
   
   # METADONNEES------------------------------------
   
   ## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
   var <- setdiff(names(renov_lls), c("depcom", "date"))
   
   ## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
   nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
     basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
     gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'
   
   ## authentification google sheet grâce au .Renviron
   gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
   gs4_deauth()
   
   ## chargement du référentiel indicateurs google sheet
   metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                     sheet = "indicateurs") %>%
     # on ne garde que les variables concernées par le présent script de chargement
     filter(source == nom_script_sce) %>% 
     # on ajoute l'unité dans le libellé de la variable
     mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
     select(variable, libelle_variable) %>% 
     # ajout des libellés pour depcom et date
     bind_rows(
       tribble(
         ~variable, ~libelle_variable,
         "depcom", "Code INSEE de la commune",
         "date", "Millesime"
       )
     )
   
   ## Vérification que la documentation des indicateurs est complète
   all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE
   
   ## Envoi des libellés de variable dans le SGBD
   post_dico_attr(dico = metadata_indicateur, table = "source_dph_reno_lls", schema = "portrait_territoires",
                  db = "datamart", user = "does")
   
   ## Récupération des métadonnées de la source
   nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
     str_replace("indicateur_", "") %>%
     str_replace("_cogiter|_cog$", "")
   
   metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                 sheet = "sources") %>%
     filter(source == nom_sce) %>% 
     mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
     pull(com_table) %>% 
     # ajout de complement sur la généalogie
     paste0(".\n", "Table de suivi ", nom_fich, " fournie par SIAL-DPH.")
   
   ## commentaires de la table
   
   commenter_table(comment = metadata_source,
                   db = "datamart",
                   schema = "portrait_territoires",
                   table = "source_dph_reno_lls", 
                   user = "does")
   

   
rm(list=ls())
