
# chargement_ecln

# librairies ------------
library(readxl)
library(tidyverse)
library(tricky)
library(lubridate)
library(COGiter)
library(DBI)
library(RPostgreSQL)
library(datalibaba)
library(googlesheets4)

rm(list = ls())

# chargement des données ECLN (Enquete sur la commercialisation des logements neufs) --------
# fichier cree a partir d une requete geokit 3 :
# "Dossiers publics/geokit3/Regions Pays de la Loire/DREAL/INDICATEURS TER DATA LAB/gk3_ecln"
ecln <- read_excel("extdata/gk3_ecln.xlsx",sheet=1)


# liste des communes COGiter ------
com_fr<- communes %>%
  select(DEPCOM) %>%
  mutate(DEPCOM=as.character(DEPCOM)) %>%
  pull(DEPCOM)


# calcul ---------
ecln1<-ecln %>%
  # filter(date>=2008)%>%
  mutate(type_construction=str_replace(type_construction,'1. Individuel', "individuel") %>% 
           str_replace('2. Collectif',"collectif"))

ecln2<-ecln1 %>%
  group_by(date,depcom) %>% 
  summarise(nb_logt_mis_en_vente=sum(nb_logt_mis_en_vente,na.rm=T),
            nb_logt_reserves_a_la_vente=sum(nb_logt_reserves_a_la_vente,na.rm=T),
            nb_logt_reserves_a_la_vente_en_invest_loc=sum(nb_logt_reserves_a_la_vente_en_invest_loc,na.rm=T),
            nb_logt_en_cours=sum(nb_logt_en_cours,na.rm=T),
            prix_total_des_ventes=sum(prix_total_des_ventes,na.rm=T),
            surface_totale_des_ventes=sum(surface_totale_des_ventes,na.rm=T),
            nb_promoteurs_mev=sum(nb_promoteurs_mev,na.rm=T),
            nb_promoteurs_reserves=sum(nb_promoteurs_reserves,na.rm=T),
            nb_promoteurs_en_cours=sum(nb_promoteurs_en_cours,na.rm=T)
            ) %>%
  ungroup() %>%
  mutate(type_construction="total")%>%
  as.data.frame()

ecln<-bind_rows(ecln1,ecln2) %>%
  rename(nb_logt_vendus = nb_logt_reserves_a_la_vente,
         nb_logt_vendus_en_invest_loc = nb_logt_reserves_a_la_vente_en_invest_loc,
         nb_promoteurs_vendus = nb_promoteurs_reserves)%>%  
  gather(variable,valeur,nb_logt_mis_en_vente:`nb_promoteurs_en_cours`)%>% 
  mutate(variable=paste0(variable,".",type_construction)) %>% 
  select(depcom,date,variable,valeur)%>% 
  mutate(date=make_date(date,12,31))%>% 
  mutate_if(is.character,as.factor) %>% 
  mutate(depcom = fct_expand(depcom, com_fr)) %>%  
  complete(depcom,date,variable,fill = list(valeur =0)) %>% 
  pivot_wider(names_from = variable,values_from = valeur)


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = ecln,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "source_ecln",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("depcom", "date"), # déclaration d'une clé primaire sur la table postée : on ne doit pas avoir deux lignes avec à la fois le même code commune et la meme date
            user = "does")

# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(ecln), c("depcom", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()



## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "depcom", "Code INSEE de la commune",
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, table = "source_ecln", schema = "portrait_territoires",
               db = "datamart", user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table) %>%
  # ajout de complement sur la généalogie
  paste0(".\n", "Chargement des donn\u00e9es sur Geokit3")

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "source_ecln", 
                user = "does")













