
# chargement_enq_collecte_ademe

# indicateurs CRTE : tonnage de déchets produits par le territoire et Taux de tri sélectif par filière

# librairies --------
library(dplyr)
library(tidyr)
library(tibble)
library(forcats)
library(stringr)
library(readr)
library(purrr)
library(COGiter)
library(tricky)
library(lubridate)
library(datalibaba)
library(googlesheets4)


rm(list=ls())


# on récupère les données de l'enquête collecte via SINOE--------
# Export SINOE - avec codes identification 'DREAL52'
# https://www.sinoe.org/thematiques/consult/ss-theme/3
# choisir la requête 'EPCI et communes exerçant au moins une compétence déchet'
# filtrer sur l'année de la dernière enquête collecte par 'Filtre Année(s) / Situation' 
# filtrer sur les 3 compétences collecte (type indifférent) - on écarte la compétence traitement
# exporter le résultats de la recherche excel ou csv
# cocher 'Indicateurs des collectes d'ordures ménagères résiduelles, collectes sélectives et déchèteries (tonnage, pop desservie, destination)'
# cocher 'données complémentaires annuelles'
# Cocher 'Gestion de proximité des biodéchets : compostage individuel, partagé, en pied d'immeuble' 
# prévisualiser et exporter


# passage des entêtes de colonnes sur une seule ligne ------
enq_collecte_full_noms0 <- readxl::read_xls(path = "X:/SCTE/DOES/IT/extdata/Sinoe_collecte_intercom_2017_Fce.xls",
                                            sheet = 1, 
                                            range = "A1:ES4",
                                            col_names = FALSE) %>% 
  t(.) %>% 
  as_tibble %>% 
  rownames_to_column("id_row") %>% 
  mutate(id_row = as.numeric(id_row),
         noms = case_when(id_row <= 33 ~ V2,
                          id_row < 44 ~ paste0("omr0", V3),
                          id_row < 54 ~ paste0("encombrants0", V3),
                          id_row < 64 ~ paste0("ddangereux0", V3),
                          id_row < 74 ~ paste0("pap_embal0", V3),
                          id_row < 84 ~ paste0("biodech0", V3),
                          id_row < 94 ~ paste0("verre0", V3),
                          id_row < 104 ~ paste0("gravats_sep0", V3),
                          id_row < 114 ~ paste0("coll_sep_hs_grav0", V3),
                          id_row < 132 ~ paste0("decheteries0", V3),
                          id_row < 138 ~ paste0("coll_et_decheteries_hs_grav0", V3),
                          id_row < 145 ~ paste0("compost_ind0", V4),
                          id_row >= 145 ~ paste0("compost_coll0", V4),
                          TRUE ~ "a revoir") %>% 
           str_standardize("") %>% 
           gsub("_$", "",.) %>% 
           gsub("_de_|_d_", "_", .))


# chargement de la table de passage entre code sinoe et siret epci --------
load("X:/SCTE/DOES/IT/extdata/table_passage_siret_code_sinoe.RData") # constitué par un autre export SINOE

epci_tonnage_incomplet <- table_passage_siret_code_sinoe %>% 
  rowwise %>% filter(length(EPCI_gr)>1) %>% 
  pull(EPCI_gr) %>% 
  unlist %>% 
  unique

acteur_incomplet <- table_passage_siret_code_sinoe %>% 
  rowwise %>% filter(length(EPCI_gr)>1) %>% 
  pull(maitre_d_ouvrage_code_acteur) %>% 
  unique


# chargement des résultats de l'enquête collecte -----
enq_collecte_full_0 <- readxl::read_xls(path = "X:/SCTE/DOES/IT/extdata/Sinoe_collecte_intercom_2017_Fce.xls",
                                        sheet = 1,
                                        range = "A5:ES1755",
                                        col_names = enq_collecte_full_noms0$noms) 


# tonnages --------
enq_collecte_full_1a <- enq_collecte_full_0 %>% 
  mutate(siren = substr(siret, 1, 9) %>% as.character,
         code_sinoe = as.character(code_sinoe)) %>% 
  # on filtre sur la région et sur les tonnages collectés non nuls pour éliminer les lignes à NA ou nulles
  filter(nom_la_region == "Pays de la Loire", coll_et_decheteries_hs_grav0tonnage_total_collecte_hors_gravats != 0) %>% 
  select(-en_savoir_plus, -nom_court, -sigle, -code_type_acteur, -c(libelle_du_titre:bureau_distributeur), 
         -c(libelle_la_commune:geolocalisation_niveau_precision), -siret, -contains("_adherente_desservie"), 
         -contains("gravats"), -contains("dominant"), -contains("compost_")) %>% 
  left_join(table_passage_siret_code_sinoe %>% select(-siren), by = c("code_sinoe" = "maitre_d_ouvrage_code_acteur")) %>% 
  # on ne garde que les EPCI aux données complètes
  filter(!(siren %in% epci_tonnage_incomplet), !(code_sinoe %in% acteur_incomplet)) %>% 
  # on passe les tonnages au format long
  pivot_longer(cols = c(contains("omr0"), contains("encombrants0"), contains("ddangereux0"), contains("pap_embal0"), 
                        contains("biodech0"), contains("verre0"), contains("gravats_sep0"), contains("coll_sep_hs_grav0"), 
                        contains("decheteries0"), contains("coll_et_decheteries_hs_grav0")),
               names_to = "variable",
               values_to = "valeur") %>% 
  separate(col = variable, into = c("filiere", "variable"), sep = "0") %>% 
  mutate(variable = case_when(
    variable %in% c("valorisation_matiere", "tonnage_destine_a_valorisation_matiere") ~ "t_dest_valo_mat",
    variable %in% c("valorisation_organique", "tonnage_destine_a_valorisation_organique") ~ "t_dest_valo_org",   
    variable %in% c("incineration", "tonnage_destine_a_incineration") ~ "t_dest_incinieration",
    variable %in% c("stockage", "tonnage_destine_a_stockage") ~ "t_dest_stockage",
    variable %in% c("autre", "tonnage_destine_a_autre") ~ "t_dest_autres",
    TRUE ~ variable),
    filiere = gsub("coll_et_decheteries_hs_grav", "dma", filiere))


# liste des variables / filières après renommage -----
var_enq_coll <- select(enq_collecte_full_1a, filiere, variable) %>% 
  unique

enq_collecte_full_1 <- enq_collecte_full_1a%>% 
  unnest(EPCI_gr) %>% 
  select(annee, EPCI = EPCI_gr, nom, filiere, variable, valeur) %>% 
  # on regroupe les données par EPCI 
  group_by(annee, EPCI, filiere) %>% 
  pivot_wider(names_from = variable, values_from = valeur, values_fill = 0) %>% 
  summarise(nom = first(nom),
            across(c(contains("population"), contains("t_dest_"), contains("tonnage_"), contains("frequentation"), 
                     contains("nombre")), ~ sum(., na.rm = TRUE)),
            ratio_collecte = if_else(sum(population_desservie, na.rm = TRUE) == 0, 0,
                                     1000 * sum(tonnage_collecte, na.rm = TRUE) / sum(population_desservie, na.rm = TRUE)),
            .groups = "drop") %>% 
  pivot_longer(cols = -c(annee, EPCI, filiere, nom), names_to = "variable", values_to = "valeur") %>% 
  # on enlève les variables spécifiques des déchèteries des autres filières
  filter(paste0(filiere, variable) %in% paste0(var_enq_coll$filiere, var_enq_coll$variable))


# totaux filiere decheterie ----------
tonnes_decheteries_dma <- enq_collecte_full_1 %>% 
  filter((filiere == "decheteries" & grepl("tonnage_", variable)) | 
           (filiere == "dma" & grepl("t_dest_", variable))) %>% 
  group_by(annee, EPCI, filiere) %>% 
  summarise(nom=first(nom), variable = "tonnage_collecte", 
            valeur = sum(valeur, na.rm = TRUE), .groups = "drop")


# synthese filiere OMA -----
tonnes_oma <- enq_collecte_full_1 %>% 
  filter(filiere %in% c("omr", "verre", "pap_embal", "biodech") & grepl("tonnage_|dest", variable)) %>% 
  pivot_wider(names_from = variable, values_from = valeur) %>% 
  group_by(annee, EPCI) %>% 
  summarise(nom=first(nom), filiere = "oma", across(where(is.numeric), sum), .groups = "drop")%>% 
  pivot_longer(cols = starts_with("t"), names_to = "variable", values_to = "valeur")

ratio_oma <- enq_collecte_full_1 %>% 
  filter(filiere %in% c("omr", "verre", "pap_embal", "biodech") & grepl("tonnage_|pop", variable)) %>% 
  group_by(annee, EPCI) %>% 
  pivot_wider(names_from = variable, values_from = valeur) %>% 
  filter(population_desservie != 0) %>% 
  summarise(nom=first(nom), variable = "ratio_collecte", filiere = "oma",
            valeur = sum(tonnage_collecte/population_desservie*1000, na.rm = TRUE), .groups = "drop") 

enq_collecte_full_2 <- enq_collecte_full_1 %>% 
  bind_rows(tonnes_decheteries_dma, tonnes_oma, ratio_oma) %>% 
  mutate(across(where(is.character), as.factor))

# indicateur filiere decheterie --------
ratio_decheteries <- enq_collecte_full_2 %>% 
  filter(filiere == "decheteries" & grepl("tonnage_|pop", variable)) %>%
  group_by(annee, EPCI, filiere) %>% 
  pivot_wider(names_from = variable, values_from = valeur) %>% 
  filter(population_desservie != 0) %>% 
  summarise(nom=first(nom), variable = "ratio_collecte",
            valeur = sum(tonnage_collecte/population_desservie*1000, na.rm = TRUE), .groups = "drop")

enq_collecte_full_3 <- enq_collecte_full_2 %>% 
  bind_rows(ratio_decheteries)


# indicateur filiere DMA ---------
ratio_dma <- enq_collecte_full_3 %>% 
  filter(filiere != "oma" & grepl("ratio_", variable)) %>% 
  group_by(annee, EPCI) %>% 
  summarise(nom=first(nom), variable = "ratio_collecte", filiere = "dma",
            valeur = sum(valeur, na.rm = TRUE), .groups = "drop")

enq_collecte_full_4 <- enq_collecte_full_3 %>% 
  bind_rows(ratio_dma)


# indicateur de valorisation par filière ---------
indic_valor <- enq_collecte_full_4 %>% 
  filter(variable == "tonnage_collecte" | grepl("dest", variable)) %>% 
  pivot_wider(names_from = variable, values_from = valeur) %>% 
  group_by(annee, EPCI, filiere) %>% 
  mutate(taux_valo_mat = if_else(tonnage_collecte == 0, 0, t_dest_valo_mat/tonnage_collecte)*100,
         taux_valo_org = if_else(tonnage_collecte == 0, 0, t_dest_valo_org/tonnage_collecte)*100,
         taux_tri = taux_valo_mat + taux_valo_org) %>% 
  select(-starts_with("t_"), -starts_with("tonnage")) %>% 
  pivot_longer(cols = starts_with("taux"), names_to = "variable", values_to = "valeur")

enq_collecte_full_5 <- enq_collecte_full_4 %>% 
  bind_rows(indic_valor)


# avant de passer au format poc IT, travail sur le libellé des 116 variables---------
lib_var <- enq_collecte_full_5 %>% 
  select(filiere, variable) %>% 
  arrange(filiere, variable) %>% 
  distinct %>% 
  mutate(
    variable_def = paste0(filiere, ".", variable),
    lib_filiere = case_when(
      # amorce : unique(lib_var$filiere) %>% paste0("filiere == ", ., " ~   ,", collapse =" ")
      filiere == "omr" ~  "la collecte des ordures ménagères résiduelles" , 
      filiere == "encombrants" ~  "la collecte séparative des encombrants", 
      filiere == "ddangereux" ~   "la collecte séparative des déchets dangereux", 
      filiere == "pap_embal" ~ "la collecte séparatives des papiers et emballages" , 
      filiere == "biodech" ~   "la collecte séparative des biodéchets", 
      filiere == "verre" ~   "la collecte séparative du verre", 
      filiere == "coll_sep_hs_grav" ~  "la collecte séparative des autres déchets" , 
      filiere == "decheteries" ~ "les déchèteries"  , 
      filiere == "dma" ~  "la collecte des déchets ménagers et assimilés", 
      filiere == "oma" ~  "la collecte des ordures ménagères et assimilées" ,
      TRUE ~ NA_character_),
    # amorce : unique(lib_var$variable) %>% paste0("variable == ", ., " ~   ,", collapse ="\n")
    lib_var = case_when(
      variable == "population_desservie" ~ "nombre d'habitants desservis par "  ,
      variable == "ratio_collecte" ~ "performance de " ,
      variable == "tonnage_collecte" ~ "tonnes de déchets collectés par ",
      variable == "t_dest_valo_mat" ~  "tonnes de déchets recyclés, provenant de " ,
      variable == "t_dest_valo_org" ~   "tonnes de déchets valorisés organiquement, provenant de " ,
      variable == "t_dest_incinieration" ~ "tonnes de déchets incinérés, provenant de ",
      variable == "t_dest_stockage" ~ "tonnes de déchets enfouis, provenant de " ,
      variable == "t_dest_autres" ~  "tonnes de déchets traités autrement, provenant de ",
      variable == "nombre_decheteries" ~ "nombre de déchèteries du territoire"  ,
      variable == "frequentation_totale_nombre_visites" ~ "fréquentation annuelle des déchèteries"  ,
      variable == "tonnage_dechets_dangereux" ~ "tonnes de déchets dangereux collectés en ",
      variable == "tonnage_materiaux_recyclables" ~ "tonnes de materiaux recyclables collectés en "  ,
      variable == "tonnage_dechets_verts" ~  "tonnes de déchets verts collectés en " ,
      variable == "tonnage_encombrants" ~  "tonnes de déchets encombrants collectés en "  ,
      variable == "tonnage_deee" ~ "tonnes de déchets d'équipements électriques ou électroniques collectés en ",
      variable == "tonnage_autres_dechets" ~ "tonnes d'autres types de déchets collectés en ",
      variable == "taux_valo_mat" ~  "taux de valorisation matière de ",
      variable == "taux_valo_org" ~  "taux de valorisation organique de " ,
      variable == "taux_tri" ~ "taux de valorisation matière et organique de ",
      TRUE ~ NA_character_),
    libelle = case_when(
      filiere == "decheteries" & variable == "ratio_collecte" ~ "performance de collecte des déchèteries", 
      filiere == "decheteries" & variable %in% c("nombre_decheteries", "frequentation_totale_nombre_visites") ~ lib_var, 
      filiere == "decheteries" & variable == "population_desservie" ~ "nombres d'habitants ayant accès aux déchèteries", 
      #pas de service de collecte à proprement parler pour les agrégats oma et dma
      filiere %in% c("oma", "omr") & grepl("_dest", variable) ~ paste0("tonnes d'", toupper(filiere), gsub("tonnes de déchets|, provenant de ", "", lib_var) %>% 
                                                                         gsub("és", "ées",.) %>% gsub("enfouis", "enfouies", .)), 
      filiere == "dma" & grepl("_dest", variable) ~ paste0("tonnes de DMA ", gsub("tonnes de déchets |, provenant de ", "", lib_var) %>% 
                                                             gsub("és", "ées",.) %>% gsub("enfouis", "enfouies", .)),
      filiere == "dma" & variable == "tonnage_collecte"~ "tonnes de DMA collectés",
      filiere %in% c("oma", "omr") & variable == "tonnage_collecte"~ paste0("tonnes d'", toupper(filiere), " collectées"),
      filiere %in% c("oma", "omr", "dma") & grepl("taux_", variable) ~ paste0(gsub(" de $", " des ", lib_var), toupper(filiere)),
      TRUE ~ paste0(lib_var, lib_filiere) %>% 
        gsub(" de les ", " des ", .) %>% 
        gsub(" en les ", " en ", .))
    )

write_csv2(select(lib_var, variable_def, libelle), file = "metadata/liv_var_enq_coll.csv")


# passage au format poc, ajout des EPCI manquants --------
# (certains à NA, les interrégionaux à partir de SINOE pour certaines variables)

# ajout Alençon (Redon n'est pas complétement disponible )
alencon <- read_csv2(file = "X:/SCTE/DOES/IT/extdata/saisie_Alencon.csv", col_names = TRUE, col_types = 'ncccn')

enq_collecte_full_6 <- enq_collecte_full_5 %>%
  mutate(variable = paste0(filiere, ".", variable)) %>% 
  select(-filiere) %>% 
  bind_rows(alencon) %>% 
  full_join(
    filter(communes, grepl("52", REGIONS_DE_L_EPCI)) %>% 
      select(EPCI, Zone = NOM_EPCI) %>% 
      distinct())

epci_vides <- filter(enq_collecte_full_6, is.na(annee)) %>% 
  select(EPCI, Zone) %>% 
  mutate(annee = 2017) %>% 
  left_join(alencon %>% select(annee, variable) %>% mutate(valeur = NA_integer_))

enq_collecte_full_7 <- filter(enq_collecte_full_6, !is.na(annee)) %>%
  bind_rows(epci_vides) %>% 
  mutate(date = make_date(annee, 12, 31), TypeZone = "Epci") %>% 
  select(TypeZone, Zone, CodeZone = EPCI, date, variable, valeur) %>% 
  mutate(across(where(is.character), as.factor),
         across(where(is.factor), fct_drop)) %>% 
  pivot_wider(names_from = variable,values_from = valeur)


# versement enquête collecte dans le sgbd/datamart.portrait_territoires -------------

rm(list = setdiff(ls(), c("enq_collecte_full_7",
                          "enq_collecte_full_0",
                          "acteur_incomplet",
                          "table_passage_siret_code_sinoe",
                          "epci_tonnage_incomplet")))

poster_data(data = enq_collecte_full_7 %>% rename_with(tolower), table = "cogifiee_enq_collecte_ademe", schema = "portrait_territoires",
            db = "datamart", post_row_name = FALSE, pk = c("typezone", "codezone", "date"), overwrite = TRUE)

# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(enq_collecte_full_7), c("TypeZone", "Zone", "CodeZone", "date")) 

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "codezone", "Code géo de la zone",
      "zone", "Libellé de la zone",
      "typezone", "Type de zone geo",
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
#### Enquête collecte
post_dico_attr(dico = metadata_indicateur %>% filter(!grepl("^compost_", variable)), 
               table = "cogifiee_enq_collecte_ademe", schema = "portrait_territoires",
               db = "datamart", user = "does")

#### Enquête compost
post_dico_attr(dico = metadata_indicateur %>% filter(grepl("^compost_", variable) | variable %in% c("codezone", "zone", "typezone", "date")), 
               table = "cogifiee_enq_compost_ademe", schema = "portrait_territoires",
               db = "datamart", user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table) %>% 
  # ajout de complement sur la généalogie
  paste0(".\n", "T\u00e9l\u00e9chargement depuis SINOE https://www.sinoe.org/thematiques/consult/ss-theme/3")

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "cogifiee_enq_collecte_ademe", 
                user = "does")

rm(list=ls())
