# chargement_enq_collecte_ademe - Volet politique compostage

# librairies --------
library(dplyr)
library(tidyr)
library(tibble)
library(forcats)
library(stringr)
library(readr)
library(purrr)
library(COGiter)
library(tricky)
library(lubridate)
library(datalibaba)
library(googlesheets4)


rm(list=ls())


# on récupère les données de l'enquête collecte via SINOE--------
# Export SINOE - avec codes identification 'DREAL52'
# https://www.sinoe.org/thematiques/consult/ss-theme/3
# choisir la requête 'EPCI et communes exerçant au moins une compétence déchet'
# filtrer sur l'année de la dernière enquête collecte par 'Filtre Année(s) / Situation' 
# filtrer sur les 3 compétences collecte (type indifférent) - on écarte la compétence traitement
# exporter le résultats de la recherche excel ou csv
# cocher 'Indicateurs des collectes d'ordures ménagères résiduelles, collectes sélectives et déchèteries (tonnage, pop desservie, destination)'
# cocher 'données complémentaires annuelles'
# Cocher 'Gestion de proximité des biodéchets : compostage individuel, partagé, en pied d'immeuble' 
# prévisualiser et exporter


# passage des entêtes de colonnes sur une seule ligne ------
enq_collecte_full_noms0 <- readxl::read_xls(path = "X:/SCTE/DOES/IT/extdata/Sinoe_collecte_intercom_2017_Fce.xls",
                                            sheet = 1, 
                                            range = "A1:ES4",
                                            col_names = FALSE) %>% 
  t(.) %>% 
  as_tibble %>% 
  rownames_to_column("id_row") %>% 
  mutate(id_row = as.numeric(id_row),
         noms = case_when(id_row <= 33 ~ V2,
                          id_row < 44 ~ paste0("omr0", V3),
                          id_row < 54 ~ paste0("encombrants0", V3),
                          id_row < 64 ~ paste0("ddangereux0", V3),
                          id_row < 74 ~ paste0("pap_embal0", V3),
                          id_row < 84 ~ paste0("biodech0", V3),
                          id_row < 94 ~ paste0("verre0", V3),
                          id_row < 104 ~ paste0("gravats_sep0", V3),
                          id_row < 114 ~ paste0("coll_sep_hs_grav0", V3),
                          id_row < 132 ~ paste0("decheteries0", V3),
                          id_row < 138 ~ paste0("coll_et_decheteries_hs_grav0", V3),
                          id_row < 145 ~ paste0("compost_ind0", V4),
                          id_row >= 145 ~ paste0("compost_coll0", V4),
                          TRUE ~ "a revoir") %>% 
           str_standardize("") %>% 
           gsub("_$", "",.) %>% 
           gsub("_de_|_d_", "_", .))


# chargement de la table de passage entre code sinoe et siret epci --------
load("X:/SCTE/DOES/IT/extdata/table_passage_siret_code_sinoe.RData") # constitué par un autre export SINOE

epci_tonnage_incomplet <- table_passage_siret_code_sinoe %>%
  rowwise %>% filter(length(EPCI_gr)>1) %>%
  pull(EPCI_gr) %>%
  unlist %>%
  unique

acteur_incomplet <- table_passage_siret_code_sinoe %>% 
  rowwise %>% filter(length(EPCI_gr)>1) %>% 
  pull(maitre_d_ouvrage_code_acteur) %>% 
  unique


# chargement des résultats de l'enquête collecte -----
enq_collecte_full_0 <- readxl::read_xls(path = "X:/SCTE/DOES/IT/extdata/Sinoe_collecte_intercom_2017_Fce.xls",
                                        sheet = 1,
                                        range = "A5:ES1755",
                                        col_names = enq_collecte_full_noms0$noms) 


# compostage -------------
ope_compost <- enq_collecte_full_0 %>% 
  mutate(siren = substr(siret, 1, 9) %>% as.character,
         code_sinoe = as.character(code_sinoe)) %>% 
  select(siren, code_sinoe, nom, contains("compost_"), -compost_ind0nombre_habitants_concernes, 
         -compost_ind0methode_comptage_estimation_enquete, -compost_coll0methode_comptage_pesees_estimation_enquete,
         -compost_ind0nombre_personnes_sensibilisees_au_compostage_dans_l_annee) %>% 
  filter(!is.na(compost_ind0existence_operations_compostage_domestique)) %>% 
  mutate(across(contains("existence"), ~ tolower(.) == "oui" )) %>% 
  pivot_longer(cols = c(-code_sinoe, -nom, -siren), names_to = "variable", values_to = "valeur") %>% 
  mutate(variable = gsub("0", ".", variable), 
         date = make_date(2017, 12, 31)) %>% 
  left_join(table_passage_siret_code_sinoe %>% select(-siren), by = c("code_sinoe" = "maitre_d_ouvrage_code_acteur")) %>% 
  # on ne garde que les EPCI aux données complètes
  filter(!(siren %in% epci_tonnage_incomplet), !(code_sinoe %in% acteur_incomplet)) %>% 
  unnest(EPCI_gr) %>% 
  select(date, EPCI = EPCI_gr, variable, valeur) %>% 
  full_join(
    filter(communes, grepl("52", REGIONS_DE_L_EPCI)) %>% 
      select(EPCI, Zone = NOM_EPCI) %>% 
      distinct())

epci_vides <- filter(ope_compost, is.na(date)) %>% 
  mutate(date = make_date(2017, 12, 31)) %>% 
  select(EPCI, Zone, date) %>% 
  distinct() %>% 
  left_join(select(ope_compost, variable, date) %>% distinct %>% filter(!is.na(date))) 

ope_compost1 <- filter(ope_compost, !is.na(date)) %>%
  bind_rows(epci_vides) %>% 
  group_by(date, EPCI, Zone, variable) %>% 
  pivot_wider(names_from = variable, values_from = valeur, values_fn = list) %>% 
  unnest(cols = contains("compost")) %>% 
  summarise(
    across(contains("existence"), ~ first(sort(.x, decreasing = TRUE))), 
    across(contains("nombre"),  ~ sum(.x, na.rm =TRUE)),
    across(contains("annee"),  ~ first(sort(.x))), .groups = "drop") %>% 
  pivot_longer(cols = contains("compost"), names_to = "variable", values_to = "valeur") %>% 
  mutate(TypeZone = "Epci") %>% 
  rename(CodeZone = EPCI) %>% 
  mutate(across(where(is.character), as.factor),
         across(where(is.factor), fct_drop)) %>% 
  pivot_wider(names_from = variable,values_from = valeur) %>% 
  rename(compost_coll.existence_ope_compost_immeuble_ou_quartier = compost_coll.existence_operations_compostage_en_pied_immeuble_ou_quartier, 
         compost_coll.nb_hab_ayant_acces_aux_sites_compostage = compost_coll.nombre_habitants_desservis_ayant_acces_aux_sites_compostage)



# versement compost dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = ope_compost1, table = "cogifiee_enq_compost_ademe", schema = "portrait_territoires",
            db = "datamart", post_row_name = FALSE, pk = c("TypeZone", "CodeZone", "date"), overwrite = TRUE)



# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(c(names(ope_compost1)), c("TypeZone", "Zone", "CodeZone", "date")) 

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "codezone", "Code géo de la zone",
      "zone", "Libellé de la zone",
      "typezone", "Type de zone geo",
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
#### Enquête compost
post_dico_attr(dico = metadata_indicateur %>% filter(grepl("^compost_", variable) | variable %in% c("codezone", "zone", "typezone", "date")), 
               table = "cogifiee_enq_compost_ademe", schema = "portrait_territoires",
               db = "datamart", user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table) %>% 
  # ajout de complement sur la généalogie
  paste0(".\n", "T\u00e9l\u00e9chargement depuis SINOE https://www.sinoe.org/thematiques/consult/ss-theme/3")

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "cogifiee_enq_compost_ademe", 
                user = "does")



rm(list=ls())
