
# chargement_etat_ecologique_cours_eau

library(magrittr)

rm(list = ls())


# chargement des données de l'Agence de l'eau Loire-Bretagne -------

# le fichier Etat_Ecologique_cours_d_eau_2017_RESUME.xlsx a été récupéré sur le site de l'agence de l'eau Loire-Bretagne : 
# https://donnees-documents.eau-loire-bretagne.fr/home/donnees/etat-2017-cours-deau.html
# https://donnees-documents.eau-loire-bretagne.fr/files/live/mounts/midas/Donnees-et-documents/Etat_Ecologique_cours_d_.92166786379235
# un 2e onglet a été créé, ne conservant que les données utiles et renommant les champs
# état écologique des masses d’eau superficielles, hors masse d'eau de transition et plans d'eau !
# état calculé avec les données 2015 à 2017

# utils::download.file(
#   url = "https://donnees-documents.eau-loire-bretagne.fr/files/live/mounts/midas/Donnees-et-documents/Etat_Ecologique_cours_d_.92166786379235",
#   destfile = "extdata/Etat_Ecologique_cours_d_eau_2017_RESUME.xlsx"
#   )
# attention, le fichier téléchargé par cette commande peut être corrompu et ne pas être lisible

# etat_ecolo_cours_eau_2017 <- readxl::read_excel(
#   path = "extdata/Etat_Ecologique_cours_d_eau_2017_RESUME.xlsx",
#   sheet="Etat Cours d'eau",
#   skip = 5,
#   col_names = TRUE
#   ) %>%
#   dplyr::select(
#     code_masse_eau = `code de la masse d'eau`,
#     nom_masse_eau = `Nom de la masse d'eau`,
#     cours_d_eau = `Cours d'eau`,
#     type_masse_d_eau = `Type de la masse d'eau`,
#     type_FR_masse_d_eau = `Type_FR de la masse d'eau`,
#     commision_territoriale = `commision territoriale`,
#     SAGE,
#     region_principale = `Region principale`,
#     regions_concernees = `Région(s) concernée(s)`,
#     departement_principal = `Département principal`,
#     departements_concernes = `Département(s) concerné(s)`,
#     etat_ecologique_valide = `État Écologique validé`,
#     niveau_de_confiance_valide = `Niveau de confiance validé`,
#     etat_ecologique_calcule = `État Écologique calculé`,
#     etat_biologique = `État Biologique`,
#     etat_physico_chimie_generale = `État physico-chimie générale`,
#     etat_polluants_specifiques = `État Polluants spécifiques`,
#     code_station_retenue_biologie_physico_chimie = `Station retenue...37`,
#     libelle_station_biologie_physico_chimie = Libellé...38,
#     code_station_retenue_polluants_specifiques = `Station retenue...39`,
#     libelle_station_retenue_polluants_specifiques = Libellé...40
#     )


# Au 15/05/2023 : le fichier Etat_Ecologique_technique_cours_d_eau_2020_RESUME.xls est téléchargeable 
# à partir de la page https://donnees-documents.eau-loire-bretagne.fr/home/donnees/etat-eco-technique-2020-cours-deau.html en .xls ou .pdf
# La page de téléchargement précise que "Cet état 2020 n’est pas concerté avec les partenaires et il n’est pas validé par le comité de bassin.
# Il est conçu comme un état « technique intermédiaire ».
# Le prochain état validé par le comité de bassin reposera sur la chronique de données 2021-2022-2023 et sera réalisé pour l’état des lieux 2025."
# url du fichier .xls est la suivante : https://donnees-documents.eau-loire-bretagne.fr/files/live/mounts/midas/Donnees-et-documents/Etat_Ecologique_cours_d_.1681377408597

# utils::download.file(
#   url = " https://donnees-documents.eau-loire-bretagne.fr/files/live/mounts/midas/Donnees-et-documents/Etat_Ecologique_cours_d_.1681377408597",
#   destfile = "extdata/Etat_Ecologique_cours_d_eau_2020_RESUME.xlsx"
#   )
# La commande génère un message d'erreur, donc téléchargement à la main dans le répertoire exdata/ du projet sgbd_datamart.

etat_ecolo_cours_eau_2020 <- openxlsx::read.xlsx(
  xlsxFile = "extdata/Etat_Ecologique_technique_cours_d_eau_2020_RESUME .xlsx", 
  sheet = "Etat Cours d'eau",
  startRow = 6,
  colNames = TRUE
  ) %>% 
  dplyr::select(
    code_masse_eau = `code.de.la.masse.d'eau`,
    etat_ecologique_technique = `État.Écologique.technique`
    )


# chargement des bassins versants géographiques --------------
n_bassin_versant_specifique_loire_bretagne <- datalibaba::importer_data(
  db = "si_eau",
  schema = "sandre",
  table = "n_bassin_versant_specifique_loire_bretagne",
  user = "does"
  )
# mapview::mapview(n_bassin_versant_specifique_loire_bretagne)


# association de l'état écologique et de la géométrie --------

# etat_ecolo_cours_eau_2017_geo <- dplyr::left_join(
#   n_masse_eau_bassin_versant_loire_bretagne %>%
#     dplyr::select(code_masse_eau = cd_eu_masse_eau),
#   etat_ecolo_cours_eau_2017 %>%
#     dplyr::select(code_masse_eau, etat_ecologique_valide)
#   )
# # mapview::mapview(etat_ecolo_cours_eau_2017_geo)

etat_ecolo_cours_eau_2020_geo <- dplyr::left_join(
  n_bassin_versant_specifique_loire_bretagne %>% 
    dplyr::select(code_masse_eau = code_bassin_versant_specifique),
  etat_ecolo_cours_eau_2020
  )


# limites administratives des communes ----------

# chargement de la liste des depcom COGiter région PDL et région PDL + epci
source("R/levels_facteurs_com.R")

commune <- COGiter::communes_metro_geo %>% 
  dplyr::filter(DEPCOM %in% com_reg_et_vois) %>% 
  dplyr::rename(code_insee = DEPCOM)


# carte ------
# mapview::mapview(
#   etat_ecolo_cours_eau_2020_geo,
#   color = "blue", col.regions = "blue", alpha.regions = 0.5,
#   legend = T, layer.name = "masse_eau"
# ) +
#   mapview::mapview(
#     commune,
#     color = "red", col.regions = "red", alpha.regions = 0.5,
#     legend = T, layer.name = "communes"
#   )
# la pointe nord-ouest de la Mayenne n'est pas couverte par les masses d'eau de Loire Bretagne 


# intersection des bassins versants de masse d'eau et des communes -------------
etat_ecolo_cours_eau_2020_com <- sf::st_intersection(
  sf::st_buffer(etat_ecolo_cours_eau_2020_geo, 0),
  sf::st_buffer(commune, 0)
  ) %>%
  dplyr::mutate(surf_me_com = sf::st_area(the_geom)) %>% 
  sf::st_drop_geometry()
etat_ecolo_cours_eau_2020_com$surf_me_com <- units::drop_units(etat_ecolo_cours_eau_2020_com$surf_me_com)


# calcul des surfaces en bon état écologique -----
# 1 :très bon ; 2 : bon ; 3 : moyen ; 4 : médiocre ; 5 : mauvais

source_etat_ecolo_cours_eau <- etat_ecolo_cours_eau_2020_com %>% 
  dplyr::mutate(etat_ecologique_technique = ifelse(is.na(etat_ecologique_technique), 99, etat_ecologique_technique)) %>% 
  dplyr::group_by(code_insee) %>%
  dplyr::mutate(surface_bon_etat_masse_eau = ifelse(etat_ecologique_technique < 3, surf_me_com, 0)) %>% 
  dplyr::summarise(
    surface_bon_etat_masse_eau = sum(surface_bon_etat_masse_eau), 
    surface_terr = max(AREA)
    ) %>%
  dplyr::ungroup() %>% 
  dplyr::mutate(date = as.Date("2020-12-31")) %>% 
  dplyr::select(depcom = code_insee, date, surface_bon_etat_masse_eau, surface_terr)


# versement dans le sgbd/datamart.portrait_territoires et metadonnées -------------
source("R/poster_documenter_data.R", encoding = "UTF-8")
poster_documenter_it(df = source_etat_ecolo_cours_eau ,
                     nom_table_sgbd = "source_etat_ecologique_cours_eau", 
                     comm_source_en_plus = "")
