## Indicateur CRTE : Nombre d'artisans et d'entreprises certifiées RGE sur le territoire -- Script à faire tourner sur le SSP cloud 
onyxia <- FALSE # un paramètre pour ne faire tourner que ce qui peut tourner sur un PC

# Chargement des packages ----------
library(tidyverse)
# remotes::install_github("maeltheuliere/COGiter")
library(COGiter)
library(lubridate)
library(httr)
library(RPostgreSQL)
library(dbplyr)
# remotes::install_gitlab("dreal-datalab/datalibaba")
library(datalibaba)
library(googlesheets4)

# Récupération des millesimes précédents
indic_rge_old <- importer_data(table = "source_ets_rge_ademe", schema = "portrait_territoires", db = "datamart")
save(indic_rge_old, file = paste0("extdata/indic_rge_old_", Sys.Date(),".RData"))

# Lecture des données opendata ademe  --------
## https://data.ademe.fr/datasets/liste-des-entreprises-rge

date <- Sys.Date() %>% format("%Y%m%d")
r <- GET("https://koumoul.com/s/data-fair/api/v1/datasets/liste-des-entreprises-rge/full")
rge <- content(r)

date_maj <- r$headers$`last-modified` %>% 
  gsub(pattern = " GMT$", replacement = "", .) %>% 
  parse_date_time('%a, %d %b %Y %H:%M:%S', locale="English_UK") %>% 
  as_date() 


## Typologie des travaux ------
# on exporte les domaines de travaux en vue de les regrouper manuellement en créant une nomenclature plus synthétique
# select(rge, DOMAINE_TRAVAUX) %>% distinct() %>% 
#   write.csv2(typo_tvx, file = "extdata/nom_rge.csv", row.names = FALSE)
# import de la nomenclature saisie
typo_tvx <- read.csv2(file = "extdata/nom_rge.csv", fileEncoding = 'UTF-8')

rge1 <- mutate(rge, DOMAINE_TRAVAUX = coalesce(DOMAINE_TRAVAUX, LIBELLE_QUALIFICATION)) %>% 
  left_join(typo_tvx, by = "DOMAINE_TRAVAUX") %>% 
  select(-DOMAINE_TRAVAUX, -LIBELLE_QUALIFICATION, -lib_groupe_domaine) %>% 
  distinct() %>% 
  mutate(DEP = if_else(substring(CODE_POSTAL, 1, 2) == "97", substring(CODE_POSTAL, 1, 3), substring(CODE_POSTAL, 1, 2)))

# Verif que tout s'y trouve
filter(rge1, is.na(groupe_domaine)) %>% nrow() == 0 # TRUE attendu

liste_siret <- select(rge1, SIRET) %>% pull %>% unique() %>% sort()
liste_siret2 <- enframe(liste_siret)


# Téléchargement bases sirenes completes - à ne lancer que sur Onyxia ---------------------
if(onyxia) {
  # On utilise les données SIRENE pour localiser les établissements (adresse plus récente) et obtenir le type d'établissement
  ## Fichier des etablissements
  download.file(url = "https://files.data.gouv.fr/insee-sirene/StockEtablissement_utf8.zip",
                destfile = "extdata/sirene_ets.zip", method = "curl")
  unzip("extdata/sirene_ets.zip", exdir = "extdata/", list = FALSE)
  source(file = "R/unzip_big_file.R")
  decompress_file(directory = "extdata", file = "sirene_ets.zip", .file_cache = FALSE)
  base_sirene_complete_ets <- data.table::fread(file = "extdata/StockEtablissement_utf8.csv", fill=TRUE)    
  
  con <- dbConnect(drv = dbDriver("PostgreSQL"), dbname="defaultdb", host="postgresql-721403", port=5432, 
                   user = "user-juliette", password = "mcu5r694lx0b6b1tzgm8")
  dbWriteTable(conn = con, name = "sirene_ets", value = base_sirene_complete_ets)
  
  ## Fichier des entreprises (pour avoir la typologie des unités légales)
  download.file(url = "https://files.data.gouv.fr/insee-sirene/StockUniteLegale_utf8.zip",
                destfile = "extdata/sirene_ul.zip", method = "curl")
  unzip("extdata/sirene_ul.zip", exdir = "extdata/", list = FALSE)
  base_sirene_ul <- data.table::fread(file = "extdata/StockUniteLegale_utf8.csv", fill=TRUE)    
  
  dbWriteTable(conn = con, name = "sirene_ul", value = base_sirene_ul)
  
  # Extraction des seules données utiles -------------------
  siret_com <- base_sirene_complete_ets %>% 
    filter(as.character(siret) %in% liste_siret) %>% 
    select(siret, depcom = codeCommuneEtablissement, 
           etat_act = etatAdministratifEtablissement,
           # cat_entreprise = etablissement.unite_legale.categorie_entreprise, 
           employ = caractereEmployeurEtablissement, 
           tr_effect = trancheEffectifsEtablissement, 
           annee_effect = anneeEffectifsEtablissement)
  
  save(siret_com, file = "extdata/siret_com.RData") # a exporter ensuite
  
  siret_com2 <- siret_com %>% 
    mutate(siret_rech = as.character(siret)) %>% 
    full_join(select(liste_siret2, value), by = c("siret_rech" = "value")) %>% 
    mutate(etat_act = factor(etat_act, levels = c("A", "F"), labels = c("Actif", "Fermé")),
           tr_effect = factor(tr_effect, levels = c('NN', '0', '1', '2', '3', '11', '12', '21', '22', '31', '32', '41', 
                                                    '42', '51', '52', '53'),
                              labels = c('0 salarié', '0 salarié', '1 ou 2 salariés', '3 à 5 salariés', '6 à 9 salariés', 
                                         '10 à 19 salariés', '20 à 49 salariés', '50 à 99 salariés', '100 à 199 salariés', 
                                         '200 à 249 salariés', '250 à 499 salariés', '500 à 999 salariés', '1 000 à 1 999 salariés', 
                                         '2 000 à 4 999 salariés', '5 000 à 9 999 salariés', '10 000 salariés et plus')
           )) %>% 
    filter(is.na(etat_act) | etat_act == "Actif") %>% 
    mutate(siren = substring(siret, 1, 9)) %>% 
    left_join(base_sirene_ul %>% select(siren, categorieEntreprise) %>% mutate(siren = as.character(siren)), by="siren")
  
  rm(base_sirene_complete_ets)
  rm(base_sirene_ul)
  save(siret_com2, file = "extdata/siret_com2.RData") # a exporter ensuite
} else {
  load("extdata/siret_com.RData")
  load("extdata/siret_com2.RData")
}


# Compléments d'affectation communale ---------------
# certains sirets sont fantaisistes, ou correspondent à des données non diffusibles, on redresse avec code postal
a_redresser <-  select(rge1, SIRET, CODE_POSTAL, VILLE, DEP) %>% 
  distinct() %>% 
  left_join(siret_com2, by = c("SIRET" = "siret_rech")) %>% 
  mutate(depcom = na_if(depcom, "")) %>% 
  filter(is.na(depcom)) 


## chargement des codes postaux-----------
load("extdata/cod_post_yc_cedex.RData")
CP <- select(cod_post_yc_cedex,  Code_postal, DEPCOM, nom_com, starts_with("nb_"), dep_ref_CP) %>% 
  distinct()

## Rattachement des ets dont le code postal ne correspond qu'à une seule commune
CP_univoques <- filter(CP, nb_com == 1) %>% 
  select(Code_postal, DEPCOM)

rge_cp_ok <- left_join(a_redresser, CP_univoques, by = c("CODE_POSTAL" = "Code_postal")) %>% 
  filter(!is.na(DEPCOM))

## Rattachement des ets dont le code postal et le libelle de la commune s'apparient correctement avec la base des codes postaux
rge_adresse_ok <- a_redresser %>% 
  anti_join(rge_cp_ok) %>% 
  left_join(select(CP, Code_postal, DEPCOM, nom_com), 
            by = c("CODE_POSTAL" = "Code_postal", "VILLE" = "nom_com")) %>% 
  filter(!is.na(DEPCOM))

## Rattachement d'enregistrements au SIRET déjà apparié précédemment (une nuance dans l'écriture du nom de la commune a fait rater la jointure ci dessous)
rge_adresses_multiples <- bind_rows(rge_cp_ok, rge_adresse_ok) %>% 
  select(SIRET, DEPCOM) %>% 
  distinct() %>% 
  group_by(SIRET) %>% 
  filter(n() == 1) %>% 
  left_join(
    a_redresser %>% 
      anti_join(rge_cp_ok) %>% 
      anti_join(rge_adresse_ok),
    ., by = "SIRET"
  ) %>% 
  filter(!is.na(DEPCOM))

## Le reste à apparier à un code commune ---------
redress_left <- bind_rows(rge_cp_ok, rge_adresse_ok, rge_adresses_multiples) %>% 
  select(SIRET, DEPCOM) %>% 
  anti_join(a_redresser, ., by = "SIRET") %>% 
  select(any_of(names(rge1)))

## Redressements manuels

redress <- redress_left %>% 
  mutate(VILLE = gsub("  ", "", toupper(VILLE)) %>% 
           gsub(" CEDEX", "", .) %>% 
           gsub("Â", "A", .) %>% 
           gsub(" CEDEX ..", "", .) %>% 
           gsub("^ ", "", .) %>% 
           gsub(" [0-9]", "", .) %>% 
           gsub("[0-9] ", "", .) %>% 
           gsub("[0-9]", "", .) %>% 
           gsub("-|'", " ", .) %>% 
           gsub("SAINT ", "ST ",.) %>% 
           gsub("SAINTE", "STE", .) %>% 
           gsub("^CHERBOURG$", "CHERBOURG EN COTENTIN", .) %>% 
           gsub("^PAMIER$", "PAMIERS", .) %>% 
           gsub("^PARIS LA DEFENSE$", "COURBEVOIE", .) %>% 
           gsub("^CHASSENEUIL FUTUROSCOPE$", "CHASSENEUIL DU POITOU", .) %>% 
           gsub("^AMELIE LES BAINS$", "AMELIE LES BAINS PALALDA", .) %>% 
           gsub("^VALANJOU$", "CHEMILLE EN ANJOU", .)) %>% 
  left_join(CP, by=c("DEP" = "dep_ref_CP", "CODE_POSTAL" = "Code_postal", "VILLE" = "nom_com")) 

a_redresser2 <- filter(redress, is.na(DEPCOM)) %>% 
  select(SIRET, CODE_POSTAL, VILLE, DEP) %>% 
  left_join(select(CP, DEPCOM, nom_com, dep_ref_CP) %>% distinct, 
            by=c("DEP" = "dep_ref_CP", "VILLE" = "nom_com")) 

redress2 <- redress %>% 
  filter(!is.na(DEPCOM)) %>% 
  bind_rows(a_redresser2 %>% filter(!is.na(DEPCOM)))

nom_com <- select(CP, DEPCOM, nom_com) %>% distinct %>% 
  add_count(nom_com) %>% 
  filter(n==1) %>% 
  select(-n)

a_redresser3 <- filter(a_redresser2, is.na(DEPCOM)) %>% 
  select(SIRET, CODE_POSTAL, VILLE, DEP) %>% 
  left_join(nom_com, by=c("VILLE" = "nom_com"))

# on rassemble toutes les correspondances SIRET+/DECOM trouvées précédemment
redress3 <- redress2 %>% 
  filter(!is.na(DEPCOM)) %>% 
  bind_rows(a_redresser3 %>% filter(!is.na(DEPCOM))) %>% 
  bind_rows(rge_adresse_ok, rge_adresses_multiples, rge_cp_ok) %>% 
  select(SIRET, DEPCOM) %>% 
  # une seule localisation par siret
  group_by(SIRET) %>% 
  slice(1) %>% 
  ungroup()

# Mise à jour de la table de passage SIRET / DEPCOM --------
siret_com3 <- siret_com2 %>% 
  mutate(depcom = na_if(depcom, "")) %>% 
  left_join(redress3, by = c("siret_rech" = "SIRET")) %>% 
  mutate(depcom = coalesce(depcom, DEPCOM), siret = as.character(siret)) %>% 
  select(-DEPCOM) %>% 
  rename(cat_entreprise = categorieEntreprise)


# Ajout des codes commune aux données ADEME et calcul des indicateurs par commune ---------
# nota : on a de l'info sur la taille de l'ets pour 20% des SIRET, il faudrait passer par l'API Entreprise pour fiabiliser l'indicateir sur cette dimension
# (accès à demander avec l'autorisation du SG)

## Liste des variables :
lib_var0 <- expand.grid(a = c("pme", "eti", "ge", "na"), b = unique(typo_tvx$groupe_domaine)) %>% 
  unite(col = "c", a, b, sep = ".", remove = FALSE) %>% 
  left_join(select(typo_tvx, groupe_domaine, lib_groupe_domaine) %>% distinct,
            by = c("b" = "groupe_domaine"))

lib_var <-  pull(lib_var0, c)

rge2 <- rge1 %>% 
  left_join(siret_com3 , by = c("SIRET" = "siret")) %>% 
  # On garde les ets ouverts, ou dont l'état d'act est inconnu et disposant d'un code commune valide
  filter(is.na(etat_act) | etat_act == "Actif", !is.na(depcom), depcom != "",
         depcom %in% levels(table_passage_com_historique$DEPCOM_HIST)) %>% 
  mutate(cat_entreprise = factor(cat_entreprise, levels = c("PME", "ETI", "GE", ""), 
                                 labels = c("pme", "eti", "ge", "na")),
         groupe_domaine = as.factor(groupe_domaine),
         depcom = as.factor(depcom) %>%  fct_expand(levels(communes$DEPCOM))) %>% 
   unite(col = "variable", cat_entreprise, groupe_domaine, sep = ".", remove = FALSE)  

## indicateurs com croisant taille ets et domaine travaux
rge_fin <- rge2 %>% 
  group_by(depcom, variable) %>% 
  summarise(valeur = n_distinct(SIRET), .groups = "drop") %>% 
  mutate(variable = factor(variable, levels = lib_var)) %>% 
  complete(depcom, variable, fill = list(valeur = 0))

## indicateurs com par taille ets

rge_taille_ets <- rge2 %>% 
  group_by(depcom, variable = cat_entreprise) %>% 
  summarise(valeur = n_distinct(SIRET), .groups = "drop") %>% 
  complete(depcom, variable, fill = list(valeur = 0))

## indicateurs com par domaine

rge_domaine <- rge2 %>% 
  group_by(depcom, variable = groupe_domaine) %>% 
  summarise(valeur = n_distinct(SIRET), .groups = "drop") %>% 
  complete(depcom, variable, fill = list(valeur = 0))

## indicateurs com tout court

rge_court <- rge2 %>% 
  group_by(depcom) %>% 
  summarise(valeur = n_distinct(SIRET), .groups = "drop") %>% 
  complete(depcom, fill = list(valeur = 0)) %>% 
  mutate(variable = factor("nb_rge"))

## indicateurs 

rge3 <- bind_rows(rge_fin, rge_domaine, rge_taille_ets, rge_court) %>% 
  mutate(variable = as.factor(variable), date = date_maj) %>% 
  arrange(depcom) 

rge4 <- pivot_wider(rge3, names_from = variable, values_from = valeur) %>% 
  bind_rows(indic_rge_old)

save(rge4, file="sysdata/chargement_ets_rge_ademe.RData")


### libelle des variables----------

lib_var1 <- data.frame(var = c("pme", "eti", "ge", "na"),
                       lib_taille_ets = c("petites ou moyennes entreprises", "entreprises de taille intermédiaire", 
                                          "grandes entreprises", "entreprises de taille inconnue")) %>% 
  left_join(lib_var0, by = c("var" = "a"))

lib_var_fin <- data.frame(
  source = "chargement_ets_rge_ademe",
  variable = levels(rge_fin$variable),
  libelle_variable = "") %>% 
  left_join(lib_var1, by = c("variable" = "c")) %>% 
  mutate(libelle_variable = paste0("Nb d'établissements des ", lib_taille_ets, " certifiés RGE dans le domaine ", tolower(lib_groupe_domaine))) %>% 
  select(source, variable, libelle_variable)

lib_var_taille_ets <- data.frame(
  source = "chargement_ets_rge_ademe",
  variable = levels(rge_taille_ets$variable),
  libelle_variable = "") %>% 
  left_join(data.frame(var = c("pme", "eti", "ge", "na"),
                       lib_taille_ets = c("petites ou moyennes entreprises", "entreprises de taille intermédiaire", 
                                          "grandes entreprises", "entreprises de taille inconnue")),
            by = c("variable" = "var")) %>% 
  mutate(libelle_variable = paste0("Nb d'établissements certifiés RGE appartenant à des ", lib_taille_ets)) %>% 
  select(source, variable, libelle_variable)

lib_var_domaine <- data.frame(
  source = "chargement_ets_rge_ademe",
  variable = levels(rge_domaine$variable),
  libelle_variable = "") %>% 
  left_join(lib_var1 %>% select(b, lib_groupe_domaine) %>% distinct(), by = c("variable" = "b")) %>% 
  mutate(libelle_variable = paste0("Nb d'établissements certifiés RGE dans le domaine ", tolower(lib_groupe_domaine))) %>% 
  select(source, variable, libelle_variable)

lib_var2 = data.frame(
  source = "chargement_ets_rge_ademe",
  variable = levels(rge_court$variable),
  libelle_variable = "Nb d'établissements certifiés RGE"
) %>% 
  bind_rows(lib_var_fin, lib_var_taille_ets, lib_var_domaine) %>% 
  mutate(unite = "n", secret = "non", theme_1	= "rénovation énergétique",
         theme_2 = "logement",	theme_3	= "énergie", theme_4 = "appareil productif",
         theme_5 = "", CRTE = TRUE, enr = "")



# Vérif que tous les libelles de variables sont présents
tous_indic <- rge3$variable %>% as.character() %>% unique() 
all(tous_indic %in% lib_var2$variable) # TRUE attendu
all(lib_var2$variable %in% tous_indic) # TRUE attendu

# Export des libelles de varaiables pour compléter le google sheet referentiel des indicateurs
write.csv2(lib_var2, file = "metadata/lib_var_RGE.csv", row.names = FALSE, fileEncoding = "utf-8")

# Versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = rge4,  
            db = "datamart",
            schema = "portrait_territoires", 
            table = "source_ets_rge_ademe",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("depcom", "date"), # déclaration d'une clé primaire sur la table postée : on ne doit pas avoir deux lignes avec à la fois le même code commune et la meme date
            user = "does")

rm(list= setdiff(ls(), c("rge4", "lib_var2")))

# METADONNEES SGBD ------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(rge4), c("depcom", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "depcom", "Code INSEE de la commune",
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, table = "source_ets_rge_ademe", schema = "portrait_territoires",
               db = "datamart", user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table) %>% 
  # ajout de complement sur la généalogie
  paste0(".\n", "T\u00e9l\u00e9chargement depuis https://data.ademe.fr/datasets/liste-des-entreprises-rge, completé par les données SIRENE de localisation des établissements et de catégories d'entreprises (PME,...)")

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "source_ets_rge_ademe", 
                user = "does")

rm(list = ls())
