
# chargement_filocom

# librairies -------------
library(tidyverse)
library(readxl)
library(DT)
library(tricky)
library(lubridate)
library(DBI)
library(RPostgreSQL)

rm(list = ls())


# millesimes à importer ----------
millesimes <- c(2009,2011,2013,2015,2017)


# fonction -----------
creer_millesimes<-function(millesimes){
  
  #chargement des fichiers
  Rapport1 <- read_excel(paste0("extdata/gk3_Filocom_regional_1_",millesimes,".xlsx"),sheet=1) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    gather(variable,valeur,nb_total_logements:revenu_brut_total) %>%
    select(depcom,date,variable,valeur)
  men1 <- read_excel(paste0("extdata/gk3_Filocom_regional_1_",millesimes,".xlsx"),sheet=2) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_menages_pourcent_de_revenus_plaf_hlm",pourcent_de_revenus_plaf_hlm_tranche_))  %>% 
    rename("valeur"="nb_total_de_menages_fiscaux")  %>% 
    select(depcom,date,variable,valeur)
  men2 <- read_excel(paste0("extdata/gk3_Filocom_regional_1_",millesimes,".xlsx"),sheet=3) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_menages_imposition_foyer_fiscal_principal",imposition_foyer_fiscal_principal))  %>% 
    rename("valeur"="nb_total_de_menages_fiscaux")  %>% 
    select(depcom,date,variable,valeur)
  log2_52 <- read_excel(paste0("extdata/gk3_Filocom_regional_2_52_",millesimes,".xlsx"),sheet=1) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts",mode_occupation,type_de_logement))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log3_52 <- read_excel(paste0("extdata/gk3_Filocom_regional_2_52_",millesimes,".xlsx"),sheet=2) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts",mode_occupation,"duree_occup_ou_vacance",duree_occup_ou_vacance_tranche_))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log4_52 <- read_excel(paste0("extdata/gk3_Filocom_regional_2_52_",millesimes,".xlsx"),sheet=3) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts",mode_occupation,classement_cadastral))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log5_52 <- read_excel(paste0("extdata/gk3_Filocom_regional_2_52_",millesimes,".xlsx"),sheet=4) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts",mode_occupation,"propriétaire",code_type_proprietaire))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log8_52 <- read_excel(paste0("extdata/gk3_Filocom_regional_2_52_",millesimes,".xlsx"),sheet=5) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts",type_de_logement))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log9_52 <- read_excel(paste0("extdata/gk3_Filocom_regional_2_52_",millesimes,".xlsx"),sheet=6) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts_mode_occupation",mode_occupation))  %>% 
    rename("valeur"="nb_total_logements") %>% 
    select(depcom,date,variable,valeur)
  log10_52 <- read_excel(paste0("extdata/gk3_Filocom_regional_2_52_",millesimes,".xlsx"),sheet=7) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts_propriétaire",code_type_proprietaire))  %>% 
    rename("valeur"="nb_total_logements") %>% 
    select(depcom,date,variable,valeur)
  
  log2_hr <- read_excel(paste0("extdata/gk3_Filocom_regional_2_hr_",millesimes,".xlsx"),sheet=1) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts",mode_occupation,type_de_logement))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log3_hr <- read_excel(paste0("extdata/gk3_Filocom_regional_2_hr_",millesimes,".xlsx"),sheet=2) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts",mode_occupation,"duree_occup_ou_vacance",duree_occup_ou_vacance_tranche_))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log4_hr <- read_excel(paste0("extdata/gk3_Filocom_regional_2_hr_",millesimes,".xlsx"),sheet=3) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts",mode_occupation,classement_cadastral))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log5_hr <- read_excel(paste0("extdata/gk3_Filocom_regional_2_hr_",millesimes,".xlsx"),sheet=4) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts",mode_occupation,"propriétaire",code_type_proprietaire))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log8_hr <- read_excel(paste0("extdata/gk3_Filocom_regional_2_hr_",millesimes,".xlsx"),sheet=5) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts",type_de_logement))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log9_hr <- read_excel(paste0("extdata/gk3_Filocom_regional_2_hr_",millesimes,".xlsx"),sheet=6) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts_mode_occupation",mode_occupation))  %>% 
    rename("valeur"="nb_total_logements") %>% 
    select(depcom,date,variable,valeur)
  log10_hr <- read_excel(paste0("extdata/gk3_Filocom_regional_2_hr_",millesimes,".xlsx"),sheet=7) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts_propriétaire",code_type_proprietaire))  %>% 
    rename("valeur"="nb_total_logements") %>% 
    select(depcom,date,variable,valeur)
  
  log1_52 <- read_excel(paste0("extdata/gk3_Filocom_regional_3_52_",millesimes,".xlsx"),sheet=1) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts",mode_occupation,"construits",annee_de_construction_tranche_))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log6_52 <- read_excel(paste0("extdata/gk3_Filocom_regional_3_52_",millesimes,".xlsx"),sheet=2) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts_occupation",statut_occupation,nb_de_pieces))  %>% 
    rename("valeur"="nb_total_logements") %>% 
    select(depcom,date,variable,valeur)
  log7_52 <- read_excel(paste0("extdata/gk3_Filocom_regional_3_52_",millesimes,".xlsx"),sheet=3) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts_occupation",statut_occupation,"construits",annee_de_construction_tranche_))  %>% 
    rename("valeur"="nb_total_logements") %>% 
    select(depcom,date,variable,valeur)
  log11_52 <- read_excel(paste0("extdata/gk3_Filocom_regional_3_52_",millesimes,".xlsx"),sheet=4) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts_construits",annee_de_construction_tranche_))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log1_hr <- read_excel(paste0("extdata/gk3_Filocom_regional_3_hr_",millesimes,".xlsx"),sheet=1) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts",mode_occupation,"construits",annee_de_construction_tranche_))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  log6_hr <- read_excel(paste0("extdata/gk3_Filocom_regional_3_hr_",millesimes,".xlsx"),sheet=2) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts_occupation",statut_occupation,nb_de_pieces))  %>% 
    rename("valeur"="nb_total_logements") %>% 
    select(depcom,date,variable,valeur)
  log7_hr <- read_excel(paste0("extdata/gk3_Filocom_regional_3_hr_",millesimes,".xlsx"),sheet=3) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts_occupation",statut_occupation,"construits",annee_de_construction_tranche_))  %>% 
    rename("valeur"="nb_total_logements") %>% 
    select(depcom,date,variable,valeur)
  log11_hr <- read_excel(paste0("extdata/gk3_Filocom_regional_3_hr_",millesimes,".xlsx"),sheet=4) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_lgts_construits",annee_de_construction_tranche_))  %>% 
    rename("valeur"="nb_total_logements")  %>% 
    select(depcom,date,variable,valeur)
  rp1 <- read_excel(paste0("extdata/gk3_Filocom_regional_4_",millesimes,".xlsx"),sheet=1) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_res_principales_statut_occupation",statut_occupation))  %>% 
    rename("valeur"="nb_total_de_residences_principales")  %>% 
    select(depcom,date,variable,valeur)
  rp2 <- read_excel(paste0("extdata/gk3_Filocom_regional_4_",millesimes,".xlsx"),sheet=2) %>% 
    set_standard_names() %>% 
    rename(date = annee,
           depcom = code_de_la_commune) %>% 
    mutate(variable=paste("nb_res_principales_de",nb_de_pieces))  %>% 
    rename("valeur"="nb_total_de_residences_principales")  %>% 
    select(depcom,date,variable,valeur)
  
  filocom <- bind_rows(Rapport1,men1,men2,log8_52,log8_hr,log9_52,log9_hr,log2_52,log2_hr,log3_52,log3_hr,log4_52,log4_hr,rp1,log10_52,log10_hr,log5_52,log5_hr,log11_52,
                       log11_hr,log1_52,log1_hr,log7_52,log7_hr,rp2,log6_52,log6_hr)
  rm(Rapport1,men1,men2,log8_52,log8_hr,log9_52,log9_hr,log2_52,log2_hr,log3_52,log3_hr,log4_52,log4_hr,rp1,log10_52,log10_hr,log5_52,log5_hr,log11_52,
     log11_hr,log1_52,log1_hr,log7_52,log7_hr,rp2,log6_52,log6_hr)
  
  return(filocom)
}

# calcul ------------
filocom<-map_dfr(millesimes,~creer_millesimes(.x))

filocom <- filocom %>%
  complete(depcom,date,variable,fill = list(valeur =0)) %>%  
  group_by(depcom,date,variable) %>%
  summarise(valeur=sum(valeur,na.rm = TRUE)) %>% 
  spread(key = variable, value= valeur)%>% 
  set_standard_names() %>%
  #ajout de nouvelles variables (regroupements)
  mutate(nb_menages_pourcent_de_revenus_plaf_hlm_inferieur_60=nb_menages_pourcent_de_revenus_plaf_hlm_1_inferieur_ou_egal_a_30_+nb_menages_pourcent_de_revenus_plaf_hlm_2_de_30_a_60_inclus,
         nb_menages_pourcent_de_revenus_plaf_hlm_sup_130=nb_menages_pourcent_de_revenus_plaf_hlm_5_de_130_a_150_inclus+nb_menages_pourcent_de_revenus_plaf_hlm_6_superieur_a_150_,
         nb_menages_pourcent_de_revenus_plaf_hlm_non_rens_ou_sans_signification=nb_menages_pourcent_de_revenus_plaf_hlm_7_non_renseigne+nb_menages_pourcent_de_revenus_plaf_hlm_8_sans_signification,
         nb_lgts_logements_vacants_duree_vacance_plus_3_ans=`nb_lgts_logements_vacants_duree_occup_ou_vacance_4_de_3_a_<_4_ans`+`nb_lgts_logements_vacants_duree_occup_ou_vacance_5_de_4_a_<_10_ans`+nb_lgts_logements_vacants_duree_occup_ou_vacance_6_10_ans_ou_plus,
         nb_lgts_construits_avant_1949=nb_lgts_construits_1_avant_1915+nb_lgts_construits_2_de_1915_a_1948,
         nb_lgts_construits_de_1949_a_1974=nb_lgts_construits_3_de_1949_a_1967+nb_lgts_construits_4_de_1968_a_1974,
         nb_lgts_construits_de_1975_a_1989=nb_lgts_construits_5_de_1975_a_1981+nb_lgts_construits_6_de_1982_a_1989,
         nb_lgts_residences_principales_construits_1949=nb_lgts_residences_principales_construits_1_avant_1915+nb_lgts_residences_principales_construits_2_de_1915_a_1948,
         nb_lgts_residences_principales_construits_de_1949_a_1974=nb_lgts_residences_principales_construits_3_de_1949_a_1967+nb_lgts_residences_principales_construits_4_de_1968_a_1974,
         nb_lgts_residences_principales_construits_de_1975_a_1989=nb_lgts_residences_principales_construits_5_de_1975_a_1981+nb_lgts_residences_principales_construits_6_de_1982_a_1989,
         nb_lgts_logements_vacants_construits_avant_1949=nb_lgts_logements_vacants_construits_1_avant_1915+nb_lgts_logements_vacants_construits_2_de_1915_a_1948,
         nb_lgts_logements_vacants_construits_de_1949_a_1974=nb_lgts_logements_vacants_construits_3_de_1949_a_1967+nb_lgts_logements_vacants_construits_4_de_1968_a_1974,
         nb_lgts_logements_vacants_construits_de_1975_a_1989=nb_lgts_logements_vacants_construits_5_de_1975_a_1981, #+nb_lgts_logements_vacants_construits_6_de_1982_a_1989,
         nb_lgts_occupation_proprietaire_occupant_construits_avant_1948=nb_lgts_occupation_proprietaire_occupant_construits_1_avant_1915+nb_lgts_occupation_proprietaire_occupant_construits_2_de_1915_a_1948,
         nb_lgts_occupation_proprietaire_occupant_construits_de_1949_a_1974=nb_lgts_occupation_proprietaire_occupant_construits_3_de_1949_a_1967+nb_lgts_occupation_proprietaire_occupant_construits_4_de_1968_a_1974,
         nb_lgts_occupation_proprietaire_occupant_construits_de_1975_a_1989=nb_lgts_occupation_proprietaire_occupant_construits_5_de_1975_a_1981+nb_lgts_occupation_proprietaire_occupant_construits_6_de_1982_a_1989,
         nb_lgts_occupation_locatif_prive_construits_1_avant_1948=nb_lgts_occupation_locatif_prive_construits_1_avant_1915+nb_lgts_occupation_locatif_prive_construits_2_de_1915_a_1948,
         nb_lgts_occupation_locatif_prive_construits_de_1949_a_1974=nb_lgts_occupation_locatif_prive_construits_3_de_1949_a_1967+nb_lgts_occupation_locatif_prive_construits_4_de_1968_a_1974,
         nb_lgts_occupation_locatif_prive_construits_5_de_1975_a_1989=nb_lgts_occupation_locatif_prive_construits_5_de_1975_a_1981+nb_lgts_occupation_locatif_prive_construits_6_de_1982_a_1989
         ) %>%
  select(depcom, date,
         nb_total_de_menages_fiscaux, 
         nb_men_fisc_avec_revenu_brut_rens,
         revenu_brut_total,        
         nb_menages_pourcent_de_revenus_plaf_hlm_inferieur_60,
         nb_menages_pourcent_de_revenus_plaf_hlm_3_de_60_a_100_inclus,
         nb_menages_pourcent_de_revenus_plaf_hlm_4_de_100_a_130_inclus,        
         nb_menages_pourcent_de_revenus_plaf_hlm_sup_130,
         nb_menages_pourcent_de_revenus_plaf_hlm_non_rens_ou_sans_signification,        
         nb_menages_imposition_foyer_fiscal_principal_2_occupant_principal_non_imposable,
         
         nb_total_logements,
         nb_lgts_collectif,
         nb_lgts_individuel,        
         nb_lgts_mode_occupation_residences_principales,
         nb_lgts_mode_occupation_residences_secondaires,
         nb_lgts_mode_occupation_logements_vacants,
         nb_lgts_logements_vacants_individuel,         
         nb_lgts_logements_vacants_collectif,
         nb_lgts_logements_vacants_duree_vacance_plus_3_ans,        
         nb_lgts_logements_vacants_classement_cadastral_7_ou_8,        
         nb_lgts_residences_principales_classement_cadastral_7_ou_8,        
         nb_lgts_residences_principales_collectif,        
         nb_lgts_residences_principales_individuel,
         nb_lgts_residences_principales_non_renseigne,        
         nb_res_principales_statut_occupation_proprietaire_occupant,        
         nb_res_principales_statut_occupation_autres,
         nb_res_principales_statut_occupation_locatif_collectiv_territ,
         nb_res_principales_statut_occupation_locatif_hlm_sem,
         nb_res_principales_statut_occupation_locatif_prive,
         nb_res_principales_statut_occupation_sans_signification,        
         nb_lgts_proprietaire_personne_physique,
         nb_lgts_proprietaire_hlm_sem,        
         nb_lgts_proprietaire_collectivite_ter_,
         nb_lgts_proprietaire_autres_pm,
         nb_lgts_logements_vacants_proprietaire_personne_physique,        
         nb_lgts_logements_vacants_proprietaire_hlm_sem,        
         nb_lgts_logements_vacants_proprietaire_collectivite_ter_,        
         nb_lgts_logements_vacants_proprietaire_autres_pm,
         nb_lgts_construits_avant_1949,
         nb_lgts_construits_de_1949_a_1974,
         nb_lgts_construits_de_1975_a_1989,        
         nb_lgts_construits_7_de_1990_a_1999,
         nb_lgts_construits_8_apres_2000,
         nb_lgts_construits_9_non_renseigne,        
         nb_lgts_residences_principales_construits_1949,
         nb_lgts_residences_principales_construits_de_1949_a_1974,
         nb_lgts_residences_principales_construits_de_1975_a_1989,        
         nb_lgts_residences_principales_construits_7_de_1990_a_1999,
         nb_lgts_residences_principales_construits_8_apres_2000,
         nb_lgts_residences_principales_construits_9_non_renseigne,
         nb_lgts_logements_vacants_construits_avant_1949,
         nb_lgts_logements_vacants_construits_de_1949_a_1974,
         nb_lgts_logements_vacants_construits_de_1975_a_1989,        
         nb_lgts_logements_vacants_construits_7_de_1990_a_1999,
         nb_lgts_logements_vacants_construits_8_apres_2000,
         nb_lgts_logements_vacants_construits_9_non_renseigne,        
         nb_lgts_occupation_proprietaire_occupant_construits_avant_1948,
         nb_lgts_occupation_proprietaire_occupant_construits_de_1949_a_1974,
         nb_lgts_occupation_proprietaire_occupant_construits_de_1975_a_1989,        
         nb_lgts_occupation_proprietaire_occupant_construits_7_de_1990_a_1999,
         nb_lgts_occupation_proprietaire_occupant_construits_8_apres_2000,
         nb_lgts_occupation_proprietaire_occupant_construits_9_non_renseigne,        
         nb_lgts_occupation_locatif_prive_construits_1_avant_1948,
         nb_lgts_occupation_locatif_prive_construits_de_1949_a_1974,
         nb_lgts_occupation_locatif_prive_construits_5_de_1975_a_1989,
         nb_lgts_occupation_locatif_prive_construits_7_de_1990_a_1999,
         nb_lgts_occupation_locatif_prive_construits_8_apres_2000,
         nb_lgts_occupation_locatif_prive_construits_9_non_renseigne,        
         nb_res_principales_de_1_piece,
         nb_res_principales_de_2_pieces,
         nb_res_principales_de_3_pieces,
         nb_res_principales_de_4_pieces,
         nb_res_principales_de_5_pieces,
         nb_res_principales_de_6_pieces_ou_plus,        
         nb_lgts_occupation_proprietaire_occupant_1_piece,
         nb_lgts_occupation_proprietaire_occupant_2_pieces,
         nb_lgts_occupation_proprietaire_occupant_3_pieces,
         nb_lgts_occupation_proprietaire_occupant_4_pieces,
         nb_lgts_occupation_proprietaire_occupant_5_pieces,
         nb_lgts_occupation_proprietaire_occupant_6_pieces_ou_plus,        
         nb_lgts_occupation_locatif_prive_1_piece,
         nb_lgts_occupation_locatif_prive_2_pieces,
         nb_lgts_occupation_locatif_prive_3_pieces,
         nb_lgts_occupation_locatif_prive_4_pieces,
         nb_lgts_occupation_locatif_prive_5_pieces,
         nb_lgts_occupation_locatif_prive_6_pieces_ou_plus, 
         ) %>%
  gather(variable,valeur,3:87) %>% 
  ungroup() %>% 
  filter(date>=2008) %>% 
  mutate(date=make_date(date,12,31)) %>% 
  mutate_if(is.character,as.factor) %>% 
  complete(depcom,date,variable,fill = list(valeur =0)) %>%
  pivot_wider(names_from = variable,values_from = valeur)


# versement dans le sgbd/datamart.portrait_territoires -------------
drv <- dbDriver("PostgreSQL")
con_datamart <- dbConnect(drv, 
                          dbname="datamart", 
                          host=Sys.getenv("server"), 
                          port=Sys.getenv("port"),
                          user=Sys.getenv("userid"),
                          password=Sys.getenv("pwd_does"))
postgresqlpqExec(con_datamart, "SET client_encoding = 'windows-1252'")

dbWriteTable(con_datamart, c("portrait_territoires","source_filocom"),
             filocom, row.names=FALSE, overwrite=TRUE)

dbDisconnect(con_datamart)

rm(list=ls())
