
# chargement_label_terre_saine

# Liste des territoires récupérée sur le site https://www.ecophyto-pro.fr/terre_saine/recherche/carte/
# Données intégrées dans le fichier exdata/label_terre_saine.xlsx
# mise à jour : 2022

# librairies ---------
library(readxl)
library(COGiter)
library(dplyr)
library(forcats)
library(tidyverse)
library(lubridate)
library(DBI)
library(RPostgreSQL)
library(datalibaba)
library(googlesheets4)

rm(list=ls())

# chargement --------
label <- read_excel("extdata/label_terre_saine.xlsx") %>%
  mutate (Code = as.character(Code))


# calcul --------
liste_communes <- label %>%
  filter (Type== "commune") %>%
  rename (DEPCOM= Code) %>%
  passer_au_cog_a_jour() %>%
  select(DEPCOM) %>%
  pull() %>%
  as.character() %>%
  unique()

liste_epci <- label %>%
  filter (Type== "epci") %>%
  select(Code) %>%
  pull() %>%
  unique()

liste_departement  <- label %>%
  filter (Type== "departement") %>%
  select(Code) %>%
  pull() %>%
  unique()

label_communes<- communes %>%
  filter( grepl("52", REGIONS_DE_L_EPCI)) %>%
  select(DEPCOM,EPCI,DEP)  %>%
  # mutate(valeur = 0 )  %>%
  mutate (DEPCOM = as.character(DEPCOM))  %>%
  mutate (nb_label = case_when(
    DEP %in% liste_departement  ~ 1,
    EPCI %in% liste_epci  ~ 1,
    DEPCOM %in% liste_communes  ~ 1,
    TRUE ~ 0))

label_terre_saine_epci <- label_communes %>%
  # select(-DEP,-DEPCOM) %>%
  mutate(nb_communes = 1) %>%
  group_by(EPCI) %>%
  summarise(nb_com_avec_label=sum(nb_label,na.rm=T),
            nb_communes=sum(nb_communes,na.rm=T)
            )

# 
# # versement dans le sgbd/datamart.portrait_territoires -------------
# drv <- dbDriver("PostgreSQL")
# con_datamart <- dbConnect(drv, 
#                           dbname="datamart", 
#                           host=Sys.getenv("server"), 
#                           port=Sys.getenv("port"),
#                           user=Sys.getenv("userid"),
#                           password=Sys.getenv("pwd_does"))
# postgresqlpqExec(con_datamart, "SET client_encoding = 'windows-1252'")
# 
# dbWriteTable(con_datamart, c("portrait_territoires","ref_label_terre_saine"),
#              label_terre_saine_epci, row.names=FALSE, overwrite=TRUE)
# 
# dbDisconnect(con_datamart)
# 
# rm(list=ls())

# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = label_terre_saine_epci,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "ref_label_terre_saine",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("EPCI"), # déclaration d'une clé primaire sur la table postée : on ne doit pas avoir deux lignes avec à la fois le même code commune et la meme date
            user = "does")

# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(label_terre_saine_epci), c("EPCI"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- "ref_label_terre_saine"

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "EPCI", "Code INSEE de L'EPCI"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, table = "ref_label_terre_saine", schema = "portrait_territoires",
               db = "datamart", user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table)

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "ref_label_terre_saine", 
                user = "does")





