
# chargement_logt_renove_anah

# table Habiter_mieux 

# librairies ---------
library(dplyr)
library(tidyr)
library(forcats)
library(purrr)
library(lubridate)
library(readODS)
library(COGiter)
library(datalibaba)
library(googlesheets4)

rm(list=ls())


# paramètres ---------
mil_anah <- c(2012:2018)


# chargement de la liste des depcom couverts par la source ---------
# pour obtenir tous les levels de DEPCOM (périmètre de la région seule)
source("R/levels_facteurs_com.R") 
# rm(com_reg_et_vois, reg)

# lecture des données et passage au format long -------
logt_renove <- imap_dfr(mil_anah, ~ read_ods("extdata/logts_renoves_commune_2012_2016.ods", sheet = as.character(.x), col_name = TRUE) %>%
                          setNames(c("depcom", "commune", "nb_lgts_subv", "gain_nrj_moy")) %>%
                          mutate(date = make_date(.x, 12, 31), depcom = as.character(depcom),
                                 gain_nrj_moy = gsub(" %", "", gain_nrj_moy))) %>%
  mutate(gain_nrj_moy_pond = as.numeric(gsub(",", ".", gain_nrj_moy)) * nb_lgts_subv) %>%
  select(date, depcom, everything(), -commune, -gain_nrj_moy) %>%
  pivot_longer(cols = nb_lgts_subv:gain_nrj_moy_pond, names_to = "variable", values_to = "valeur") %>%  
  mutate_if(is_character, as.factor) %>%
  mutate(depcom = fct_expand(depcom, com_reg)) %>%
  complete(depcom, date, variable, fill = list(valeur = 0)) %>%
  mutate(depcom = fct_expand(depcom, com_reg_et_vois)) %>%
  complete(depcom, date, variable, fill = list(valeur = NA)) %>% 
  arrange(date, depcom) %>%
  pivot_wider(names_from = variable, values_from = valeur)


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = logt_renove,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "source_logt_renove_anah",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("depcom", "date"), # déclaration d'une clé primaire sur la table postée : on ne doit pas avoir deux lignes avec à la fois le même code commune et la meme date
            user = "does")

# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(logt_renove), c("depcom", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "depcom", "Code INSEE de la commune",
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, table = "source_logt_renove_anah", schema = "portrait_territoires",
               db = "datamart", user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table) 

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "source_logt_renove_anah", 
                user = "does")



rm(list=ls())
