
# chargement_mode_transport_dom_travail

# librairies -----
library(tidyverse)
library(dplyr)
library(lubridate)
library(stringr)
library(datalibaba)

rm(list = ls())


# paramètre --------- 
date = 2020


# chargement data ------------

# chargement des données : https://www.insee.fr/fr/statistiques/7632973?sommaire=7632977
# fichier BTT_TD_NAV2B  
# NAV2 – Population active de 15 ans ou plus ayant un emploi par sexe, lieu de travail (géographie urbaine)
# et moyen de transport (Paru le : 27/06/2023)

racine_nom_fich <- paste0("extdata/TD_NAV2B_", date)
download.file(url = "https://www.insee.fr/fr/statistiques/fichier/7632973/TD_NAV2B_2020_csv.zip", 
              destfile = paste0(racine_nom_fich, ".zip"))
unzip(paste0(racine_nom_fich, ".zip"), overwrite = TRUE, exdir = "extdata")

BTT_TD_NAV2B_mil <- read.csv2(file = paste0(racine_nom_fich, ".csv"), dec = '.', header = TRUE, sep = ";", 
                              stringsAsFactors = FALSE, encoding = "UTF-8")

# nomenclature TRANS_19 : mode de transport
nomenclature <- tribble(
  ~'TRANS_19_code',	~'TRANS_19',
  1,	'mode_pas_de_transport',
  2,	'mode_marche_a_pied',
  3,	'mode_velo',
  4,	'mode_deux_roues_motorise',
  5,	'mode_voiture_camion_fourgonnette',
  6,	'mode_transports_en_commun'
)

mode_transport_dom_travail_detail <- BTT_TD_NAV2B_mil %>%
  filter(NIVGEO == "COM") %>%
  select (-NIVGEO , -LIBGEO) %>%
  group_by(CODGEO, TRANS_19_code = TRANS_19) %>%
  summarise(valeur = sum(NB, na.rm = TRUE), .groups = "drop") %>%
  left_join(nomenclature, by = 'TRANS_19_code')

mode_transport_total <- mode_transport_dom_travail_detail  %>%
  group_by(CODGEO) %>%
  summarise(valeur = sum(valeur, na.rm = TRUE), .groups = "drop" ) %>%
  mutate(TRANS_19 = "mode_total")

mode_transport_dom_travail <- bind_rows(mode_transport_dom_travail_detail, mode_transport_total) %>%
  mutate(TRANS_19 = factor(TRANS_19), CODGEO = factor(CODGEO)) %>% 
  mutate(date = make_date(date, 12, 31)) %>%
  rename(depcom = CODGEO, variable = TRANS_19) %>% 
  select(depcom, date,variable, valeur) %>%  
  complete(depcom, date, variable, fill = list(valeur =0)) %>% 
  pivot_wider(names_from = variable, values_from = valeur)

source_mode_transport_dom_travail_anterieur <- importer_data(db = "datamart",
                                                             schema = "portrait_territoires",
                                                             table = "source_mode_transport_dom_travail")

source_mode_transport_dom_travail <- bind_rows(source_mode_transport_dom_travail_anterieur, mode_transport_dom_travail)


# versement dans le sgbd/datamart.portrait_territoires et metadonnées -------------
source("R/poster_documenter_data.R", encoding = "UTF-8")
poster_documenter_it(df = source_mode_transport_dom_travail ,
                     nom_table_sgbd = "source_mode_transport_dom_travail", 
                     comm_source_en_plus = "")


