
# chargement_ocsge

library(magritt)

rm(list=ls())


# connexion au SGBDR ------------
con_referentiels <- DBI::dbConnect(
  RPostgres::Postgres(), 
  dbname="referentiels",
  host=Sys.getenv("server"),
  port=Sys.getenv("port"),
  user=Sys.getenv("userid"),
  password=Sys.getenv("pwd_does")
  )


# fonction get_ocsge_dep_com ---------

# elle decoupe une couche dep ocsge millesimée aux contours des communes de la bd topo
# et renvoie une ligne par commune, usage et couverture 

get_ocsge_dep_com <- function(dep, mil = "2016") {
  query = paste0("SELECT com.code_insee, ocsge.couverture, ocsge.usage, ocsge.millesime, ", 
                 "SUM(ST_Area(ST_intersection(ocsge.the_geom, com.the_geom))) AS surf_intersection_m2 ",
                 "FROM ocsge.n_occupation_sol_", mil, "_0", dep, " AS ocsge, ",
                 "bdtopo_v3.n_bdt_commune_s_r52 AS com ",
                 "WHERE ST_intersects(ocsge.the_geom, com.the_geom)",
                 "GROUP BY com.code_insee, ocsge.couverture, ocsge.usage, ocsge.millesime",
                 ";")
  DBI::dbGetQuery(con_referentiels, query)
}


# application de la fonction aux 5 départements et aux 2 millésimes -------
ocsge_pdl <- purrr::map2_dfr(
  .x = rep(c("44", "49", "53", "72", "85"), 2), 
  .y = c(rep("2013man", 5), rep("2016", 5)), 
  .f = ~ get_ocsge_dep_com(dep = .x, mil = .y) ) %>%
  dplyr::mutate(date = lubridate::make_date(millesime, 06, 30))

# en cas de connexion par VPN, mieux vaut procéder par étape pour éviter de tout perdre en cas de déconnexion
# ocsge_44 <- get_ocsge_dep_com(dep = "44", mil = "2016")
# ocsge_49 <- get_ocsge_dep_com(dep = "49", mil = "2016")
# ocsge_53 <- get_ocsge_dep_com(dep = "53", mil = "2016")
# ocsge_72 <- get_ocsge_dep_com(dep = "72", mil = "2016")
# ocsge_85 <- get_ocsge_dep_com(dep = "85", mil = "2016")
# ocsge_44_2013 <- get_ocsge_dep_com(dep = "44", mil = "2013man")
# ocsge_49_2013 <- get_ocsge_dep_com(dep = "49", mil = "2013man")
# ocsge_53_2013 <- get_ocsge_dep_com(dep = "53", mil = "2013man")
# ocsge_72_2013 <- get_ocsge_dep_com(dep = "72", mil = "2013man")
# ocsge_85_2013 <- get_ocsge_dep_com(dep = "85", mil = "2013man")
# 
# ocsge_pdl <- dplyr::bind_rows(
#   ocsge_44, ocsge_49, ocsge_53, ocsge_72, ocsge_85,
#   ocsge_44_2013, ocsge_49_2013, ocsge_53_2013, ocsge_72_2013, ocsge_85_2013
#   ) %>%
#   dplyr::mutate(date = lubridate::make_date(millesime + 1, 01, 01))

DBI::dbDisconnect(con_referentiels)


# versement de ocsge_pdl dans le sgbd/datamart.portrait_territoires -------------
ocsge_pdl_2013 <- dplyr::filter(ocsge_pdl, millesime == 2013)
ocsge_pdl_2016 <- dplyr::filter(ocsge_pdl, millesime == 2016)

datalibaba::poster_data(
  data = ocsge_pdl_2013,
  db = "datamart",
  schema = "portrait_territoires", 
  table = "ocsge_pdl_couverture_usage_2013",
  post_row_name = FALSE, 
  overwrite = TRUE,
  droits_schema = TRUE,
  user = "does"
  )

datalibaba::poster_data(
  data = ocsge_pdl_2016,
  db = "datamart",
  schema = "portrait_territoires", 
  table = "ocsge_pdl_couverture_usage_2016",
  post_row_name = FALSE, 
  overwrite = TRUE,
  droits_schema = TRUE,
  user = "does"
  )


# typologie des espaces -------
ocsge_type <- dplyr::select(ocsge_pdl, couverture, usage) %>% 
  dplyr::distinct() %>% 
  dplyr::mutate(
    type_espace = dplyr::case_when(
      couverture %in% c("CS1.1.1.1", "CS1.1.1.2", "CS1.1.2.1", "CS1.1.2.2")  ~ "espace_artificialise",
      couverture == "CS1.2.1" & 
        usage %in% c("US1.1", "US1.3", "US1.4", "US235", "US4.1.1", "US4.1.2", "US4.1.3", "US4.1.4", "US4.2", "US4.3", "US6.1", "US6.2")  ~ "espace_artificialise",
      couverture == "CS1.2.1" &
        usage %in% c("US1.2", "US1.5", "US6.3", "US6.4") ~ "autre_surface_naturelle", 
      couverture == "CS1.2.2" ~ "surface_en_eau",
      couverture %in% c("CS2.1.1.1", "CS2.1.1.2", "CS2.1.1.3", "CS2.1.2", "CS2.1.3", "CS2.2.1", "CS2.2.2") & usage == "US1.1" ~ "espace_agricole",
      couverture %in% c("CS2.1.1.1", "CS2.1.1.2", "CS2.1.1.3","CS2.1.1", "CS2.1.2", "CS2.1.3") & usage %in% c("US1.3", "US235") ~ "espace_artificialise", 
      couverture %in% c("CS2.1.1.1", "CS2.1.1.2", "CS2.1.1.3", "CS2.1.2", "CS2.1.3") & 
        usage %in% c("US1.2", "US1.4", "US1.5", "US4.1.1", "US4.1.2", "US4.1.3", "US4.1.4", "US4.1.5", "US4.2", "US4.3", "US6.1", "US6.2", "US6.3", "US6.4") ~ "surface_naturelle_boisee",
      couverture == "CS2.2.1" &
        usage %in% c("US1.3", "US1.4", "US1.5", "US235", "US4.1.1", "US4.1.2", "US4.1.3", "US4.1.4", "US4.1.5", "US4.2", "US4.3", "US6.1", "US6.2")  ~ "espace_artificialise", 
      couverture == "CS2.2.1" &
        usage %in% c("US1.2", "US6.3", "US6.4") ~ "autre_surface_naturelle",
      couverture == "CS2.2.2" &
        usage != "US1.1" ~ "a_definir",
      TRUE ~ "a_revoir"
      )
    )


# chargement de la liste des depcom COGiter région PDL et région PDL + epci -------
source("R/levels_facteurs_com.R")


# calcul des indicateurs communaux -----------
source_ocsge <- ocsge_pdl %>%
  dplyr::left_join(ocsge_type) %>% 
  dplyr::select(
    depcom = code_insee, 
    date, 
    variable = type_espace, 
    valeur = surf_intersection_m2
    ) %>%
  dplyr::group_by(date, depcom, variable) %>%
  dplyr::summarise(valeur = sum(valeur), .groups = "drop") %>%
  dplyr::mutate_if(is.character, as.factor) %>% 
  dplyr::mutate(depcom = forcats::fct_expand(depcom, com_reg)) %>%
  tidyr::complete(depcom, date, variable, fill = list(valeur = 0), explicit = FALSE) %>% 
  dplyr::mutate(depcom = forcats::fct_expand(depcom, com_reg_et_vois)) %>%
  tidyr::complete(depcom, date, variable, fill = list(valeur = NA)) %>%   
  tidyr::pivot_wider(names_from = variable,values_from = valeur)
  

# versement de ocsge dans le sgbd/datamart.portrait_territoires et metadonnées -------------
source("R/poster_documenter_data.R", encoding = "UTF-8")
poster_documenter_it(
  df = source_ocsge ,
  nom_table_sgbd = "source_ocsge", 
  comm_source_en_plus = ""
  )

