# chargement_osm_parkings_velo

# librairies ----------
library(dplyr)
library(tibble)
library(tidyr)
library(purrr)
library(forcats)
library(sf)
library(COGiter)
library(jsonify)
library(datalibaba)

rm(list=ls())


# lecture des données OSM --------
## parkings à velo --------
park_velo_0 <- st_read("https://ws.dataosm.info/api/group/download/?provider_vector_id=undefined&table_id=undefined&provider_style_id_target=1053&provider_vector_id_target=543&driver=gpkg",
                       layer = 'Parking vlo')
# save(park_velo_0, file = paste0("extdata/parking_velos_true_409_329_", Sys.Date(), ".RData"))

park_velo_1 <- park_velo_0 %>% 
  rowwise() %>% 
  mutate(attr = list(from_json(hstore_to_json, fill_na = TRUE)))

attr_possibles <- flatten(park_velo_1$attr) %>% names() %>% unique()
attr_possibles

park_velo_2 <- park_velo_1 %>% 
  rowwise %>% 
  mutate(capa = list(flatten(attr)$capacity),
         payant = list(flatten(attr)$fee),
         couvert = list(flatten(attr)$covered),
         acces = list(flatten(attr)$access),
         interieur = list(flatten(attr)$indoor),
         surveille = list(flatten(attr)$supervised),
         lit = list(flatten(attr)$lit),
         surveille2 = list(flatten(attr)$surveillance),
         type = list(flatten(attr)$'bicycle_parking:type'),
         ferme = list(flatten(attr)$locked),
         protege = list(flatten(attr)$protected),
         private = list(flatten(attr)$private),
         cover = list(flatten(attr)$cover)) %>% 
  select(-hstore_to_json, -attr) %>% 
  ungroup

park_velo_3 <- park_velo_2 %>% 
  unnest(cols = c(capa, surveille, surveille2, protege, cover, couvert, ferme, type, payant, acces, interieur,
                  lit, private), keep_empty = TRUE) 

save(park_velo_3, file = "extdata/park_velo_3.RData")
# load("extdata/park_velo_3.RData")

# communes --------
## attention 350 Mo à rapatrier d'osm
com_osm <- st_read("https://ws.dataosm.info/api/group/download/?provider_vector_id=undefined&table_id=undefined&provider_style_id_target=1145&provider_vector_id_target=98&driver=gpkg")
# save(com_osm, file = "extdata/communes_true_272_179.RData")


# source("R/admin_express.R")
load("extdata/admin_exp_com.RData")
com_admin_exp <- com_admin_exp %>% 
  filter(!(INSEE_REG %in% paste0("0", 1:6))) %>% 
  st_transform(2154)

# SGBD 1 versement des parkings dans SGBD/production/pistes_cycl_osm  -------
# (couche brute dans production.pistes_cycl_osm)
poster_data(data = park_velo_3, table = paste0("parkings_velo_n_brut_", Sys.Date() %>% gsub("-", "", .)), db = "production",
            schema = "pistes_cycl_osm", pk = 'osm_id', post_row_name = FALSE, overwrite = TRUE)
commentaire_table <- paste0("La table est résulte d une extraction Open street map réalisée le ", 
                            Sys.Date() %>% format("%d %m %Y"),
                            " grâce à https://demo.openstreetmap.fr/map. Les données sont issues de la couche D.durable/mobilité douce.")
commenter_table(comment = commentaire_table, db = "production", schema = "pistes_cycl_osm", 
                table = paste0("parkings_velo_n_brut_", Sys.Date() %>% gsub("-", "", .)))


# nettoyage et préparation de la table de données individuelles -------------

# examen des modalités des variables 
unique(park_velo_3$lit)
unique(park_velo_3$acces)
unique(park_velo_3$amenity)
unique(park_velo_3$type)
unique(park_velo_3$ferme)
unique(park_velo_3$protege)
unique(park_velo_3$interieur)
unique(park_velo_3$surveille)        
unique(park_velo_3$surveille2)
unique(park_velo_3$private)
unique(park_velo_3$couvert)
unique(park_velo_3$payant)

# création de la variable 'sécurisé' et autre nettoyage
park_velo_4 <- park_velo_3 %>% 
  mutate(securise = case_when(ferme == "yes" ~ TRUE,
                              tolower(surveille) != "no" & tolower(surveille) != "non" ~ TRUE,
                              !(tolower(surveille2) %in% c("no", "no ", "public", "outdoor")) & !is.na(surveille2) ~ TRUE,
                              TRUE ~ FALSE),
         couvert = if_else(couvert %in% c("yes", "saddle only", "6", "partial", "roof" , "true"), TRUE, FALSE),
         payant = case_when(payant == "yes" ~ TRUE,
                            payant == "no" ~ FALSE,
                            payant == "0" ~ FALSE,
                            grepl("month|Badge|badge|varies|40|10|private", payant) ~ TRUE,
                            grepl("gratuit|free|Free", payant) ~ FALSE,
                            is.na(payant) ~ FALSE,   # on considère que si non renseigné c'est que gratuit
                            TRUE ~ NA)) %>%
  select(-name, -amenity, -type, -acces,
         -lit, -protege, -private, -cover,
         -ferme, -surveille, -surveille2, -interieur) %>% 
  st_transform(2154) %>% 
  mutate(osm_id = as.character(osm_id),
         capa = capa %>% gsub("around |environ |~|>", "", .) %>% as.numeric() %>% na_if(0)) 

# jointures géo avec la table des communes
park_velo_com <- st_join(x = park_velo_4, y = select(com_admin_exp, INSEE_COM), left = TRUE, join = st_intersects)

park_velo_com_NA <- filter(park_velo_com, is.na(INSEE_COM)) %>% 
  st_transform(4326) %>% 
  st_join(x = ., y = select(com_osm, ref, name), left = TRUE, join = st_intersects) %>% 
  filter(!is.na(ref)) %>% # beaucoup de parkings hors france ou dans TOM
  st_drop_geometry()

park_velo_com2 <- park_velo_com %>% 
  full_join(park_velo_com_NA, by = c("osm_id", "capa", "payant", "couvert", "securise", "INSEE_COM")) %>% 
  mutate(INSEE_COM = coalesce(INSEE_COM, ref)) %>% 
  select(-ref)

save(park_velo_com2, file = "extdata/park_velo_com2.RData")
load("extdata/park_velo_com2.RData")

# SGBD 2 versement de la table de données individuelles nettoyée -------

# 
# dbDisconnect(con)
# rm(con)
poster_data(data = park_velo_com2, table = paste0("parkings_velo_n_", Sys.Date() %>% gsub("-", "", .)), db = "production",
            schema = "pistes_cycl_osm", pk = 'osm_id', post_row_name = FALSE, overwrite = TRUE)
commentaire_table <- paste0("La table est résulte d une extraction Open street map réalisée le ", Sys.Date() %>% format("%d %m %Y"),
                            " grâce à https://demo.openstreetmap.fr/map. Les données sont issues de la couche D.durable/mobilité douce.", 
                            " Les attributs ont été affinés et nettoyes dans le cadre du POC Indicateurs territoriaux et des CRTE.';")
commenter_table(comment = commentaire_table, db = "production", schema = "pistes_cycl_osm", 
                table = paste0("parkings_velo_n_", Sys.Date() %>% gsub("-", "", .)))

# calcul des indicateurs communaux ----------
park_velo <- park_velo_com2 %>% 
  # ajout des communes manquantes
  right_join(table_passage_com_historique, by = c("INSEE_COM" = "DEPCOM_HIST")) %>% # suppression des TOM, ajout des communes sans parking
  st_drop_geometry() %>%   
  filter(!is.na(DEPCOM)) %>% 
  group_by(DEPCOM) %>% 
  summarise(nb_park_velo = n_distinct(osm_id, na.rm = TRUE), capacite = sum(capa), # capa_moy = mean(capa, na.rm = TRUE),
            nb_park_velo_payants = sum(payant, na.rm = TRUE), nb_park_velo_secu = sum(securise, na.rm = TRUE),
            nb_park_velo_couvert = sum(couvert, na.rm=TRUE), .groups = "drop") %>% 
  mutate(capacite = if_else(nb_park_velo == 0, 0, capacite),
         date = Sys.Date()) %>% 
  rename(depcom=DEPCOM) %>% 
  pivot_longer(cols = c(starts_with("nb_park_velo"), capacite), names_to = "variable", values_to = "valeur") %>% 
  mutate(across(where(is.character), as.factor)) %>% 
  pivot_wider(names_from = variable,values_from = valeur)

save(park_velo, file = "extdata/park_velo.RData")
load("extdata/park_velo.RData")

# versement dans le sgbd/datamart.portrait_territoires et documentation-------------
source("R/poster_documenter_data.R", encoding = "UTF-8")
poster_documenter_it(df = park_velo, nom_table_sgbd = "source_osm_parkings_velo", 
                     comm_source_en_plus = "")

rm(list=ls())


# # libelle des variables (partie neutralisée) ------
# lib_var <- data.frame(
#   source = "chargement_osm_parkings_velo",
#   variable=levels(park_velo$variable),
#   libelle_variable = c("Nombre total de places pour vélo",
#                        "Nombre de parkings à vélos",
#                        "Nombre de parkings à vélo couverts",
#                        "Nombre de parkings à vélo payants",
#                        "Nombre de parkings à vélo sécurisés"),
#   unite = "",
#   secret = "non")