# chargement_pistes_cyclables_osm
# grâce à osmextract

library(osmextract)
# library(osmdata)
library(tidyverse)
library(sf)
library(COGiter)
library(datalibaba)
library(units)


# 8 requete OSM à exécuter -----------
# les criteres de sélection : 
# highway = cycleway
# highway =* + cycleway=track ou cyclestreet=yes
# highway = path + (bicycle = designated OR bicycle = official) 
# highway =* + bicycle=use_sidepath
# highway =* + cycleway=lane
# highway =* + cycleway=share_busway
# https://wiki.openstreetmap.org/wiki/FR:Bicycle#cite_note-anyroad-1


# Tous les objets lineaires de la France -----------
qline <-  oe_get("France", quiet = FALSE, query = "SELECT * FROM 'lines'") 
qline_drom <- bind_rows(oe_get("Martinique", quiet = FALSE, query = "SELECT * FROM 'lines'"),
                        oe_get("Guadeloupe", quiet = FALSE, query = "SELECT * FROM 'lines'"),
                        oe_get("Guyane", quiet = FALSE, query = "SELECT * FROM 'lines'"),
                        oe_get("La Réunion", quiet = FALSE, query = "SELECT * FROM 'lines'"),
                        oe_get("Mayotte", quiet = FALSE, query = "SELECT * FROM 'lines'"))
osm_line_fre_ent <- bind_rows(qline, qline_drom)
save(qcycl_0, file = "extdata/qcycl_0.RData")


# les aménagements cyclables -----------

# highway = cycleway
qcycl1 = filter(osm_line_fre_ent, highway == 'cycleway') %>% 
  mutate(typ_amenagmt = "piste cyclable", date_requete=Sys.Date())

# highway = * + cycleway = track ou opposite_track ou cyclestreet=yes
qcycl2 <- filter(osm_line_fre_ent, highway != 'cycleway', 
                 str_detect(other_tags, '^"cycleway.*?"=>"track"|^"cycleway.*?"=>"opposite_track"')) %>% 
  mutate(typ_amenagmt = "piste cyclable", date_requete=Sys.Date())

qcycl2bis <- filter(osm_line_fre_ent, highway != 'cycleway', 
                    str_detect(other_tags, '^"cyclestreet"=>"yes"')) %>% 
  mutate(typ_amenagmt = "piste cyclable", date_requete=Sys.Date())

# highway = path + (bicycle = designated OR bicycle = official)
qcycl3a5 <- filter(osm_line_fre_ent, highway %in% c('path', "footway", "pedestrian"), 
                   str_detect(other_tags, '^"bicycle"=>"official"|^"bicycle"=>"designated"|^"bicycle"=>"segregated"')) %>% 
  mutate(typ_amenagmt = "piste cyclable", date_requete=Sys.Date())

# highway =* + bicycle=use_sidepath ou share_busway
qcycl6 <- filter(osm_line_fre_ent, highway != 'cycleway', 
                 str_detect(other_tags, '^"cycleway.*?"=>"use_sidepath"|^"cycleway.*?"=>"lane"|^"cycleway.*?"=>"share_busway"|^"cycleway.*?"=>"opposite_lane"')) %>% 
  mutate(typ_amenagmt = "bande cyclable", date_requete=Sys.Date())

qcycl7 <- filter(osm_line_fre_ent, highway %in% c("track", "service"), 
                 str_detect(other_tags, '^"motor.*=>"no"') | str_detect(other_tags,'"psv"=>"NULL"|"psv"=>"no"') |
                   str_detect(other_tags, '"bus"=>"NULL"|"bus"=>"no"') |  str_detect(other_tags, '".*?bicycle"=>"NULL"|".*?bicycle"=>"(?!no)')) %>% 
  mutate(typ_amenagmt = "autres", date_requete = Sys.Date())


qcycl8 <- filter(osm_line_fre_ent, str_detect(c("track|service"), tolower(highway)), 
                 str_detect(other_tags, '"access"=>"no"') | str_detect(other_tags,'"psv"=>"NULL"|"psv"=>"no"') |
                   str_detect(other_tags,'"motorcycle"=>"NULL"|"motorcycle"=>"no"') |
                   str_detect(other_tags, '"bus"=>"NULL"|"bus"=>"no"'),  
                 str_detect(other_tags, '".*?bicycle"=>"yes"|".*?bicycle"=>"official"|".*?bicycle"=>"designated"|".*?bicycle"=>"permissive"')) %>% 
  mutate(typ_amenagmt = "autres", date_requete = Sys.Date())


# leur assemblage -----------
qcycl_0 <- bind_rows(qcycl1, qcycl2, qcycl2bis, qcycl3a5, qcycl6, qcycl7, qcycl8)  %>% 
  distinct()
save(qcycl_0, file = "extdata/qcycl_0.RData")


# l'élimination des doublons ---------
qcycl_1 <- qcycl_0 %>% 
  mutate(geom_txt = st_as_text(geometry)) %>% 
  st_drop_geometry() %>%
  group_by(osm_id, geom_txt) %>% 
  slice(1) %>% 
  ungroup() %>%
  mutate(geometry = st_as_sfc(geom_txt)) %>%
  select(-geom_txt) %>%
  st_as_sf(crs = st_crs(qcycl_0))
save(qcycl_1, file = "extdata/qcycl_1.RData")
# load(file="extdata/qcycl_1.RData")


# versement de qcycl dans SGBD/production/pistes_cycl_osm -----
# qcycl_1 : table unifiée avec l'ens des attributs OSM

nom_table <-  paste0("pistes_cycl_fr_", qcycl_1$date_requete[1] %>% gsub("-", "", .))
poster_data(data = qcycl_1, table = nom_table, schema =  "pistes_cycl_osm",
            pk = "osm_id", db = "production", overwrite = TRUE)

statement = paste0("La table est résulte d une extraction Open street map réalisée le ", qcycl_1$date_requete[1], " avec les 8 requêtes suivantes :
                    1. highway = cycleway, 2. highway = path + (bicycle = designated OR bicycle = official), 3. highway =* + bicycle=use_sidepath,
                    4. highway =* + cycleway=track, 5. highway =* + cycleway=lane, 6. highway =* + cycleway=share_busway (bandes cyclables),
                    7. Autres sites propres : routes et chemin qui ne sont pas accessibles aux véhicules à moteur,
                    8. Les voies particulières de type track et service dont l accès est interdits aux voitures ou dont l accès est interdits à tous sauf aux vélos.
                    Les requêtes 1 à 5 renvoient des pistes cyclables, la requête 6 renvoit des bandes cyclables, les requêtes 7 et 8 renvoient des aménagements cyclables autres.
                    plus d info : https://wiki.openstreetmap.org/wiki/FR:Bicycle#cite_note-anyroad-1")

commenter_table(comment = statement, db = "production", schema = "pistes_cycl_osm", table = nom_table)


# récupération d'une géo fine des communes -----------

# source("R/admin_express.R")
# Error: Cannot open "~/ADMIN-EXPRESS_3-1__SHP__FRA_WM_2022-06-21/ADMIN-EXPRESS/1_DONNEES_LIVRAISON_2022-06-21/ADE_3-1_SHP_WGS84G_FRA/COMMUNE.shp"; The file doesn't seem to exist.

# n_commune_exp_000 <- importer_data(db = "referentiels",
#                                    schema = "adminexpress",
#                                    table = "n_commune_exp_000") 
# l'alternative sur le sgbd : ADMIN-EXPRESS édition Mars 2022 France métropolitaine seulement !

# script admin_express.R modifié pour pouvoir créer admin_exp_com.RData "à la main"

load("extdata/admin_exp_com.RData")


# calcul des indicateurs ----------

communes_ae <- com_admin_exp %>%
  select(DEPCOM = INSEE_COM) %>%
  mutate(DEPCOM2 = DEPCOM) %>%
  rename(the_geom = geometry) %>%
  column_to_rownames(var = "DEPCOM2") %>%
  st_as_sf()

rm(com_admin_exp)

# abandon des attributs inutiles (tout a été stocké dans le sgbd)
qcycl <- select(qcycl_1, osm_id, highway, typ_amenagmt, date_requete)


# rapprochement de la géometrie communale de la géométrie des pistes cyclable
pist_com_0 <- st_join(qcycl, communes_ae)

sf_use_s2(FALSE) # sinon, problème avec summarise par la suite

pist_com_1 <- pist_com_0 %>%
  filter(!is.na(DEPCOM)) %>%
  group_by(DEPCOM, typ_amenagmt, date_requete) %>% 
  summarise(do_union = TRUE, .groups = "drop") 
save(pist_com_1, file = "extdata/pist_com_1.RData") # calcul plutôt long

sf_use_s2(TRUE)

pist_com_2 <- pist_com_1 %>% 
  dplyr::left_join(as_tibble(communes_ae), by = "DEPCOM") %>% # jointure complete pour ajouter les communes vides
  rename(geom_pist_avec_debordmt = geometry, geom_com = the_geom) %>%
  mutate(geom_pist_com = map2(geom_pist_avec_debordmt, geom_com, st_intersection) %>% st_as_sfc(crs = 4326)) %>%
  st_set_geometry("geom_pist_com") %>%
  select(-geom_com, -geom_pist_avec_debordmt) %>%
  mutate(valeur = st_length(geom_pist_com) %>% set_units(km) %>%  round(4) %>% drop_units()) %>% # conversion de m en km
  st_drop_geometry() %>%
  rename(date = date_requete, depcom = DEPCOM, variable = typ_amenagmt) %>%
  mutate(variable = paste0("km_", gsub(pattern = " ", replacement = "_", variable)) %>% as.factor)

# on ajoute les communes vides
pist_com_3 <- pist_com_2 %>% 
  full_join(st_drop_geometry(communes_ae), by = c("depcom" = "DEPCOM")) %>% 
  mutate(variable = coalesce(variable, "km_piste_cyclable"),
         date = coalesce(date, qcycl$date_requete[1]),
         valeur = coalesce(valeur, 0)) %>%
  complete(depcom, date, variable, fill = list(valeur=0), ) %>% 
  filter(!is.na(depcom))

indic_pist_com <- group_by(pist_com_3, depcom, date) %>%
  summarise(variable = "km_cyclables_tot", valeur = sum(valeur), .groups = "drop") %>%
  bind_rows(pist_com_3)
save(indic_pist_com, file = "extdata/indic_pist_com.RData")


# avant de passer à la suite, correction de l'exercice 2022 -----------
# script provisoire à part et non déposé dans gitlab


# combinaison avec millésimes précédents et versement des indicateurs complets (multimillesimes) dans le sgbd ----

## Découverte des tables d'indicateurs présentes et lecture
## seule la + récente est à importer elle comprend les indicateurs des différentes dates de collecte
con <- datalibaba::connect_to_db(db = "production")
table_old <- grep("indic_com_pistes_cycl", datalibaba::list_tables(con, schema = "pistes_cycl_osm"), value = TRUE) %>%
  sort(decreasing = TRUE)
DBI::dbDisconnect(con);rm(con)

indic_pist_com_old <- importer_data(table = table_old[1], schema = "pistes_cycl_osm", db = "production") %>%
  filter(date != indic_pist_com$date[1])

# cf. correction de 2022
# indic_pist_com_old <- importer_data(table = "indic_com_pistes_cycl_fr_20170801_20220722", schema = "pistes_cycl_osm", db = "production")

## Assembage
indic_pist_com2 <- bind_rows(indic_pist_com, indic_pist_com_old) %>% 
  mutate(across(where(is.character), as.factor)) %>% 
  group_by(date, depcom, variable) %>% 
  summarise_all(sum) %>% 
  ungroup


# versement des indicateurs dans le sgbd/production/pistes_cycl_osm -------------
table <- paste0("indic_com_pistes_cycl_fr_", min(indic_pist_com2$date) %>% gsub("-", "", .), "_",
                max(indic_pist_com2$date) %>% gsub("-", "", .))
dates <- indic_pist_com2$date %>% unique %>% sort() %>% format("%d-%m-%Y") %>% paste0(collapse = ", ")

poster_data(data = indic_pist_com2, table = table, schema = "pistes_cycl_osm", db = "production", pk = c("depcom", "date", "variable"), 
            post_row_name = FALSE, overwrite = TRUE)

commenter_table(comment = paste0("La table résulte d une exploitation des extractions Open street map réalisées les ", dates,  "."), 
                table = table, schema = "pistes_cycl_osm", db = "production")


# versement dans le sgbd/datamart.portrait_territoires -------------
indic_pist_com3 <- indic_pist_com2 %>% 
  complete(depcom, date, variable, fill = list(valeur = 0)) %>% 
  pivot_wider(names_from = variable, values_from = valeur)

source("R/poster_documenter_data.R", encoding = "UTF-8")
poster_documenter_it(df = indic_pist_com3, nom_table_sgbd = "source_pistes_cyclables_osm", 
                     comm_source_en_plus = "")

rm(list=ls())



