
# chargement_population_legale

library(magrittr)

rm(list = ls())

# chargement de l'historique des populations légales de 1968 à 2021 -----------
# Source : https://www.insee.fr/fr/statistiques/2522602
# Historique des populations légales, Recensements de la population 1968-2021

# file <- "extdata/Fichier_poplegale_6820.xlsx"
file <- "extdata/Fichier_poplegale_6821.xlsx"
utils::download.file(
  # url = "https://www.insee.fr/fr/statistiques/fichier/2522602/fichier_poplegale_6820.xlsx",
  url = "https://www.insee.fr/fr/statistiques/fichier/2522602/fichier_poplegale_6821.xlsx",
  destfile = file, 
  method = "curl"
  )
list <- readxl::excel_sheets(file)
# Suppression des onglets de définition
list <- list[-c(1:2)]

# calcul de l'indicateur ------
population_legale <- purrr::map(list, readxl::read_excel, skip = 7, path = file) %>%
  purrr::map(., ~ dplyr::select(., -NCC)) %>%
  purrr::reduce(dplyr::full_join) %>%
  tidyr::pivot_longer(names_to = "variable", values_to = "valeur", -COM) %>%
  dplyr::mutate(
    annee = ifelse(
      stringr::str_sub(variable, -2, -1) < "60",
      stringr::str_c("20", stringr::str_sub(variable, -2, -1)),
      stringr::str_c("19", stringr::str_sub(variable, -2, -1))
      ),
    variable = "population_municipale",
    date = lubridate::ymd(stringr::str_c(annee, "01", "01")),
    dplyr::across(tidyselect::where(is.character), as.factor),
    valeur = tidyr::replace_na(valeur, 0)
    ) %>%
  dplyr::select(depcom = COM, date, variable, valeur) %>%
  dplyr::filter(depcom != "97801", depcom != "97701", depcom != "97123", depcom != "97127") %>% 
  tidyr::complete(depcom, date, variable, fill = list(valeur = 0)) %>%
  tidyr::pivot_wider(names_from = variable, values_from = valeur) 

# "97801" et "97123" commune de Saint-Martin du fait qu'elle était une commune jusqu'en 2007, depuis elle est une collectivité d'outre-mer
# "97701" et "97127" commune de Saint-Barthélémy idem

# versement dans le sgbd/datamart.portrait_territoires et metadonnées ------------- 
source("R/poster_documenter_data.R", encoding = "UTF-8")
poster_documenter_it(
  df = population_legale,
  nom_table_sgbd = "source_population_legale", 
  comm_source_en_plus = "T\u00e9l\u00e9chargement depuis le site de l\'Insee https://www.insee.fr/fr/statistiques/2522602. Historique des populations l\u00e9gales - Recensements de la population 1968-2021"
  )


