# chargement_prod_biomethane
# production de biométhane injectée sur le réseau de gaz naturel

# on récupère les données préalablement nettoyées dans le cadre du POC ENR TEO dans le SGBD
# script de dataprep : https://gitlab.com/dreal-datalab/enr_reseaux_teo/-/blob/master/collecte/registre_biogaz/registre_biogaz.Rmd


# librairies ----------
library(datalibaba)
library(stringr)
library(dplyr)
library(tidyr)
library(forcats)
library(stringr)
library(readr)
library(purrr)
library(COGiter)
library(lubridate)

rm(list=ls())


# paramètres ----------
mil <- 2022
table <- paste0("indic_biogaz_", mil, "_com_frce_entiere")


# lecture des données versées dans le sgbd/production/gaz dans le cadre du POC ENR TEO -----
prod_biomethane <- importer_data(table = table, schema = "mecc_gaz", db = "production") %>% 
  rename_with(tolower) %>% select(-source)


# mise au format long pour le projet indicateurs territoriaux ------
prod_biomethane2 <- prod_biomethane %>%
  mutate(type = gsub(" |'", "_", tolower(type)) %>%
           gsub("_d_", "_", .) %>% 
           gsub("é", "e", .)) %>% 
  unite(col="indicateur", type, indicateur, sep = ".", remove = TRUE) 

# ajout de l'indicateur 'total'
prod_biomethane3 <- prod_biomethane %>% 
  group_by(depcom, indicateur, annee) %>% 
  summarise(valeur = sum(valeur), .groups = "drop") %>% 
  bind_rows(prod_biomethane2) %>%
  mutate(variable = as.factor(indicateur),
         date = make_date(annee, 12, 31)) %>% 
  select(-annee, -indicateur)

# on complete avec les communes sans installations
prod_biomethane4 <- prod_biomethane3 %>% 
  # le dataset originel porte sur les communes de France continentale exclusivement
    mutate(depcom = as.factor(depcom) %>% fct_expand(as.character(communes$DEPCOM))) %>% 
  # La source ne couvre pas les DOM 
    complete(depcom, date, variable, fill = list(valeur = NA)) %>% 
    pivot_wider(names_from = variable, values_from = valeur)

# Et on vérifie que ça s'est bien passé
# nb_com <- nrow(communes)
# nb_var <- length(levels(prod_biomethane3$variable)) #18
# nb_mil <- n_distinct(prod_biomethane3$date)
# nrow(prod_biomethane4) == (nb_com * nb_mil)


# # # libelle des variables (partie à dé-commenter si changement de dessin de fichier) ------
# lib_var <- data.frame(
#   source = "chargement_prod_biomethane",
#   variable=levels(prod_biomethane3$variable),
#   libelle_variable = "",
#   unite = "",
#   secret = "non")
# write.csv2(lib_var, file = "../../lib_var_biomethane.csv", row.names = FALSE, fileEncoding = "utf-8")


# versement dans le sgbd/datamart.portrait_territoires -------------
source("R/poster_documenter_data.R")
poster_documenter_it(df = prod_biomethane4, nom_table_sgbd = "source_prod_biomethane", 
                     comm_source_en_plus = "")



rm(list=ls())
