
# chargement_prod_elec_renouv

# production électricité renouvelable art 179 ltecv fournies par Enedis

# on récupère les données préalablement nettoyées dans le cadre du POC ENR TEO dans le SGBD
# script de nettoyage : https://gitlab-forge.din.developpement-durable.gouv.fr/dreal-pdl/csd/enr_reseaux_teo/-/blob/master/collecte/production_elec/opendata_Enedis.Rmd"
# datasets Enedis publics très proches https://data.enedis.fr/explore/?sort=modified&refine.keyword=Production+%C3%A9lectrique 

rm(list=ls())

## librairies ----------
library(datalibaba)
library(dplyr)
library(tidyr)
library(forcats)
library(stringr)
library(readr)
library(purrr)
library(COGiter)
library(lubridate)
library(tricky)
library(googlesheets4)
source("R/poster_documenter_data.R")
source("R/poster_documenter_ind.R")


# paramètres ----------
mil <- 2022
reg <- 52
table <- paste0("prod_elec_renouv_2011_", mil, "_r", reg)


# lecture des données versées dans sgbd/production/electricite dans le cadre du POC ENR TEO --------

prod_elec_renouv0 <- importer_data(table = table, db = "production", schema = "mecc_electricite") %>% 
  rename_with(str_standardize) 

# calcul ----------
prod_elec_renouv1 <- prod_elec_renouv0 %>%
  mutate(filiere_de_production = str_standardize(filiere_de_production),
         indicateur = gsub(".", "_", indicateur, fixed = TRUE),
         indicateur = gsub(" ", "_", indicateur, fixed = TRUE),
         indicateur = gsub("_totale_en_", "_", indicateur, fixed = TRUE),
         indicateur = gsub("Nombre_de_sites", "Nb_sites", indicateur, fixed = TRUE),
         ) %>%
  unite(col = "indicateur", indicateur, filiere_de_production, sep = ".", remove = TRUE) %>%
  rename(TypeZone = typezone, CodeZone = codezone) %>% 
  filter(!grepl("ZZZ", CodeZone)) %>%
  mutate(date = make_date(as.character(annee), 12,31)) %>%
  select(-annee) 

# Le df prod_elec_renouv comprend les productions électriques annuelles à toutes les échelles sauf iris depuis 2011.
# Il correspond à la mise aux référentiels géographiques actuels de l'ensemble de la source Enedis. 
# En raison de la manière de gérer le secret, il ne faut pas utiliser les consommations communales pour déduire les consommations supra, 
# mais utiliser directement les consommations agrégées à l'échelle EPCI, département ou région.


# sauvegarde des métadonnées sur l'origine de l'estimation de la production -------
metad_prod_elec_renouv <- select(prod_elec_renouv1, -valeur) %>%
  mutate_if(is.character, as.factor) %>%
  select(TypeZone, CodeZone, date, everything())

save(metad_prod_elec_renouv, file="metadata/metad_prod_elec_renouv.RData")

# mise au format long pour le projet indicateurs territoriaux ---------
# le résultat doit ressembler à ce que produit cogifier
# d'abord on récupère les types de champs (facteurs, dates et autres)
# que le passage via PostgreSql a supprimé
# il faudra vérifier que le jeu de données est complet

zones_r52 <- filter(liste_zone, grepl("52", REG)) %>%
  select(CodeZone, TypeZone, Zone) %>%
  unite(col = "IdZone", CodeZone, TypeZone, sep = "_") %>%
  mutate(across(everything(), fct_drop))

prod_elec_renouv <- prod_elec_renouv1 %>%
  select(-estimation, -type_estimation) %>%
  unite("IdZone", CodeZone, TypeZone) %>%
  mutate_if(is.character, as.factor) %>%
  mutate(IdZone = fct_expand(IdZone, levels(zones_r52$IdZone))) %>%
  complete(IdZone, date, indicateur) %>%
  separate(IdZone, c("CodeZone", "TypeZone"), sep = "_") %>%
  left_join(liste_zone %>% select(CodeZone, TypeZone, Zone), 
            by =  c("CodeZone", "TypeZone")) %>% 
  mutate_if(is.factor, as.character) %>% 
  rename(variable = indicateur) %>%
  pivot_wider(names_from = variable, values_from = valeur)


# versement dans le sgbd/datamart.portrait_territoires + documentation -------------

# doublons - TRUE attendu
prod_elec_renouv %>% 
  dplyr::count(CodeZone, TypeZone, date) %>% 
  dplyr::filter(n>1) %>% 
  nrow() == 0


source("R/poster_documenter_ind.R")
poster_documenter_ind(df = prod_elec_renouv, nom_table_sgbd = "cogifiee_prod_elec_renouv", 
                     comm_source_en_plus = "")

rm(list=ls())
