
# chargement_ptz


# librairies --------------
library(readxl)
library(tidyverse)
library(tricky)
library(lubridate)
library(DBI)
library(RPostgreSQL)
library(datalibaba)
library(googlesheets4)

rm(list = ls())


# chargement et calcul ---------
# chargement des données PTZ (Prêts à Taux Zéro) --------
# fichier cree a partir d une requete geokit 3 :
# "Dossiers publics/geokit3/Regions Pays de la Loire/DREAL/INDICATEURS TER DATA LAB/gk3_ptz"
ptz <-bind_rows(read_excel("extdata/gk3_ptz.xlsx",sheet=1),
                read_excel("extdata/gk3_ptz.xlsx",sheet=2),
                read_excel("extdata/gk3_ptz.xlsx",sheet=3),
                read_excel("extdata/gk3_ptz.xlsx",sheet=4))

names(ptz)<-c("depcom","date","typlog","etatlog","statutlog","valeur")  
ptz$variable<-paste(substr(ptz$typlog,1,1),substr(ptz$etatlog,1,1),substr(ptz$statutlog,1,1),sep="") 
ptz<-ptz %>% 
  select(depcom,date,variable,valeur) %>% 
  complete(date,depcom,variable) %>% 
  mutate_all(funs(ifelse(is.na(.),0,.)))

ptz<-rbind(
  cbind(aggregate(valeur~depcom+date,ptz,sum),variable="nb_ptz.total"),  
  cbind(aggregate(valeur~depcom+date,ptz[ptz$variable>100 & ptz$variable<200,],sum),variable="nb_ptz.individuel"),
  cbind(aggregate(valeur~depcom+date,ptz[ptz$variable>200,],sum),variable="nb_ptz.collectif"),
  cbind(aggregate(valeur~depcom+date,ptz[substr(ptz$variable,2,2)==1,],sum),variable="nb_ptz.ancien"),
  cbind(aggregate(valeur~depcom+date,ptz[substr(ptz$variable,2,2)==2,],sum),variable="nb_ptz.neuf"),
  cbind(aggregate(valeur~depcom+date,ptz[substr(ptz$variable,3,3)==2,],sum),variable="nb_ptz.locataire_autre"),
  cbind(aggregate(valeur~depcom+date,ptz[substr(ptz$variable,3,3)==3,],sum),variable="nb_ptz.proprietaire_ou_autre"),
  cbind(aggregate(valeur~depcom+date,ptz[substr(ptz$variable,3,3)==1,],sum),variable="nb_ptz.locataire_hlm")) %>%
  # filter(date>=2008)%>% 
  mutate(date=make_date(date,12,31))%>% 
  mutate_if(is.character,as.factor) %>% 
  complete(depcom,date,variable,fill = list(valeur = 0)) %>% 
  pivot_wider(names_from = variable,values_from = valeur)


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = ptz,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "source_ptz",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("depcom", "date"), # déclaration d'une clé primaire sur la table postée : on ne doit pas avoir deux lignes avec à la fois le même code commune et la meme date
            user = "does")

# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(ptz), c("depcom", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()



## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "depcom", "Code INSEE de la commune",
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, table = "source_ptz", schema = "portrait_territoires",
               db = "datamart", user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table) %>%
  # ajout de complement sur la généalogie
  paste0(".\n", "Chargement des donn\u00e9es sur Geokit3")

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "source_ptz", 
                user = "does")

