
# chargement_reseaux_chaleur

# indicateur CRTE : existence de réseaux de chaleurs, ainsi que leur combustible (part d'énergie renouvelable)

# librairies ----------
library(tidyverse)
library(COGiter)
library(lubridate)
library(datalibaba)
library(googlesheets4)
library(sf)

rm(list = ls())


# Chargement des données depuis SGBD/production/reseaux_chaleur -----------

RC0 <- importer_data(table = "reseaux_chaleur_2019_r52", schema = "reseaux_chaleur", db = "production") %>% 
  mutate(type_mix = as.factor(type_mix)) %>% 
  st_drop_geometry

# chargement des communes de la réunion pour rendre le jeus de données communal exhaustif -----
com_pdl <- filter(communes, REG == "52") %>% 
  transmute(DEPCOM = fct_drop(DEPCOM))

com_limit <-  filter(communes, grepl("52", REGIONS_DE_L_EPCI)) %>% 
  transmute(DEPCOM = fct_drop(DEPCOM))


# calcul des agrégats à la commune ---------
indic_RC <- group_by(RC0, DEPCOM, type_mix) %>% 
  summarise(nb_rc = n(), .groups = "drop") %>% 
  pivot_wider(names_from = type_mix,  names_prefix = "nb_rc_",   values_from = nb_rc) %>% 
  full_join(com_pdl, by = "DEPCOM") %>% 
  arrange(DEPCOM) %>% 
  rename(nb_rc_enr_pur = 'nb_rc_100% EnR',
         nb_rc_recup = 'nb_rc_récupération',
         nb_rc_mix_inconnu = nb_rc_inconnu) %>% 
  mutate(across(everything(), ~replace_na(.x, 0))) %>% 
  # tip : names(indic_RC[,2:6]) %>% paste0(collapse = " + ")
  mutate(depcom = as.factor(DEPCOM),
         date = make_date(2018, 12, 31),
         nb_rc = nb_rc_mixte + nb_rc_enr_pur + nb_rc_fossile + nb_rc_mix_inconnu + nb_rc_recup,
         nb_rc_enrr_et_mixtes = nb_rc_mixte + nb_rc_enr_pur + nb_rc_recup) %>% 
  select(-DEPCOM) %>% 
  pivot_longer(names_to = "variable", values_to = "valeur", cols = starts_with("nb_rc"), 
               names_transform = list(variable = as.factor))


# # libelle des variables (A ne lancer que si les variables ont changé) ------
# lib_var <- data.frame(
#   source = "chargement_reseaux_chaleur",
#   variable=levels(indic_RC$variable),
#   libelle_variable = c("Nombre de réseaux de chaleur",
#                        "Nombre de réseaux de chaleur à 100 % renouvelable",
#                        "Nombre de réseaux de chaleur partiellement ENR&R",
#                        "Nombre de réseaux de chaleur aux combustibles purement fossiles",
#                        "Nombre de réseaux de chaleur au mix énergétique fossiles",
#                        "Nombre de réseaux de chaleur au mix énergétique mêlant énergies renouvelables, énergies de récupération et énergies fossiles",
#                        "Nombre de réseaux de chaleur alimentés par des énergies de récupération (UIOM, chaleur fatale...)"),
#   unite = "",
#   secret = "non")
# 
# # write_csv2(lib_var, file = ".Rproj.user/indicateurs_RC.csv")



indic_RC2 <- indic_RC %>% 
  complete(depcom, date, variable, fill = list(valeur = 0)) %>% 
  pivot_wider(names_from = variable, values_from = valeur) %>% 
  mutate(depcom = fct_expand(depcom, levels(com_limit$DEPCOM))) %>% 
  complete(depcom, date, fill = list(valeur = NA_integer_)) 

# versement dans le sgbd/datamart.portrait_territoires et documentation-------------

source("R/poster_documenter_data.R")
poster_documenter_it(df = indic_RC2, nom_table_sgbd = "source_reseaux_chaleur", comm_source_en_plus = "")



rm(list=ls())

