# chargement_lgt_rp_insee

# 2020 --> https://www.insee.fr/fr/statistiques/7631446?sommaire=7631713
# https://www.insee.fr/fr/statistiques/fichier/7631446/TD_PRINC2_2020_csv.zip
# paru le 27/06/2023


# librairies ----------
library(tidyverse)
library(lubridate)
library(datalibaba)
library(dplyr)
# library(googlesheets4)

rm(list = ls())

# chargement data -------
download.file(url = "https://www.insee.fr/fr/statistiques/fichier/7631446/TD_PRINC2_2020_csv.zip",
              destfile = "extdata/TD_PRINC2_2020_csv.zip")
unzip("extdata/TD_PRINC2_2020_csv.zip", overwrite = TRUE, exdir = "extdata")


# chargement data annees precedentes -------
load("extdata/statut_occupation_des_rp.RData")
# statut_occupation_des_rp <- importer_data(db = "datamart",
#                                  schema = "portrait_territoires",
#                                  table = "source_statut_occupation_des_rp")
statut_occupation_des_rp_old <- statut_occupation_des_rp
rm(statut_occupation_des_rp)

# chargement du nouveau millésime

millesime = 2020

# path <- paste0("extdata/BTT_TD_PRINC2_",millesime,".txt") #pour les années jusque 2016
# path <- paste0("extdata/BTT_TD_PRINC2_",millesime,".csv") #pour les années 2017 à 2019
path <- paste0("extdata/TD_PRINC2_",millesime,".csv") # à partir de 2020

statut_occupation_des_rp0 <- read.csv2(path,
                    dec='.', 
                    header = TRUE, 
                    sep=";", 
                    stringsAsFactors = FALSE,
                    encoding = "UTF-8") %>%
  mutate( NB = as.numeric(gsub(pattern=",",replacement='.', x=NB))) %>% #ligne ajoutée pour l'import de 2009 à 2011
  # rename(NIVGEO = NIVEAU,     #lignes ajoutée pour l'import de 2009 à 2010
  #          NBPIR = C_NBPIC,
  #        STOCD = C_STOCD) %>% 
  filter(NIVGEO == "COM") %>%
  select (-NIVGEO , -LIBGEO) %>%
  # select (-NIVGEO , -REG, -DEP, -EPCI) %>%  #utilisé pour 2009
  # select (-NIVGEO , -REG, -DEP) %>%  #utilisé pour 2010
  mutate(STOCD = replace(STOCD, STOCD == "23", "21"),    #regroupement des locataires de logements non HLM
         NBPIR = replace(NBPIR, NBPIR == "2", "1"),      #regroupement des 1 pièce et 2 pièces
         NBPIR = replace(NBPIR, NBPIR == "4", "3"),      #regroupement des 3 pièces et 4 pièces
         NBPIR = replace(NBPIR, NBPIR == "6", "5")) %>%       #regroupement des 5 pièces et 6 pièces
  mutate(date = make_date(millesime, 12, 31)) %>%
  rename(depcom = CODGEO) 

statut_occupation_des_rp1 <- statut_occupation_des_rp0 %>% 
  group_by(depcom,date, NBPIR, STOCD) %>%
  summarise(valeur = sum(NB, na.rm=T)) %>%
  ungroup() %>%   
  mutate(variable = paste(STOCD, NBPIR)) %>%
  mutate(variable = replace(variable, variable == "10 1", "nb_rp_proprietaire_1a2_pieces"),
         variable = replace(variable, variable == "10 3", "nb_rp_proprietaire_3a4_pieces"),
         variable = replace(variable, variable == "10 5", "nb_rp_proprietaire_5_pieces_et_plus"),
         variable = replace(variable, variable == "21 1", "nb_rp_locataire_non_hlm_1a2_pieces"),
         variable = replace(variable, variable == "21 3", "nb_rp_locataire_non_hlm_3a4_pieces"),
         variable = replace(variable, variable == "21 5", "nb_rp_locataire_non_hlm_5_pieces_et_plus"),
         variable = replace(variable, variable == "22 1", "nb_rp_locataire_hlm_1a2_pieces"),
         variable = replace(variable, variable == "22 3", "nb_rp_locataire_hlm_3a4_pieces"),
         variable = replace(variable, variable == "22 5", "nb_rp_locataire_hlm_5_pieces_et_plus"),         
         variable = replace(variable, variable == "30 1", "nb_rp_gratuit_1a2_pieces"),
         variable = replace(variable, variable == "30 3", "nb_rp_gratuit_3a4_pieces"),
         variable = replace(variable, variable == "30 5", "nb_rp_gratuit_5_pieces_et_plus")) %>%  
  select (depcom, date, variable, valeur) %>%  
  complete(depcom, date, variable, fill = list(valeur = 0))

statut_occupation_des_rp2 <- statut_occupation_des_rp0 %>% 
  group_by(depcom,date, TYPLR, STOCD) %>%
  summarise(valeur = sum(NB, na.rm=T)) %>%
  ungroup() %>%   
  mutate(variable = paste(STOCD, TYPLR)) %>%
  mutate(variable = replace(variable, variable == "21 1", "nb_rp_locataire_non_hlm_maison"),
         variable = replace(variable, variable == "21 2", "nb_rp_locataire_non_hlm_appartement"),
         variable = replace(variable, variable == "21 3", "nb_rp_locataire_non_hlm_autre"),
         variable = replace(variable, variable == "22 1", "nb_rp_locataire_hlm_maison"),
         variable = replace(variable, variable == "22 2", "nb_rp_locataire_hlm_appartement"),
         variable = replace(variable, variable == "22 3", "nb_rp_locataire_hlm_autre"),         
         variable = replace(variable, variable == "10 1", "nb_rp_proprietaire_maison"),
         variable = replace(variable, variable == "10 2", "nb_rp_proprietaire_appartement"),
         variable = replace(variable, variable == "10 3", "nb_rp_proprietaire_autre"),
         variable = replace(variable, variable == "30 1", "nb_rp_gratuit_maison"),
         variable = replace(variable, variable == "30 2", "nb_rp_gratuit_appartement"),
         variable = replace(variable, variable == "30 3", "nb_rp_gratuit_autre")) %>%  
  select (depcom, date, variable, valeur) %>%  
  complete(depcom, date, variable, fill = list(valeur = 0))

statut_occupation_des_rp <- bind_rows(statut_occupation_des_rp1,statut_occupation_des_rp2) %>% 
  pivot_wider(names_from = variable, values_from = valeur)

statut_occupation_des_rp <- bind_rows(statut_occupation_des_rp_old,statut_occupation_des_rp) %>% 
  distinct()

save(statut_occupation_des_rp,file="extdata/statut_occupation_des_rp.RData")


# versement dans le sgbd/datamart.portrait_territoires et metadonnées -------------
source("R/poster_documenter_data.R", encoding = "UTF-8")
poster_documenter_it(df = statut_occupation_des_rp ,
                     nom_table_sgbd = "source_statut_occupation_des_rp", 
                     comm_source_en_plus = "")

rm(list = ls())
