
# chargement_territoire_engage_pour_la_nature
# liste des territoires engagés disponibles sur https://engagespourlanature.ofb.fr/territoires/engagements

# librairies ----------
library(readxl)
library(COGiter)
library(dplyr)
library(forcats)
library(tidyverse)
library(lubridate)
library(DBI)
library(RPostgreSQL)
library(datalibaba)
library(googlesheets4)

rm(list=ls())


# chargement et calcul ------------
epci52<-epci %>%
  filter( grepl("52", REGIONS_DE_L_EPCI)) %>% 
  mutate(EPCI=as.character(EPCI)) %>%
  pull(EPCI)

engage_pour_la_nature <- read_excel("extdata/label_territoire_engage_pour_la_nature.xlsx") %>%
  select(EPCI,annee_mise_a_jour) %>%
  rename(date = annee_mise_a_jour) %>%
  mutate(date=make_date(date,06,30))%>%
  mutate(variable = "engage_pour_la_nature" , valeur = "Oui") %>%
  mutate( EPCI=as.character(EPCI)) %>%
  mutate(EPCI = fct_expand(EPCI, epci52)) %>%  
  complete(EPCI,date,variable, fill = list( valeur = "Non")) %>%
  mutate_if(is.character,as.factor) %>% 
  pivot_wider(names_from = variable,values_from = valeur)


# # versement dans le sgbd/datamart.portrait_territoires -------------
# drv <- dbDriver("PostgreSQL")
# con_datamart <- dbConnect(drv, 
#                           dbname="datamart", 
#                           host=Sys.getenv("server"), 
#                           port=Sys.getenv("port"),
#                           user=Sys.getenv("userid"),
#                           password=Sys.getenv("pwd_does"))
# postgresqlpqExec(con_datamart, "SET client_encoding = 'windows-1252'")
# 
# dbWriteTable(con_datamart, c("portrait_territoires","ref_engage_pour_la_nature"),
#              engage_pour_la_nature, row.names=FALSE, overwrite=TRUE)
# 
# dbDisconnect(con_datamart)
# 
# rm(list=ls())


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = engage_pour_la_nature,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "ref_engage_pour_la_nature",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("EPCI", "date"), # déclaration d'une clé primaire sur la table postée : on ne doit pas avoir deux lignes avec à la fois le même code commune et la meme date
            user = "does")

# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(engage_pour_la_nature), c("EPCI", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- "ref_territoire_engage_pour_la_nature"

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()



## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "EPCI", "Code INSEE de l'EPCI",
      "date", "date de mise à jour des données"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, table = "ref_engage_pour_la_nature", schema = "portrait_territoires",
               db = "datamart", user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table) %>%
  # ajout de complement sur la généalogie
  paste0(".\n", "Chargement des donn\u00e9es sur https://engagespourlanature.ofb.fr/territoires/engagements")

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "ref_engage_pour_la_nature", 
                user = "does")


