
# indicateur_basemis
rm(list = ls())


# librairies -----------
library(dplyr)
library(tidyr)
library(COGiter)
library(purrr)
library(datalibaba)
source("R/poster_documenter_ind.R")


# Chargement des données basemis cogifiées ---------
cogifiee_basemis <- importer_data(table = "cogifiee_basemis", schema = "portrait_territoires", db = "datamart", user = "does") %>% 
  pivot_longer(cols = where(is.numeric),
               names_to = "variable",
               values_to = "valeur")


# correction des données basemis pour epci interregionaux--------------
epci_interreg <- mutate(epci, regions = map_chr(REGIONS_DE_L_EPCI, ~unlist(.x) %>% length)) %>%
  filter(regions > 1, grepl("52", REGIONS_DE_L_EPCI)) %>%
  pull(EPCI) %>% as.character()

indic_basemis0 <- cogifiee_basemis %>%
  filter(grepl("conso_ktep.resid|ges_sc1_teqco2.agri|utcf", variable), TypeZone != "Communes", date==max(date)) %>%
  mutate(variable = case_when(grepl("conso_ktep.resid", variable) ~ "conso_ktep.resid",
                              grepl("ges_sc1_teqco2.agri", variable) ~ "ges_sc1_teqco2.agri",
                              grepl("ges_sc1_teqco2.utcf.non_energetiq", variable) ~ "ges_sc1_teqco2.utcf",
                              TRUE ~ as.character(variable)),
         valeur = if_else(CodeZone %in% epci_interreg, NA_real_, valeur)) %>%
  group_by(across(-valeur)) %>%
  summarise(valeur = sum(valeur), .groups = "drop") %>%
  pivot_wider(names_from = variable, values_from = valeur) %>%
  ungroup()

rm(epci_interreg, cogifiee_basemis)

# chargement surface des territoires ---------
surf <- importer_data(table = "cogifiee_superficie_territoires", schema = "portrait_territoires", db = "datamart", user = "does") %>% 
  select(-Zone, -date)

# chargement population ----------------
pop <- importer_data(table = "cogifiee_pop_rgp_insee", schema = "portrait_territoires", db = "datamart", user = "does") %>% 
  filter(TypeZone != "Communes", date == max(date)) %>%
  select(TypeZone, CodeZone, pop.ttage.cs0)

# calcul indicateur------------------
indic_basemis <- left_join(indic_basemis0, surf, by = c("TypeZone", "CodeZone")) %>%
  left_join(pop, by = c("TypeZone", "CodeZone")) %>%
  group_by(TypeZone) %>% 
  mutate(utcf_teqco2_par_km2 = ges_sc1_teqco2.utcf / aire_du_territoire_en_m2 * 1000000,
         enjeu_utcf = utcf_teqco2_par_km2 > quantile(utcf_teqco2_par_km2, 0.75, na.rm = TRUE, names = FALSE),
         conso_lgt_mwh_par_hab = conso_ktep.resid * 11630 / pop.ttage.cs0,
         enjeu_conso_lgt = (conso_lgt_mwh_par_hab > (quantile(conso_lgt_mwh_par_hab, 0.75, na.rm = T, names=F)-1) %>% round(digits = 0)) &
           (conso_ktep.resid > (quantile(conso_ktep.resid, 0.75, na.rm = T, names=F)-10) %>% round(digits = -1)), 
         # comprends pas pourquoi all() ne donne pas les mêmes résultats
         enjeu_ges_agri = ges_sc1_teqco2.agri > quantile(ges_sc1_teqco2.agri, 0.75, na.rm = T, names=F)) %>%
  ungroup() %>% 
  select(-pop.ttage.cs0, -aire_du_territoire_en_m2) %>%
  # garder les variables d'enjeu pour les départements, la région ? 
  mutate(across(starts_with("enjeu"), ~if_else(TypeZone %in% c("Régions", "Départements"), NA, .x)))

# chargement des indicateurs calculés et des commentaires
poster_documenter_ind(df = indic_basemis, nom_table_sgbd = "indicateur_basemis", 
                      nom_script_sce = "indicateur_basemis", comm_source_en_plus = "")

rm(list=ls())
