
# indicateur_dph_reno_lls

rm(list=ls())

# librairies -----------
library(tidyverse)
library(datalibaba)
source("R/poster_documenter_ind.R")


# chargement data -------------
cogifiee_dph_reno_lls <- importer_data(db = "datamart", schema = "portrait_territoires", table = "cogifiee_dph_reno_lls", user = "does")
cogifiee_dph_reno_lls <- pivot_longer(cogifiee_dph_reno_lls, cols = where(is.numeric),
                                      names_to = "variable", values_to = "valeur")

indicateur_rpls <- importer_data(db = "datamart", schema = "portrait_territoires", table = "indicateur_rpls", user = "does") 
indicateur_rpls <- pivot_longer(indicateur_rpls, cols = where(is.numeric),
                                names_to = "variable", values_to = "valeur")


# calcul ------------
passoires_com <- indicateur_rpls %>%
  filter(date == "2015-01-01", variable == "nb_logements_sociaux_passoires_thermiques") %>%
  select(contains("Zone"), nb_logements_sociaux_energivores=valeur)

indicateur_dph_reno_lls <- cogifiee_dph_reno_lls %>%
  as_tibble() %>% 
  separate(variable, into = c("indic", "type_org"), sep="\\.") %>%
  group_by(TypeZone, CodeZone, Zone, indic, date) %>%
  summarise(valeur = sum(valeur, na.rm = TRUE)) %>%
  arrange(TypeZone, CodeZone, Zone, indic, date) %>%
  mutate(valeur = cumsum(valeur)) %>%  # pour passer de données de flux annuels de renovation aux données de stocks
  ungroup %>% 
  filter(indic != "n_org") %>%    # il y a surement des doubles comptes entre les années, il aurait fallu s'y prendre autrement si l'indicateur était important
  spread(indic, valeur) %>%
  left_join(passoires_com) %>%
  mutate(nb_logements_sociaux_energivores = replace_na(nb_logements_sociaux_energivores, 0),
         gain_nrj_m2 = gain_nrj/surf, 
         lgts_rehab_sur_lgts_EFG = if_else(nb_logts==0, nb_logts, nb_logts/nb_logements_sociaux_energivores*100)) %>%
  select(-nb_logements_sociaux_energivores) %>%
  mutate_if(is.factor, as.character)


# versement dans le sgbd/datamart.portrait_territoires et doc-------------
poster_documenter_ind(df = indicateur_dph_reno_lls, nom_table_sgbd = "indicateur_dph_reno_lls", 
                      nom_script_sce = "indicateur_dph_reno_lls", comm_source_en_plus = "")

rm(list=ls())

