
# indicateur_eptb

# librairies ---------
library(googlesheets4)
library(tidyverse)
library(dplyr)
library(tidyr)
library(DBI)
library(RPostgreSQL)
library(datalibaba)

rm(list=ls())


secretise_eptb <- importer_data(db = "datamart",
                             schema = "portrait_territoires",
                             table = "secretise_eptb")


# calcul -----------
indicateur_eptb<-secretise_eptb %>%
  mutate(cout_global_moyen_constructions_neuves_de_particuliers = round((prix_total_des_maisons_en_euros_avec_terrain_achete + prix_total_des_terrains_en_euros) /nombre_de_terrains_achetes ,digits = 1)) %>%
  mutate(cout_moyen_maison_par_m2_pour_constructions_neuves_individuelle = round(prix_total_des_maisons_en_euros / surface_totale_des_maisons_en_m2,digits = 1)) %>%
  mutate(cout_moyen_maison_pour_constructions_neuves_individuelles = round(prix_total_des_maisons_en_euros / nombre_de_maisons_terrain_achete_ou_non,digits = 1)) %>%
  mutate(cout_moyen_terrain_par_m2_pour_constructions_neuves_individuell = round(prix_total_des_terrains_en_euros / superficie_totale_des_terrains_achetes_en_m2,digits = 1))%>%
  mutate(cout_moyen_terrain_pour_constructions_neuves_individuelles = round(prix_total_des_terrains_en_euros / nombre_de_terrains_achetes,digits = 1)) %>%
  mutate(superficie_moyenne_des_terrains_achetes = round(superficie_totale_des_terrains_achetes_en_m2 / nombre_de_terrains_achetes,digits = 1)) %>%
  mutate(surface_moyenne_des_maisons_construites = round(surface_totale_des_maisons_en_m2 / nombre_de_maisons_terrain_achete_ou_non,digits = 1)) %>%
  mutate(part_du_terrain_dans_le_cout_total_du_projet = round(prix_total_des_terrains_en_euros / (prix_total_des_maisons_en_euros_avec_terrain_achete + prix_total_des_terrains_en_euros)*100,digits = 1)) %>%
  select(-c(nombre_d_observations_non_pondere:surface_totale_des_maisons_en_m2)) %>%
  mutate_if(is.factor, as.character)


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = indicateur_eptb,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "indicateur_eptb",
            pk = c("TypeZone", "Zone", "CodeZone", "date"),
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            user = "does")

# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(indicateur_eptb), c("TypeZone", "Zone" , "CodeZone" , "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()



## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "TypeZone", "Type de territoire",
      "Zone", " Nom du territoire",
      "CodeZone", "Code INSEE du territoire",
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, table = "indicateur_eptb", schema = "portrait_territoires",
               db = "datamart", user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table) %>%
  # ajout de complement sur la généalogie
  paste0(".\n", "Chargement des donn\u00e9es sur Geokit3")

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "indicateur_eptb", 
                user = "does")
