
# indicateur_fichier_foncier_etalement_urbain

library(magrittr)

rm(list = ls())

# variables et identifiants de connexion ----------
base <- "datamart"
schema <- "portrait_territoires"
tab1 <- "cogifiee_fichier_foncier_artificialisation"
tab2 <- "cogifiee_population_legale"
tab_indicateur <- "indicateur_ff_etalement_urbain"


# chargement des datamarts cogifiés ---------
fichier_foncier_artificialisation <- datalibaba::importer_data(
  db = base,
  schema = schema,
  table = tab1
  )
# unique(fichier_foncier_artificialisation$date)
# [1] "2016-01-01" "2018-01-01" "2017-01-01" "2019-01-01" "2020-01-01" "2021-01-01" "2022-01-01" "2023-01-01"

population_legale <- datalibaba::importer_data(
  db = base,
  schema = schema,
  table = tab2
  )
# unique(population_legale$date)
# [1] "1968-01-01" "1975-01-01" "1982-01-01" "1990-01-01" "1999-01-01" "2006-01-01" "2007-01-01" "2008-01-01" "2009-01-01"
# [10] "2010-01-01" "2011-01-01" "2012-01-01" "2013-01-01" "2014-01-01" "2015-01-01" "2016-01-01" "2017-01-01" "2018-01-01"
# [19] "2019-01-01" "2020-01-01" "2021-01-01"

# calcul de l'indicateur -----------
indicateur_fichierfoncier_etalementurbain <- function(date_pop_max, population_legale, fichier_foncier_artificialisation){
  date_pop_min = date_pop_max - 5 + 1
  date_ff_artif_max = date_pop_max + 1
  date_ff_artif_min = (date_pop_max + 1) - 5 + 1
  
  evol_pop <- population_legale %>%
    dplyr::filter(lubridate::year(date) %in% c(date_pop_min, date_pop_max)) %>%
    dplyr::arrange(TypeZone, CodeZone, date) %>% 
    dplyr::group_by(TypeZone, Zone, CodeZone) %>% 
    dplyr::mutate(taux_evo_pop = (population_municipale-lag(population_municipale))*100/lag(population_municipale)) %>% 
    dplyr::ungroup() %>% 
    dplyr::filter(lubridate::year(date) == date_pop_max) 
  
  evol_artif <- fichier_foncier_artificialisation %>%
    dplyr::filter(lubridate::year(date) %in% c(date_ff_artif_min, date_ff_artif_max)) %>%
    dplyr::arrange(TypeZone, CodeZone, date) %>% 
    dplyr::group_by(TypeZone, Zone, CodeZone) %>% 
    dplyr::mutate(
      taux_evo_artif = (surf_artificialisee - dplyr::lag(surf_artificialisee))*100/dplyr::lag(surf_artificialisee)
      ) %>% 
    dplyr::ungroup() %>% 
    dplyr::filter(lubridate::year(date) == date_ff_artif_max) 
  
  indicateur_ff_etalement_urbain <- dplyr::left_join(
    evol_artif, 
    evol_pop %>% dplyr::select(-date)
    ) %>% 
    dplyr::mutate(indicateur_etalement_urbain = dplyr::case_when(
      taux_evo_artif < 0 & taux_evo_pop >= 0 ~ "classe 1",
      taux_evo_artif >= 0 & taux_evo_pop >= 0 & taux_evo_pop >=  taux_evo_artif ~ "classe 2a",
      taux_evo_artif <= 0 & taux_evo_pop < 0 & taux_evo_pop <= taux_evo_artif ~ "classe 2b",
      taux_evo_artif < 0 & taux_evo_pop < 0 & taux_evo_pop > taux_evo_artif ~ "classe 2c",
      taux_evo_pop >= 0 & taux_evo_pop < taux_evo_artif ~ "classe 3",
      taux_evo_artif > 0 & taux_evo_pop < 0 ~ "classe 4") %>%
        as.factor()
      ) %>% 
    dplyr::select(TypeZone, Zone, CodeZone, date, indicateur_etalement_urbain)
}

indicateur_ff_etalement_urbain_2022 <- indicateur_fichierfoncier_etalementurbain(
  2021, 
  population_legale, fichier_foncier_artificialisation
)
indicateur_ff_etalement_urbain_2021 <- indicateur_fichierfoncier_etalementurbain(
  2020, 
  population_legale, fichier_foncier_artificialisation
  )
indicateur_ff_etalement_urbain_2020 <- indicateur_fichierfoncier_etalementurbain(
  2019, 
  population_legale, fichier_foncier_artificialisation
  )
indicateur_ff_etalement_urbain <- dplyr::bind_rows(
  indicateur_ff_etalement_urbain_2022,
  indicateur_ff_etalement_urbain_2021, 
  indicateur_ff_etalement_urbain_2020
  )

# versement dans le sgbd/datamart.portrait_territoires et metadonnées -------------
comm_table <- paste0(
  "Indicateur d'étalement urbain\nrecours à la table ",base,".",schema,".",tab1, "\nrecours à la table ",base,".",schema,".",tab2
  )

source("R/poster_documenter_ind.R")
poster_documenter_ind(
  df = indicateur_ff_etalement_urbain,
  nom_table_sgbd = "indicateur_ff_etalement_urbain",
  nom_script_sce = "indicateur_fichier_foncier_etalement_urbain",
  comm_source_en_plus = comm_table
  )

rm(list=ls())
