
# indicateur_lgt_rgp_insee

# librairies ---------
library(tidyverse)
library(datalibaba)

rm(list=ls())


# chargement data ---------------
cogifiee_lgt_rgp_insee <- importer_data(table = "cogifiee_lgt_rgp_insee",
                                  schema = "portrait_territoires",
                                  db = "datamart",
                                  user = "does")

# calcul -------
indicateur_lgt_rgp_insee0 <- cogifiee_lgt_rgp_insee %>%
  mutate(autres_logt = log - (maison + appart)) %>%
  mutate(part_rp = if_else(log == 0 , NA, round(rp / log *100,digits = 1))) %>%
  mutate(part_rs = if_else(log == 0 , NA, round(rsecocc / log *100,digits = 1))) %>% 
  mutate(part_logvac = if_else(log == 0 , NA, round(logvac / log *100,digits = 1))) %>%
  mutate(part_appart = if_else(log == 0 , NA, round(appart / log *100,digits = 1))) %>%
  mutate(part_maison = if_else(log == 0 , NA, round(maison / log *100,digits = 1))) %>%
  mutate(part_autres_logt = if_else(log == 0 , NA, round(autres_logt / log *100,digits = 1))) %>%
  # mutate(log2 =appart+maison)  %>%
  mutate(somme_pieces=rp.1p+rp.2p+rp.3p+rp.4p+rp.5pp ,
         part_rp_1_2_pieces = round((rp.1p + rp.2p)/somme_pieces *100,digits = 1),
         part_rp_3_4_pieces = round((rp.3p + rp.4p)/somme_pieces *100,digits = 1),
         part_rp_5_pieces_et_plus = round( rp.5pp /somme_pieces *100,digits = 1),
         part_PO_des_rp = round( rp.prop /rp *100,digits = 1)) %>% 
      select(TypeZone, Zone, CodeZone, date,autres_logt, part_rp,part_rs,part_logvac,part_appart,part_maison,part_autres_logt,rp,part_rp_1_2_pieces,part_rp_3_4_pieces,part_rp_5_pieces_et_plus,part_PO_des_rp) %>%
  mutate_if(is.factor, as.character) 

indicateur_lgt_rgp_insee1 <- indicateur_lgt_rgp_insee0 %>% 
  # select(TypeZone, Zone, CodeZone, date, part_rp,part_rs,part_logvac) %>% 
  arrange(TypeZone, Zone, CodeZone,date)%>% 
  group_by(TypeZone, Zone, CodeZone) %>% 
  mutate(evol_part_rp_depuis_dern_mill = part_rp - lag(part_rp),
         evol_part_rs_depuis_dern_mill = part_rs - lag(part_rs),
         evol_part_logvac_depuis_dern_mill = part_logvac - lag(part_logvac)) %>%
  # calcul de l evolution annuelle du nb de ménages
  # soit y la valeur de la derniere année, x celle de la premiere année, n le nombre d'années
  # exemple y= 220 en 2019, x= 200 en 2008, n = 2019-2008=11
  # y= x * a^11 (puissance 11) d'où a= racine 11e de y/x qui s'écrit aussi a= (y/x)^(1/n)
  # dans l'exemple, on a  a=(220/200)^(1/11) = 1,0087 d'où une augmentation annuelle de 0,87%
  mutate(annee= year(date),
         nb_annees = annee - lag(annee,1),
         evol_moy_ann_nb_menages = round((((rp / lag(rp,1))^(1/nb_annees))-1)*100,2)
  ) %>%
  select (-rp,-annee,-nb_annees) %>%
  ungroup()

indicateur_lgt_rgp_insee <- indicateur_lgt_rgp_insee1 %>%
  arrange(TypeZone, Zone, CodeZone,date)%>% 
  group_by(TypeZone, Zone, CodeZone) %>% 
  mutate(evol_part_po_depuis_dern_mill = part_PO_des_rp - lag(part_PO_des_rp)) %>% 
  ungroup()

# versement dans le sgbd/datamart.portrait_territoires et metadonnées -------------
source("R/poster_documenter_ind.R", encoding = "UTF-8")
poster_documenter_ind(df = indicateur_lgt_rgp_insee,
                      nom_table_sgbd = "indicateur_lgt_rgp_insee",
                      comm_source_en_plus = "")

rm(list=ls())

