
# indicateur_logt_renove_anah

# indicateurs Habiter mieux Anah du kit data PCAET
# gain_nrj_moy      	Gain énergétique moyen des rénovations de l’année (recalcul pour échelles supra communales, indicateur non additif)
# gain_nrj_moy_cumul	Gain énergétique moyen des rénovations effectuées depuis 2012
# cumul_lgts_subv	    Nombre de rénovations habiter mieux effectuées (cumul depuis 2012)
# tx_logt_renov	      Proportion de logements rénovés (Nb total de rénovations rapporté aux nombre de lgts énergivores)             

rm(list = ls())

# librairies -------
library(dplyr)
library(tidyr)
library(forcats)
library(datalibaba)
source("R/poster_documenter_ind.R")


# chargement data ----------


indicateur_prec_nrj0 <- importer_data(table = "indicateur_prec_nrj", schema = "portrait_territoires", db = "datamart", user = "does")

indicateur_prec_nrj <- pivot_longer(indicateur_prec_nrj0, cols = c(where(is.numeric), where(is.logical)),
                                    names_to = "variable", values_to = "valeur")

cogifiee_logt_renove_anah <- importer_data(table = "cogifiee_logt_renove_anah", schema = "portrait_territoires", db = "datamart", user = "does")


# calcul ----------
passoires <- indicateur_prec_nrj %>%
  filter(variable == "nb_lgt_FGH") %>%
  select(-date, -variable) %>%
  rename(nb_lgt_FGH = valeur)

indicateur_logt_renove_anah <- cogifiee_logt_renove_anah %>% 
  left_join(passoires) %>% 
  mutate(gain_nrj_moy = if_else(nb_lgts_subv == 0, 0, gain_nrj_moy_pond / nb_lgts_subv)) %>%
  group_by(TypeZone, Zone, CodeZone) %>%
  arrange(date) %>%
  mutate(gain_nrj_moy_cumul = if_else(cumsum(nb_lgts_subv) == 0, 0, cumsum(gain_nrj_moy * nb_lgts_subv) / cumsum(nb_lgts_subv)),
         cumul_lgts_subv = cumsum(nb_lgts_subv),
         tx_logt_renov = cumsum(nb_lgts_subv) / nb_lgt_FGH * 100) %>%
  select(-nb_lgt_FGH, -gain_nrj_moy_pond, -nb_lgts_subv) %>% 
  ungroup() %>% 
  mutate_if(is.factor, as.character) 


# chargement dans le SGBD des indicateurs calculés et des commentaires
poster_documenter_ind(df = indicateur_logt_renove_anah, nom_table_sgbd = "indicateur_logt_renove_anah", 
                      comm_source_en_plus = "", nom_script_sce = "indicateur_logt_renove_anah")

rm(list=ls())

