
# indicateur_observatoire_artificialisation_population_legale

library(magrittr)

rm(list = ls())

# variables et identifiants de connexion ----------
base <- "datamart"
schema <- "portrait_territoires"
tab1 <- "cogifiee_observatoire_artificialisation"
tab2 <- "cogifiee_population_legale"
tab_indicateur <- "indicateur_observatoire_artificialisation_population_legale" 


# chargement des données cogifiees -------------
observatoire_artificialisation <- datalibaba::importer_data(db = base, schema = schema, table = tab1)
# unique(observatoire_artificialisation$date)
# [1] "2010-01-01" "2011-01-01" "2012-01-01" "2013-01-01" "2014-01-01" "2015-01-01" "2016-01-01" "2017-01-01" "2018-01-01" "2019-01-01"
# [11] "2020-01-01" "2021-01-01" "2022-01-01"

population_legale <- datalibaba::importer_data(db = base, schema = schema, table = tab2)
# unique(population_legale$date)
# [1] "1968-01-01" "1975-01-01" "1982-01-01" "1990-01-01" "1999-01-01" "2006-01-01" "2007-01-01" "2008-01-01" "2009-01-01" "2010-01-01"
# [11] "2011-01-01" "2012-01-01" "2013-01-01" "2014-01-01" "2015-01-01" "2016-01-01" "2017-01-01" "2018-01-01" "2019-01-01" "2020-01-01"
# [21] "2021-01-01"

# superficie
territoires <- datalibaba::importer_data(
  db = base, 
  schema = schema, 
  table = "cogifiee_superficie_territoires"
  ) %>% 
  dplyr::select(CodeZone, TypeZone, SurfaceZone = aire_du_territoire_en_m2)

# calcul de l'indicateur -----------
population_legale_2 <- population_legale %>%
  dplyr::mutate(dplyr::across(tidyselect::where(is.factor), as.character)) %>%
  dplyr::filter(date >= "2006-01-01") %>%
  dplyr::group_by(TypeZone, CodeZone) %>% 
  dplyr::mutate(
    diff_population_legale_5ans = population_municipale - dplyr::lag(population_municipale, 5),
    lag5_population_legale = dplyr::lag(population_municipale, 5)
    ) %>%
  dplyr::ungroup() %>% 
  dplyr::filter(!is.na(lag5_population_legale)) %>%
  dplyr::select(-c(population_municipale, lag5_population_legale))

observatoire_artificialisation_2 <- observatoire_artificialisation %>% 
  dplyr::mutate_if(is.factor, as.character) %>%
  dplyr::select(dplyr::contains("Zone"), date, flux_naf_artificialisation_total) %>% 
  dplyr::group_by(TypeZone, CodeZone) %>% 
  dplyr::arrange(date) %>% 
  dplyr::mutate(
    lag1 = dplyr::lag(flux_naf_artificialisation_total, 1),
    lag2 = dplyr::lag(flux_naf_artificialisation_total, 2),
    lag3 = dplyr::lag(flux_naf_artificialisation_total, 3),
    lag4 = dplyr::lag(flux_naf_artificialisation_total, 4)
    ) %>%
  dplyr::mutate(
    naf_artificialisation_5ans = flux_naf_artificialisation_total + lag1 + lag2 + lag3 + lag4
    ) %>%
  dplyr::select(dplyr::contains("Zone"), date, naf_artificialisation_5ans) %>% 
  dplyr::filter(!is.na(naf_artificialisation_5ans)) %>%
  dplyr::ungroup()

# ajout d'un indicateur calculé spécifiquement pour le projet d'observatoire habitat foncier
# seule la période de 10 ans 2011 - 2020 (au 31/12) est calculée, car elle constitue une référence
# cet indicateur n'a donc pas vocation à être calculé tous les ans
observatoire_artificialisation_3 <- observatoire_artificialisation %>%
  dplyr::mutate_if(is.factor, as.character) %>%
  dplyr::select(dplyr::contains("Zone"), date, flux_naf_artificialisation_total) %>% 
  dplyr::filter(lubridate::year(date) > 2011, lubridate::year(date) < 2022) %>%  
  dplyr::group_by(TypeZone, Zone, CodeZone) %>%
  dplyr::select(-date) %>% 
  dplyr::summarise(naf_artificialisation_10ans = sum(flux_naf_artificialisation_total)) %>%
  dplyr::mutate(date = as.Date("2021-01-01")) %>% 
  dplyr::relocate (date, .before = 4) %>%
  dplyr::ungroup() 

indicateur_observatoire_artificialisation_population_legale <- dplyr::left_join(
  observatoire_artificialisation_2, 
  population_legale_2
  ) %>% 
  dplyr::mutate(
    naf_artificialisation_par_hbt_accueilli_5ans = ifelse(
      diff_population_legale_5ans > 0, round(naf_artificialisation_5ans/diff_population_legale_5ans, digits = 2), NA)
    ) %>% 
  dplyr::left_join(territoires) %>%
  dplyr::left_join(observatoire_artificialisation_3) %>% 
  dplyr::mutate(
    pourcentage_naf_artificialisation_5ans_sur_surfarcezone = as.numeric(
      round(naf_artificialisation_5ans/SurfaceZone * 100, digits = 1)
      )
    ) %>%
  dplyr::select(-c(diff_population_legale_5ans, SurfaceZone))

# versement dans le sgbd/datamart.portrait_territoires et metadonnées -------------
source("R/poster_documenter_ind.R", encoding = "UTF-8")
poster_documenter_ind(
  df = indicateur_observatoire_artificialisation_population_legale,
  nom_table_sgbd = "indicateur_observatoire_artificialisation_population_legale",
  comm_source_en_plus = paste0(
    "Indicateur d'artificialisation des sols sur 5 ans, selon population accueillie, et calcul de l'indicateur de référence du ZAN.\nRecours aux tables ",
    base,".", schema,".", tab1,  " et ", base, ".", schema, ".", tab2
    )
  )

