
# indicateur_pop_rgp_insee

# librairies ----------
library(datalibaba)
library(tidyverse)

rm(list = ls())


# chargement data ---------------
cogifiee_pop_rgp_insee <- importer_data(table = "cogifiee_pop_rgp_insee",
                                        schema = "portrait_territoires",
                                        db = "datamart",
                                        user = "does")
# calcul ----------
indicateur_pop_rgp_insee <- cogifiee_pop_rgp_insee %>% 
  select(TypeZone, Zone, CodeZone, date, pop.ttage.cs0) %>% 
  arrange(TypeZone, Zone, CodeZone, date)%>% 
  group_by(TypeZone, Zone, CodeZone) %>% 
  # calcul de l evolution annuelle de la population
  # soit y la valeur de la derniere année, x celle de la premiere année, n le nombre d'années
  # exemple y= 220 en 2019, x= 200 en 2008, n = 2019-2008=11
  # y= x * a^11 (puissance 11) d'où a= racine 11e de y/x qui s'écrit aussi a= (y/x)^(1/n)
  # dans l'exemple, on a  a=(220/200)^(1/11) = 1,0087 d'où une augmentation annuelle de 0,87%
  mutate(annee= as.character(year(date)),
         # annees = paste0(lag(annee, 2), "_", annee),
         annee = as.numeric(annee),
         nb_annees = annee - lag(annee, 1),
         evol_moy_ann_pop_dd_mil = round((((pop.ttage.cs0 / lag(pop.ttage.cs0, 1))^(1/nb_annees)) - 1) * 100 , 2)
         ) %>% 
  ungroup() %>%
  select(-pop.ttage.cs0, -annee, -nb_annees) %>% 
  filter(date != "2009-12-31")

# versement dans le sgbd/datamart.portrait_territoiresdes données et de leur métadonnées -------------
source("R/poster_documenter_ind.R", encoding = "UTF-8")
poster_documenter_ind(df = indicateur_pop_rgp_insee, nom_table_sgbd = "indicateur_pop_rgp_insee", 
                      comm_source_en_plus = "")

rm(list=ls()) 




