
# indicateur_prio_bois_energie

# un indicateur valable uniquement à l'échelle des EPCI, défini dans la stratégie rég bois énergie de 2015

# librairies --------------
library(dplyr)
library(tidyr)
library(COGiter)
library(datalibaba)
rm(list = ls())
source("R/poster_documenter_ind.R")



# chargement data ----------
cogifiee_pop_rgp_insee <- importer_data(table = "cogifiee_pop_rgp_insee", schema = "portrait_territoires", db = "datamart", user = "does")
pop <- cogifiee_pop_rgp_insee %>% 
  rename_all(tolower) %>% 
  filter(date == max(date), typezone == "Communes") %>%
  select(contains("zone"), pop.ttage.cs0) %>% 
  left_join(communes %>% select(DEPCOM, REGIONS_DE_L_EPCI, EPCI, NOM_EPCI), by=c("codezone"="DEPCOM")) %>%
  filter(grepl("52", REGIONS_DE_L_EPCI))


cogifiee_conso_gaz_179 <- importer_data(table = "cogifiee_conso_gaz_179", schema = "portrait_territoires", db = "datamart", user = "does")

gaz <- cogifiee_conso_gaz_179 %>% 
  rename_all(tolower) %>% 
  # le but est d'établir la liste des communes desservies en gaz naturel, on garde le dernier millésime
  filter(date == max(date)) %>% 
  select(date, contains("zone"), conso_gaz_gwh) %>% 
  mutate(desserte_gaz_nat = !(is.na(conso_gaz_gwh)|conso_gaz_gwh==0)) %>% 
  right_join(pop) %>% 
  select(-REGIONS_DE_L_EPCI) %>%
  mutate(prior = factor(case_when(pop.ttage.cs0 > 10000 ~ "priorité 1 pop",
                                  pop.ttage.cs0 > 5000 & !desserte_gaz_nat ~ "priorité 1 gaz",
                                  pop.ttage.cs0 > 2000 & !desserte_gaz_nat ~ "priorité 2",
                                  TRUE ~ "non prioritaire"),
                        levels = c("priorité 1 pop", "priorité 1 gaz", "priorité 2", "non prioritaire"), ordered = TRUE))

indicateur_prio_bois_energie <- gaz %>%
  group_by(date, EPCI, NOM_EPCI) %>% 
  summarise (nb_com = n(), nb_com_gaz_distr = sum(desserte_gaz_nat), prior = min(prior), .groups = "drop") %>%
  mutate(Taux_com_gaz_distr = nb_com_gaz_distr/nb_com, 
         niv_prio_bois_nrj = case_when(prior=="priorité 1 pop" ~ "priorité 1",
                                       prior=="priorité 1 gaz" & Taux_com_gaz_distr < 0.8 ~ "priorité 1",
                                       prior=="priorité 2" & Taux_com_gaz_distr < 0.8 ~ "priorité 2",
                                       TRUE ~ "priorité 3"),
         enj_fort_bois_nrj = ifelse(niv_prio_bois_nrj == "priorité 1", "oui", "non")) %>%
  select(codezone = EPCI, zone = NOM_EPCI, date, niv_prio_bois_nrj, enj_fort_bois_nrj) %>%
  mutate_if(is.factor, as.character) %>%
  mutate(zone=if_else(codezone=="ZZZZZZZZZ", "L'Île-d'Yeu", zone),
         typezone=if_else(codezone=="ZZZZZZZZZ", "Communes", "Epci"),
         codezone=if_else(codezone=="ZZZZZZZZZ", "85113", codezone)) %>%
  mutate_if(is.character, as.factor) %>% 
  select(TypeZone = typezone, CodeZone = codezone, Zone = zone, everything())


# chargement dans le SGBD des indicateurs calculés et des commentaires -------------
poster_documenter_ind(df = indicateur_prio_bois_energie, nom_table_sgbd = "indicateur_prio_bois_energie", 
                      comm_source_en_plus = "", nom_script_sce = "indicateur_prio_bois_energie")

rm(list=ls())
 
