
# indicateur_rsvero

# librairies ------
library(datalibaba)
library(tidyverse)
library(lubridate)

rm(list = ls())


# chargement des données ----------
cogifiee_rsvero <- importer_data(db = "datamart",
                                 schema = "portrait_territoires",
                                 table = "cogifiee_rsvero")


# calcul ------------
indicateur_rsvero <- cogifiee_rsvero %>% 
  group_by(TypeZone, Zone, CodeZone, date) %>% 
  mutate(
    part_vehicule_pl_electrique_hydrogene_hybride_rechargeable = 
      round(100*pl_electrique_et_hydrogene / sum(c_across(starts_with("pl_"))), digits = 2),
    part_vehicule_tcp_electrique_hydrogene_hybride_rechargeable = 
      round(100*tcp_electrique_et_hydrogene / sum(c_across(starts_with("tcp_"))), digits = 2),
    part_vehicule_vp_electrique_hydrogene_hybride_rechargeable = 
      round(100*(vp_electrique_et_hydrogene + vp_hybride_rechargeable) / sum(c_across(starts_with("vp_"))), digits = 2),
    part_vehicule_vul_electrique_hydrogene_hybride_rechargeable = 
      round(100*(vul_electrique_et_hydrogene + vul_hybride_rechargeable) / sum(c_across(starts_with("vul_"))), digits = 2),
    part_vehicule_electrique_hydrogene_hybride_rechargeable = 
      round(100*sum(c_across(ends_with(c("_electrique_et_hydrogene","_hybride_rechargeable")))) / sum(c_across(starts_with(c("pl_","tcp_","vp_","vul_")))), digits = 2),
         ) %>% 
  ungroup() %>% 
  select(TypeZone, Zone, CodeZone, date, starts_with('part_'))


# versement dans le sgbd/datamart.portrait_territoires et metadonnées -------------
source("R/poster_documenter_ind.R", encoding = "UTF-8")
poster_documenter_ind(df = indicateur_rsvero,
                      nom_table_sgbd = "indicateur_rsvero",
                      comm_source_en_plus = "")
