
# indicateur_sitadel_densite

# librairies --------
library(dplyr)
library(tidyr)
library(COGiter)
library(DBI)
library(RPostgreSQL)
library(datalibaba)
library(googlesheets4)
library(tidyverse)

rm(list = ls())

# chargement data -------------
cogifiee_sitadel_densite <- importer_data(db = "datamart",
                                schema = "portrait_territoires",
                                table = "cogifiee_sitadel_densite")

data_cogifiee<-pivot_longer(cogifiee_sitadel_densite,
                            cols = id.nb_lgt.col_nr:id.superf_terrain.total_rs,
                            names_to = "variable",
                            values_to = "valeur")


# calcul ----------
indicateur_sitadel_densite<-data_cogifiee %>%
  spread(variable,valeur) %>%
  mutate(id.densite.col_nr = round((id.nb_lgt.col_nr /id.superf_terrain.col_nr ) *10000,digits = 2),
         id.densite.col_rp = round((id.nb_lgt.col_rp /id.superf_terrain.col_rp ) *10000,digits = 2),
         id.densite.col_rs = round((id.nb_lgt.col_rs /id.superf_terrain.col_rs ) *10000,digits = 2),
         id.densite.col_total = round((id.nb_lgt.total_col	 /id.superf_terrain.total_col ) *10000,digits = 2),
         id.densite.ip_nr = round((id.nb_lgt.ip_nr /id.superf_terrain.ip_nr ) *10000,digits = 2),
         id.densite.ip_rp = round((id.nb_lgt.ip_rp	 /id.superf_terrain.ip_rp ) *10000,digits = 2),
         id.densite.ip_rs = round((id.nb_lgt.ip_rs	 /id.superf_terrain.ip_rs ) *10000,digits = 2),         
         id.densite.ip_total = round((id.nb_lgt.total_ip	 /id.superf_terrain.total_ip ) *10000,digits = 2),
         id.densite.ig_nr = round((id.nb_lgt.ig_nr /id.superf_terrain.ig_nr ) *10000,digits = 2),
         id.densite.ig_rp = round((id.nb_lgt.ig_rp /id.superf_terrain.ig_rp ) *10000,digits = 2),
         id.densite.ig_rs = round((id.nb_lgt.ig_rs /id.superf_terrain.ig_rs ) *10000,digits = 2),
         id.densite.ig_total = round((id.nb_lgt.total_ig	 /id.superf_terrain.total_ig ) *10000,digits = 2),
         id.densite.ind_nr = round((id.nb_lgt.ind_nr /id.superf_terrain.ind_nr ) *10000,digits = 2),
         id.densite.ind_rp = round((id.nb_lgt.ind_rp /id.superf_terrain.ind_rp ) *10000,digits = 2),
         id.densite.ind_rs = round((id.nb_lgt.ind_rs /id.superf_terrain.ind_rs ) *10000,digits = 2),
         id.densite.ind_total = round((id.nb_lgt.total_ind	 /id.superf_terrain.total_ind ) *10000,digits = 2),
         id.densite.total_nr = round((id.nb_lgt.total_nr	 /id.superf_terrain.total_nr ) *10000,digits = 2),
         id.densite.total_rp = round((id.nb_lgt.total_rp	 /id.superf_terrain.total_rp ) *10000,digits = 2),
         id.densite.total_rs = round((id.nb_lgt.total_rs	 /id.superf_terrain.total_rs ) *10000,digits = 2),
         id.densite.total = round((id.nb_lgt.total	 /id.superf_terrain.total ) *10000,digits = 2),
         ) %>%
  select(-c(id.nb_lgt.col_nr:id.superf_terrain.total_rs)) %>%
  gather(variable,valeur,id.densite.col_nr:id.densite.total) %>%
  mutate_if(is.character, as.factor)

indicateur_sitadel_densite$valeur[is.nan(indicateur_sitadel_densite$valeur)]<-NA
indicateur_sitadel_densite<-pivot_wider(indicateur_sitadel_densite,names_from = variable,values_from = valeur)%>% 
  mutate_if(is.factor,as.character)

# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = indicateur_sitadel_densite,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "indicateur_sitadel_densite",
            pk = c("TypeZone", "Zone", "CodeZone", "date"),
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            user = "does")

# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(indicateur_sitadel_densite), c("TypeZone", "Zone" , "CodeZone" , "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()



## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "TypeZone", "Type de territoire",
      "Zone", " Nom du territoire",
      "CodeZone", "Code INSEE du territoire",
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, table = "indicateur_sitadel_densite", schema = "portrait_territoires",
               db = "datamart", user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table) %>%
  # ajout de complement sur la généalogie
  paste0(".\n", "Chargement des donn\u00e9es sur Geokit3")

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "indicateur_sitadel_densite", 
                user = "does")

rm(list=ls())
