
# secret_ecln

# librairies -------------
library(dplyr)
library(tidyr)
library(lubridate)
library(COGiter)
library(DBI)
library(RPostgreSQL)
library(datalibaba)
library(googlesheets4)

rm(list=ls())


# chargement data -------------
cogifiee_ecln <- importer_data(db = "datamart",
                               schema = "portrait_territoires",
                               table = "cogifiee_ecln")

data_cogifiee<-pivot_longer(cogifiee_ecln,
                cols = nb_logt_en_cours.collectif : surface_totale_des_ventes.total,
                names_to = "variable",
                values_to = "valeur") %>%
  mutate_if(is.character,as.factor)

# tranches_ecln <- read.csv2('metadata/secret_ecln.csv', as.is = TRUE, encoding = "UTF-8" )

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
tranches_ecln <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                            sheet = "secret_ecln")


data_ecln <- left_join(data_cogifiee, liste_zone, by= c("CodeZone","TypeZone","Zone")) %>%
  left_join(epci %>% select(EPCI,NOM_EPCI), by = "EPCI")


# distinction des données à secrétiser ---------

# listes des variables logt et promoteurs
variables_logt <- tranches_ecln  %>%
  pull(variable)
variables_promoteurs <- tranches_ecln  %>%
  pull(variable_associee)  %>%
  unique()

# table des nb promoteurs
data_promoteurs <- data_ecln  %>%
  filter (variable %in% variables_promoteurs) %>%
  rename(variable_associee=variable, nb_promoteurs=valeur)

#table des données
data_ecln_donnees <- data_ecln  %>%
  filter (variable %in% variables_logt)

data_ecln_donnees <- left_join(data_ecln_donnees, tranches_ecln, by= "variable")
data_ecln_donnees <- left_join(data_ecln_donnees, data_promoteurs %>%
                                 select(TypeZone,CodeZone,date,variable_associee,nb_promoteurs),
                               by= c("TypeZone","CodeZone","date", "variable_associee") )

#liste des variables publiques ou non
variables_publiques <- tranches_ecln  %>%
  filter(secret=="0")  %>%
  pull(variable)
variables_non_publiques <- tranches_ecln  %>%
  filter(secret !="0")  %>%
  pull(variable)

#table des données publiques
data_ecln_A <- data_ecln_donnees  %>%
  filter (variable %in% variables_publiques|
            TypeZone == "France" )  %>%
  select(TypeZone,Zone,CodeZone,date,variable,valeur)  %>%
  mutate(valeur=as.character(valeur))

#table des données à secrétiser
data_ecln_B <- data_ecln_donnees  %>%
  filter (variable %in% variables_non_publiques &
            TypeZone %in% c("Communes","Epci","Régions","Départements"))


# secrétisation des données -----------
secret_communes<-data_ecln_B %>% 
  filter(TypeZone=="Communes")

#secret induit, pour une meme variable et un meme epci, pour ne pas retrouver la valeur d'une commune
#en faisant la somme des communes

secret_communes<-secret_communes %>% 
  group_by(variable,EPCI,date) %>%
  mutate(A_nb_inf3=length(which(nb_promoteurs<3))) %>% #compte combien inférieur à 3
  mutate(A_rang=rank(nb_promoteurs, ties.method = "first")) #classe pour repérer les 2 plus petites valeurs
secret_communes$A_sec<-case_when(
  secret_communes$nb_promoteurs<3 ~ 1,      #secret pour toutes les nb_promoteurs inférieurs à 3
  secret_communes$A_nb_inf3== 0 ~ 0,   #enlève le secret si aucune des communes rang 1 et 2 inférieur à 3
  secret_communes$A_rang<3 ~ 1,         #secret sur les 2 communes avec valeurs les plus basses
  TRUE ~ 0)

# secret induit, pour une meme categorie et une meme commune, pour ne pas retrouver la valeur d'une variable
# en faisant la somme des variables de la commune

secret_communes<-secret_communes %>%
  group_by(categorie,Zone,date) %>%
  mutate(B_nb_inf3=length(which(nb_promoteurs<3))) %>% #compte combien inférieur à 3
  mutate(B_rang=rank(nb_promoteurs, ties.method = "first")) #classe pour repérer les 2 plus petites valeurs
secret_communes$B_sec<-case_when(
  secret_communes$B_nb_inf3== 0 ~ 0,   #enlève le secret si aucune des communes rang 1 et 2 inférieur à 11
  secret_communes$B_rang<3 ~ 1,         #secret sur les 2 communes avec valeurs les plus basses
  TRUE ~ 0)  

# masque le collectif pour une commune dont l'individuel a été masqué par le secret induit
secret_communes <- secret_communes %>%
  mutate (somme_secrets = A_sec + B_sec) %>%
  group_by(CodeZone,categorie,date) %>% #pour chaque commune
  mutate(a_secretiser=length(which(somme_secrets>0)))  # secretise toutes les donnes groupees

# regroupement des secrets, masquage des valeurs
secret_communes<-secret_communes %>%
  mutate(valeur=as.character(valeur))
secret_communes$valeur<-case_when(
  is.na(secret_communes$nb_promoteurs)~ "nc",
  secret_communes$a_secretiser > 0 ~ "nc",         #remplace valeur par "nc" si secret stat
  TRUE ~ secret_communes$valeur)
secret_communes<-secret_communes %>%
  ungroup() %>%
  select(TypeZone,Zone,CodeZone,date,variable,valeur)


# secretisation des EPCI -----

secret_epci<- data_ecln_B %>%
  filter(TypeZone =="Epci")

# secret induit, pour une meme categorie et un meme epci, pour ne pas retrouver la valeur d'une variable
# en faisant la somme des variables de l'Epci

secret_epci<-secret_epci %>%
  group_by(categorie,CodeZone,date) %>%
  mutate(B_nb_inf3=length(which(nb_promoteurs<3))) %>% #compte combien inférieur à 3
  mutate(B_rang=rank(nb_promoteurs, ties.method = "first")) #classe pour repérer les 2 plus petites valeurs
secret_epci$B_sec<-case_when(
  secret_epci$valeur<3 ~ 1,      #secret pour toutes les valeurs inférieures à 3  
  secret_epci$B_nb_inf3== 0 ~ 0,   #enlève le secret si aucune des communes rang 1 et 2 inférieur à 3
  secret_epci$B_rang<3 ~ 1,         #secret sur les 2 communes avec valeurs les plus basses
  TRUE ~ 0)  

# regroupement des secrets, masquage des valeurs
secret_epci<-secret_epci %>%
  mutate(valeur=as.character(valeur))
secret_epci$valeur<-case_when(
  is.na(secret_epci$nb_promoteurs)~ "nc",
  secret_epci$B_sec== 1 ~ "nc",         #remplace valeur par "nc" si secret stat
  TRUE ~ secret_epci$valeur)
secret_epci<-secret_epci %>%
  ungroup() %>%
  select(TypeZone,Zone,CodeZone,date,variable,valeur)


# secretisation Départements et Régions -----

secret_dep_reg<- data_ecln_B %>%
  filter(TypeZone %in% c("Régions","Départements"))


      #table des données publiques departement et regions
public_dep_reg_A <- secret_dep_reg  %>%
  filter (!(variable %in% c("prix_total_des_ventes.collectif","prix_total_des_ventes.individuel","prix_total_des_ventes.total" )))  %>%
  select(TypeZone,Zone,CodeZone,date,variable,valeur)  %>%
  mutate(valeur=as.character(valeur))

      #table des données à secrétiser departement et regions
secret_dep_reg_B <- secret_dep_reg  %>%
  filter (variable %in% c("prix_total_des_ventes.collectif","prix_total_des_ventes.individuel","prix_total_des_ventes.total" ))

#secret induit, pour une meme variable et une meme regioçn, pour ne pas retrouver la valeur d'un département
#en faisant la somme des partements

secret_dep_reg_B1<-secret_dep_reg_B %>% 
  mutate(REG = as.character(REG)) %>%
  group_by(variable,REG,TypeZone,date) %>%
  mutate(A_nb_inf3=length(which(nb_promoteurs<3))) %>% #compte combien inférieur à 3
  mutate(A_rang=rank(nb_promoteurs, ties.method = "first")) #classe pour repérer les 2 plus petites valeurs
secret_dep_reg_B1$A_sec<-case_when(
  secret_dep_reg_B1$nb_promoteurs<3 ~ 1,      #secret pour toutes les nb_promoteurs inférieurs à 3
  secret_dep_reg_B1$A_nb_inf3== 0 ~ 0,   #enlève le secret si aucun des departements rang 1 et 2 inférieur à 3
  secret_dep_reg_B1$A_rang<3 ~ 1,         #secret sur les 2 DEPARTEMENTS avec valeurs les plus basses
  TRUE ~ 0)

      # secret induit, pour une meme categorie et un meme departement, pour ne pas retrouver la valeur d'une variable
      # en faisant la somme des variables du departement
secret_dep1<-secret_dep_reg_B1 %>%
  ungroup() %>%
  group_by(categorie,TypeZone,CodeZone,date) %>%  #groupe par categorie, zone et annee
  mutate(B_nb_inf3=length(which(nb_promoteurs<3))) # compte le nombre de fois ou nb promoteurs <3 par groupe
secret_dep1$B_sec<-case_when(
  secret_dep1$B_nb_inf3== 0 ~ 0,   #enleve secret (affiche 0) si le nb de fois où groupe <3 est égal à 0
  TRUE ~ 1) #pour les autres, code 1 (secret)
# secret_dep1$C_sec<-case_when(
#     secret_dep1$B_nb_inf3== 0 ~ 0,   #enleve secret (affiche 0) si le nb de fois où groupe <3 est égal à 0
#     TRUE ~ 1)

# masque le collectif pour un dep dont l'individuel a été masqué par le secret induit
secret_dep2 <- secret_dep1 %>%
  mutate (somme_secrets = A_sec + B_sec) %>%
  group_by(TypeZone,DEP,REG,categorie,date) %>% #pour chaque departement
  mutate(a_secretiser=length(which(somme_secrets>0)))  # secretise toutes les donnes groupees



      # regroupement des secrets, masquage des valeurs
secret_dep2<-secret_dep2 %>%
  mutate(valeur=as.character(valeur))
secret_dep2$valeur<-case_when(
  is.na(secret_dep2$nb_promoteurs)~ "nc",
  secret_dep2$a_secretiser > 0 ~ "nc",         #remplace valeur par "nc" si secret stat
  TRUE ~ secret_dep2$valeur)

secret_dep2<-secret_dep2 %>%
  ungroup() %>%
  select(TypeZone,Zone,CodeZone,date,variable,valeur)

# regroupement des zonages ------------
secretise_ecln <-bind_rows(secret_communes,secret_epci,data_ecln_A,public_dep_reg_A,secret_dep2)


# remplace "nc" par NA    
secretise_ecln$valeur<-na_if(secretise_ecln$valeur,"nc")

secretise_ecln <- secretise_ecln %>%
  mutate(valeur=as.numeric(valeur)) %>%
  mutate_if(is.factor,as.character) %>% 
  pivot_wider(names_from = variable,values_from = valeur)


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = secretise_ecln,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "secretise_ecln",
            pk = c("TypeZone", "Zone", "CodeZone", "date"),
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            user = "does")

# commentaires de la table et des variables -------------

# récupération des commentaires de la table source
dico_var <- get_table_comments(
  db = "datamart",
  schema = "portrait_territoires",
  table = "cogifiee_ecln",
  user = "does")

# commentaire de la table
comm_table <- filter(dico_var, is.na(nom_col)) %>% 
  pull(commentaire) %>% 
  gsub("\nCommentaire.*$", "", .)

commenter_table(
  comment = comm_table,
  db = "datamart",
  schema = "portrait_territoires",
  table = "secretise_ecln",
  user = "does"
)

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == "secret_ecln") %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "TypeZone", "Type de territoire",
      "Zone", " Nom du territoire",
      "CodeZone", "Code INSEE du territoire",
      "date", "Millesime"
    )
  )

post_dico_attr(
  dico = metadata_indicateur,
  db = "datamart",
  schema = "portrait_territoires",
  table = "secretise_ecln",
  user = "does"
)
