
# chargement_ocsge_typologie_auran

# librairies ------
library(DBI)
library(RPostgreSQL)
library(dplyr)
library(tidyr)

rm(list = ls())


# chargement data -------------
drv <- dbDriver("PostgreSQL")
con_datamart <- dbConnect(drv, 
                          dbname="datamart", 
                          host=Sys.getenv("server"), 
                          port=Sys.getenv("port"),
                          user=Sys.getenv("userid"),
                          password=Sys.getenv("pwd_does"))
postgresqlpqExec(con_datamart, "SET client_encoding = 'windows-1252'") 

ocsge_pdl_couverture_usage_2013<-dbReadTable(con_datamart,c("portrait_territoires","ocsge_pdl_couverture_usage_2013"))

ocsge_pdl_couverture_usage_2016<-dbReadTable(con_datamart,c("portrait_territoires","ocsge_pdl_couverture_usage_2016"))

ocsge_pdl<-bind_rows(ocsge_pdl_couverture_usage_2013,
                     ocsge_pdl_couverture_usage_2016)


# définition typologie auran --------------
# type_0 : Croisement non existant
# type_1 : Zones d’habitat, équipements, zones d’activités économiques et commerciales
# type_2 : Infrastructures routières, ferroviaires, portuaires, aéroportuaires et réseaux d’utilité publique
# type_3 : Activités d’extraction
# type_4 : Zones en transition
# type_5 : Bâtiments, serres et espaces artificialisés agricoles
# type_6 : Espaces agricoles non artificialisés
# type_7 : Bois et forêts
# type_8 : Autres espaces naturels
# type_9 : Surfaces en eau


# typologie des espaces -------
ocsge_type <- select(ocsge_pdl, couverture, usage) %>% 
  distinct() %>% 
mutate(type_espace = case_when(
usage == "US1.1" & couverture == "CS1.1.1.1" ~ "type_5",
usage == "US1.2" & couverture == "CS1.1.1.1" ~ "type_0",
usage == "US1.3" & couverture == "CS1.1.1.1" ~ "type_3",
usage == "US1.4" & couverture == "CS1.1.1.1" ~ "type_5",
usage == "US1.5" & couverture == "CS1.1.1.1" ~ "type_0",
usage == "US235" & couverture == "CS1.1.1.1" ~ "type_1",
usage == "US4.1.1" & couverture == "CS1.1.1.1" ~ "type_2",
usage == "US4.1.2" & couverture == "CS1.1.1.1" ~ "type_2",
usage == "US4.1.3" & couverture == "CS1.1.1.1" ~ "type_2",
usage == "US4.1.4" & couverture == "CS1.1.1.1" ~ "type_2",
usage == "US4.1.5" & couverture == "CS1.1.1.1" ~ "type_0",
usage == "US4.2" & couverture == "CS1.1.1.1" ~ "type_2",
usage == "US4.3" & couverture == "CS1.1.1.1" ~ "type_2",
usage == "US6.1" & couverture == "CS1.1.1.1" ~ "type_4",
usage == "US6.2" & couverture == "CS1.1.1.1" ~ "type_1",
usage == "US6.3" & couverture == "CS1.1.1.1" ~ "type_0",
usage == "US6.4" & couverture == "CS1.1.1.1" ~ "type_0", 

usage == "US1.1" & couverture == "CS1.1.1.2" ~ "type_5",
usage == "US1.2" & couverture == "CS1.1.1.2" ~ "type_0",
usage == "US1.3" & couverture == "CS1.1.1.2" ~ "type_3",
usage == "US1.4" & couverture == "CS1.1.1.2" ~ "type_5",
usage == "US1.5" & couverture == "CS1.1.1.2" ~ "type_0",
usage == "US235" & couverture == "CS1.1.1.2" ~ "type_1",
usage == "US4.1.1" & couverture == "CS1.1.1.2" ~ "type_2",
usage == "US4.1.2" & couverture == "CS1.1.1.2" ~ "type_2",
usage == "US4.1.3" & couverture == "CS1.1.1.2" ~ "type_2",
usage == "US4.1.4" & couverture == "CS1.1.1.2" ~ "type_2",
usage == "US4.1.5" & couverture == "CS1.1.1.2" ~ "type_0",
usage == "US4.2" & couverture == "CS1.1.1.2" ~ "type_2",
usage == "US4.3" & couverture == "CS1.1.1.2" ~ "type_2",
usage == "US6.1" & couverture == "CS1.1.1.2" ~ "type_4",
usage == "US6.2" & couverture == "CS1.1.1.2" ~ "type_1",
usage == "US6.3" & couverture == "CS1.1.1.2" ~ "type_0",
usage == "US6.4" & couverture == "CS1.1.1.2" ~ "type_0",

usage == "US1.1" & couverture == "CS1.1.2.1" ~ "type_5",
usage == "US1.2" & couverture == "CS1.1.2.1" ~ "type_0",
usage == "US1.3" & couverture == "CS1.1.2.1" ~ "type_3",
usage == "US1.4" & couverture == "CS1.1.2.1" ~ "type_5",
usage == "US1.5" & couverture == "CS1.1.2.1" ~ "type_0",
usage == "US235" & couverture == "CS1.1.2.1" ~ "type_1",
usage == "US4.1.1" & couverture == "CS1.1.2.1" ~ "type_2",
usage == "US4.1.2" & couverture == "CS1.1.2.1" ~ "type_2",
usage == "US4.1.3" & couverture == "CS1.1.2.1" ~ "type_2",
usage == "US4.1.4" & couverture == "CS1.1.2.1" ~ "type_2",
usage == "US4.1.5" & couverture == "CS1.1.2.1" ~ "type_0",
usage == "US4.2" & couverture == "CS1.1.2.1" ~ "type_2",
usage == "US4.3" & couverture == "CS1.1.2.1" ~ "type_2",
usage == "US6.1" & couverture == "CS1.1.2.1" ~ "type_4",
usage == "US6.2" & couverture == "CS1.1.2.1" ~ "type_2",
usage == "US6.3" & couverture == "CS1.1.2.1" ~ "type_0",
usage == "US6.4" & couverture == "CS1.1.2.1" ~ "type_0",

usage == "US1.1" & couverture == "CS1.1.2.2" ~ "type_0",
usage == "US1.2" & couverture == "CS1.1.2.2" ~ "type_0",
usage == "US1.3" & couverture == "CS1.1.2.2" ~ "type_0",
usage == "US1.4" & couverture == "CS1.1.2.2" ~ "type_5",
usage == "US1.5" & couverture == "CS1.1.2.2" ~ "type_0",
usage == "US235" & couverture == "CS1.1.2.2" ~ "type_1",
usage == "US4.1.1" & couverture == "CS1.1.2.2" ~ "type_0",
usage == "US4.1.2" & couverture == "CS1.1.2.2" ~ "type_2",
usage == "US4.1.3" & couverture == "CS1.1.2.2" ~ "type_0",
usage == "US4.1.4" & couverture == "CS1.1.2.2" ~ "type_0",
usage == "US4.1.5" & couverture == "CS1.1.2.2" ~ "type_0",
usage == "US4.2" & couverture == "CS1.1.2.2" ~ "type_0",
usage == "US4.3" & couverture == "CS1.1.2.2" ~ "type_0",
usage == "US6.1" & couverture == "CS1.1.2.2" ~ "type_4",
usage == "US6.2" & couverture == "CS1.1.2.2" ~ "type_0",
usage == "US6.3" & couverture == "CS1.1.2.2" ~ "type_0",
usage == "US6.4" & couverture == "CS1.1.2.2" ~ "type_0",

usage == "US1.1" & couverture == "CS1.2.1" ~ "type_0",
usage == "US1.2" & couverture == "CS1.2.1" ~ "type_0",
usage == "US1.3" & couverture == "CS1.2.1" ~ "type_0",
usage == "US1.4" & couverture == "CS1.2.1" ~ "type_0",
usage == "US1.5" & couverture == "CS1.2.1" ~ "type_0",
usage == "US235" & couverture == "CS1.2.1" ~ "type_1",
usage == "US4.1.1" & couverture == "CS1.2.1" ~ "type_0",
usage == "US4.1.2" & couverture == "CS1.2.1" ~ "type_0",
usage == "US4.1.3" & couverture == "CS1.2.1" ~ "type_0",
usage == "US4.1.4" & couverture == "CS1.2.1" ~ "type_0",
usage == "US4.1.5" & couverture == "CS1.2.1" ~ "type_0",
usage == "US4.2" & couverture == "CS1.2.1" ~ "type_0",
usage == "US4.3" & couverture == "CS1.2.1" ~ "type_0",
usage == "US6.1" & couverture == "CS1.2.1" ~ "type_4",
usage == "US6.2" & couverture == "CS1.2.1" ~ "type_0",
usage == "US6.3" & couverture == "CS1.2.1" ~ "type_8",
usage == "US6.4" & couverture == "CS1.2.1" ~ "type_0",

usage == "US1.1" & couverture == "CS1.2.2" ~ "type_9",
usage == "US1.2" & couverture == "CS1.2.2" ~ "type_0",
usage == "US1.3" & couverture == "CS1.2.2" ~ "type_3",
usage == "US1.4" & couverture == "CS1.2.2" ~ "type_5",
usage == "US1.5" & couverture == "CS1.2.2" ~ "type_0",
usage == "US235" & couverture == "CS1.2.2" ~ "type_9",
usage == "US4.1.1" & couverture == "CS1.2.2" ~ "type_2",
usage == "US4.1.2" & couverture == "CS1.2.2" ~ "type_0",
usage == "US4.1.3" & couverture == "CS1.2.2" ~ "type_0",
usage == "US4.1.4" & couverture == "CS1.2.2" ~ "type_9",
usage == "US4.1.4" & couverture == "CS1.2.2" ~ "type_0",
usage == "US4.2" & couverture == "CS1.2.2" ~ "type_0",
usage == "US4.3" & couverture == "CS1.2.2" ~ "type_2",
usage == "US6.1" & couverture == "CS1.2.2" ~ "type_0",
usage == "US6.2" & couverture == "CS1.2.2" ~ "type_0",
usage == "US6.3" & couverture == "CS1.2.2" ~ "type_9",
usage == "US6.4" & couverture == "CS1.2.2" ~ "type_0",

usage == "US1.1" & couverture == "CS2.1.1.1" ~ "type_6",
usage == "US1.2" & couverture == "CS2.1.1.1" ~ "type_7",
usage == "US1.3" & couverture == "CS2.1.1.1" ~ "type_3",
usage == "US1.4" & couverture == "CS2.1.1.1" ~ "type_0",
usage == "US1.5" & couverture == "CS2.1.1.1" ~ "type_0",
usage == "US235" & couverture == "CS2.1.1.1" ~ "type_1",
usage == "US4.1.1" & couverture == "CS2.1.1.1" ~ "type_2",
usage == "US4.1.2" & couverture == "CS2.1.1.1" ~ "type_2",
usage == "US4.1.3" & couverture == "CS2.1.1.1" ~ "type_2",
usage == "US4.1.4" & couverture == "CS2.1.1.1" ~ "type_0",
usage == "US4.1.5" & couverture == "CS2.1.1.1" ~ "type_0",
usage == "US4.2" & couverture == "CS2.1.1.1" ~ "type_0", 
usage == "US4.3" & couverture == "CS2.1.1.1" ~ "type_2",
usage == "US6.1" & couverture == "CS2.1.1.1" ~ "type_0",
usage == "US6.2" & couverture == "CS2.1.1.1" ~ "type_7",
usage == "US6.3" & couverture == "CS2.1.1.1" ~ "type_7",
usage == "US6.4" & couverture == "CS2.1.1.1" ~ "type_0",

usage == "US1.1" & couverture == "CS2.1.1.2" ~ "type_6",
usage == "US1.2" & couverture == "CS2.1.1.2" ~ "type_7",
usage == "US1.3" & couverture == "CS2.1.1.2" ~ "type_3",
usage == "US1.4" & couverture == "CS2.1.1.2" ~ "type_0",
usage == "US1.5" & couverture == "CS2.1.1.2" ~ "type_0",
usage == "US235" & couverture == "CS2.1.1.2" ~ "type_1",
usage == "US4.1.1" & couverture == "CS2.1.1.2" ~ "type_2",
usage == "US4.1.2" & couverture == "CS2.1.1.2" ~ "type_2",
usage == "US4.1.3" & couverture == "CS2.1.1.2" ~ "type_0",
usage == "US4.1.4" & couverture == "CS2.1.1.2" ~ "type_0",
usage == "US4.1.5" & couverture == "CS2.1.1.2" ~ "type_0",
usage == "US4.2" & couverture == "CS2.1.1.2" ~ "type_0",
usage == "US4.3" & couverture == "CS2.1.1.2" ~ "type_0",
usage == "US6.1" & couverture == "CS2.1.1.2" ~ "type_0",
usage == "US6.2" & couverture == "CS2.1.1.2" ~ "type_0",
usage == "US6.3" & couverture == "CS2.1.1.2" ~ "type_7",
usage == "US6.4" & couverture == "CS2.1.1.2" ~ "type_0",

usage == "US1.1" & couverture == "CS2.1.1.3" ~ "type_6",
usage == "US1.2" & couverture == "CS2.1.1.3" ~ "type_7",
usage == "US1.3" & couverture == "CS2.1.1.3" ~ "type_0",
usage == "US1.4" & couverture == "CS2.1.1.3" ~ "type_0",
usage == "US1.5" & couverture == "CS2.1.1.3" ~ "type_0",
usage == "US235" & couverture == "CS2.1.1.3" ~ "type_1",
usage == "US4.1.1" & couverture == "CS2.1.1.3" ~ "type_2",
usage == "US4.1.2" & couverture == "CS2.1.1.3" ~ "type_2",
usage == "US4.1.3" & couverture == "CS2.1.1.3" ~ "type_0",
usage == "US4.1.4" & couverture == "CS2.1.1.3" ~ "type_0",
usage == "US4.1.5" & couverture == "CS2.1.1.3" ~ "type_0",
usage == "US4.2" & couverture == "CS2.1.1.3" ~ "type_0",
usage == "US4.3" & couverture == "CS2.1.1.3" ~ "type_0",
usage == "US6.1" & couverture == "CS2.1.1.3" ~ "type_0",
usage == "US6.2" & couverture == "CS2.1.1.3" ~ "type_0",
usage == "US6.3" & couverture == "CS2.1.1.3" ~ "type_7",
usage == "US6.4" & couverture == "CS2.1.1.3" ~ "type_0",

usage == "US1.1" & couverture == "CS2.1.2" ~ "type_6",
usage == "US1.2" & couverture == "CS2.1.2" ~ "type_8",
usage == "US1.3" & couverture == "CS2.1.2" ~ "type_3",
usage == "US1.4" & couverture == "CS2.1.2" ~ "type_0",
usage == "US1.5" & couverture == "CS2.1.2" ~ "type_0",
usage == "US235" & couverture == "CS2.1.2" ~ "type_1",
usage == "US4.1.1" & couverture == "CS2.1.2" ~ "type_2",
usage == "US4.1.2" & couverture == "CS2.1.2" ~ "type_2",
usage == "US4.1.3" & couverture == "CS2.1.2" ~ "type_2",
usage == "US4.1.4" & couverture == "CS2.1.2" ~ "type_0",
usage == "US4.1.5" & couverture == "CS2.1.2" ~ "type_0",
usage == "US4.2" & couverture == "CS2.1.2" ~ "type_2",
usage == "US4.3" & couverture == "CS2.1.2" ~ "type_2",
usage == "US6.1" & couverture == "CS2.1.2" ~ "type_0",
usage == "US6.2" & couverture == "CS2.1.2" ~ "type_8",
usage == "US6.3" & couverture == "CS2.1.2" ~ "type_8",
usage == "US6.4" & couverture == "CS2.1.2" ~ "type_0",

usage == "US1.1" & couverture == "CS2.1.3" ~ "type_6",
usage == "US1.2" & couverture == "CS2.1.3" ~ "type_0",
usage == "US1.3" & couverture == "CS2.1.3" ~ "type_0",
usage == "US1.4" & couverture == "CS2.1.3" ~ "type_0",
usage == "US1.5" & couverture == "CS2.1.3" ~ "type_0",
usage == "US235" & couverture == "CS2.1.3" ~ "type_6",
usage == "US4.1.1" & couverture == "CS2.1.3" ~ "type_0",
usage == "US4.1.2" & couverture == "CS2.1.3" ~ "type_2",
usage == "US4.1.3" & couverture == "CS2.1.3" ~ "type_0",
usage == "US4.1.4" & couverture == "CS2.1.3" ~ "type_0",
usage == "US4.1.5" & couverture == "CS2.1.3" ~ "type_0",
usage == "US4.2" & couverture == "CS2.1.3" ~ "type_0",
usage == "US4.3" & couverture == "CS2.1.3" ~ "type_0",
usage == "US6.1" & couverture == "CS2.1.3" ~ "type_0",
usage == "US6.2" & couverture == "CS2.1.3" ~ "type_0",
usage == "US6.3" & couverture == "CS2.1.3" ~ "type_0",
usage == "US6.4" & couverture == "CS2.1.3" ~ "type_0",

usage == "US1.1" & couverture == "CS2.2.1" ~ "type_6",
usage == "US1.2" & couverture == "CS2.2.1" ~ "type_0",
usage == "US1.3" & couverture == "CS2.2.1" ~ "type_3",
usage == "US1.4" & couverture == "CS2.2.1" ~ "type_6",
usage == "US1.5" & couverture == "CS2.2.1" ~ "type_0",
usage == "US235" & couverture == "CS2.2.1" ~ "type_1",
usage == "US4.1.1" & couverture == "CS2.2.1" ~ "type_2",
usage == "US4.1.2" & couverture == "CS2.2.1" ~ "type_2",
usage == "US4.1.3" & couverture == "CS2.2.1" ~ "type_2",
usage == "US4.1.4" & couverture == "CS2.2.1" ~ "type_2",
usage == "US4.1.5" & couverture == "CS2.2.1" ~ "type_0",
usage == "US4.2" & couverture == "CS2.2.1" ~ "type_2",
usage == "US4.3" & couverture == "CS2.2.1" ~ "type_2",
usage == "US6.1" & couverture == "CS2.2.1" ~ "type_4",
usage == "US6.2" & couverture == "CS2.2.1" ~ "type_8",
usage == "US6.3" & couverture == "CS2.2.1" ~ "type_8",
usage == "US6.4" & couverture == "CS2.2.1" ~ "type_0",

usage == "US1.1" & couverture == "CS2.2.2" ~ "type_0",
usage == "US1.2" & couverture == "CS2.2.2" ~ "type_0",
usage == "US1.3" & couverture == "CS2.2.2" ~ "type_0",
usage == "US1.4" & couverture == "CS2.2.2" ~ "type_6",
usage == "US1.5" & couverture == "CS2.2.2" ~ "type_0",
usage == "US235" & couverture == "CS2.2.2" ~ "type_1",
usage == "US4.1.1" & couverture == "CS2.2.2" ~ "type_0",
usage == "US4.1.2" & couverture == "CS2.2.2" ~ "type_2",
usage == "US4.1.3" & couverture == "CS2.2.2" ~ "type_0",
usage == "US4.1.4" & couverture == "CS2.2.2" ~ "type_0",
usage == "US4.1.5" & couverture == "CS2.2.2" ~ "type_0",
usage == "US4.2" & couverture == "CS2.2.2" ~ "type_0",
usage == "US4.3" & couverture == "CS2.2.2" ~ "type_0",
usage == "US6.1" & couverture == "CS2.2.2" ~ "type_4",
usage == "US6.2" & couverture == "CS2.2.2" ~ "type_0",
usage == "US6.3" & couverture == "CS2.2.2" ~ "type_8",
usage == "US6.4" & couverture == "CS2.2.2" ~ "type_0",

usage == "US235" & couverture == "CS2.1.1" ~ "type_1" 
# cas du Bigne 44014 en 2013, CS2.1.1 décliné en CS2.1.1.1, CS2.1.1.2, CS2.1.1.3
)
)


# calcul des indicateurs communaux -----------
ocsge_auran <- ocsge_pdl %>%
  left_join(ocsge_type) %>% 
  select(depcom = code_insee, date, variable = type_espace, valeur = surf_intersection_m2) %>%
  group_by(date, depcom, variable) %>%
  summarise(valeur = sum(valeur), .groups = "drop") %>%
  mutate_if(is.character, as.factor) %>% 
  complete(depcom,date,variable,fill = list(valeur = 0)) %>% 
  pivot_wider(names_from = variable,values_from = valeur) 


ocsge_auran_type_0<-filter(ocsge_auran,type_0 != 0) # 32 obs
save(ocsge_auran_type_0,file = "sysdata/ocsge_auran_type_0.Rdata")


# versement dans le sgbd/datamart.portrait_territoires -------------
dbWriteTable(con_datamart,
             c("portrait_territoires","source_ocsge_auran"),
             ocsge_auran, 
             row.names=FALSE, 
             overwrite=TRUE)

dbDisconnect(con_datamart)

rm(list=ls())
