
# specifique_couverture_sage

# librairies --------
library(datalibaba)
library(tidyverse)
library(mapview)
library(COGiter)
library(sf)
library(units)
library(googlesheets4)


rm(list = ls())


# chargement SAGE ------------
n_sage_r52<-importer_data(db = "si_eau",
                          schema = "zonages_de_gestion",
                          table = "n_sage_r52") %>% 
  mutate(lb_etat=case_when(lb_etat=="Mis en oeuvre"~"mis_en_oeuvre",
                           lb_etat=="Élaboration"~"elaboration",
                           lb_etat=="Première révision"~"premiere_revision"))
# mapview(n_sage_r52,zol = c("nom"), color = "blue", alpha.regions = 0.5, legend = T)
# la couche géographique est de mauvaise qualité, car des limites de SAGE intersectent entre elles !


# limites administratives ----------

n_commune_exp_r52 <- importer_data(db = "referentiels",
                                   schema = "adminexpress",
                                   table = "n_commune_exp_r52") %>%
  select(insee_com, nom_com = nom) %>%
  mutate(surf_commune = st_area(the_geom))

n_epci_zsup_r52<-importer_data(db = "consultation",
                               schema = "donnee_generique",
                               table = "n_epci_zsup_r52") %>%
  select(siren_epci, nom_epci) %>% 
  mutate(surf_epci = st_area(the_geom))

n_departement_exp_r52 <- importer_data(db = "referentiels",
                                       schema = "adminexpress",
                                       table = "n_departement_exp_r52") %>%
  select(insee_dep,nom_dep = nom) %>%
  mutate(surf_departement = st_area(the_geom))

n_region_exp_r52 <- importer_data(db = "referentiels",
                                  schema = "adminexpress",
                                  table = "n_region_exp_r52") %>% 
  select(insee_reg, nom_reg) %>%
  mutate(surf_region = st_area(the_geom))


# intersection communes ------------------
etat_sage_communes<-st_intersection(st_buffer(n_sage_r52, 0), st_buffer(n_commune_exp_r52, 0))
# mapview(etat_sage_communes)

indicateur_etat_sage_communes<-etat_sage_communes %>% 
  mutate(surf_sage_intersect = st_area(the_geom)) %>% 
  st_drop_geometry() %>%
  select(nom, code, lb_etat, insee_com, surf_commune, nom_com, surf_sage_intersect) %>% 
  group_by(nom_com, lb_etat) %>%
  mutate(pourc = round(sum(surf_sage_intersect)/surf_commune*100, digits = 0)) %>%
  ungroup() %>% 
  select(insee_com, nom_com, lb_etat, pourc) %>% 
  unique() %>% 
  group_by(insee_com) %>%
  mutate(difference = as_units(100) - sum(pourc)) %>%
  mutate(pourc = ifelse(difference<as_units(0) & lb_etat=="mis_en_oeuvre", pourc+difference, pourc)) %>% # traitement lié à la mauvaise qualité de la table n_sage_r52
  mutate(difference = ifelse(difference<as_units(0), as_units(0), difference)) %>%
  ungroup()

indicateur_etat_sage_communes <- bind_rows(indicateur_etat_sage_communes,
                                         n_commune_exp_r52 %>% 
                                           st_drop_geometry() %>% 
                                           select(insee_com,nom_com) %>% 
                                           mutate(lb_etat="hors_sage") %>% 
                                           left_join(indicateur_etat_sage_communes %>%
                                                       select(insee_com,difference) %>%
                                                       unique())
                                         ) 

indicateur_etat_sage_communes<-indicateur_etat_sage_communes %>% 
  group_by(insee_com) %>% 
  mutate(pourc=ifelse(is.na(pourc),difference,pourc)) %>% 
  ungroup() %>% 
  select(-difference) %>%
  filter(pourc>0) %>% 
  mutate(TypeZone="Communes") %>%
  rename(CodeZone = insee_com) %>%
  select(-nom_com) %>% 
  mutate_if(is.factor,as.character)


# intersection epci ---------
etat_sage_epci<-st_intersection(st_buffer(n_sage_r52,0),st_buffer(n_epci_zsup_r52,0))
# mapview(etat_sage_epci)

indicateur_etat_sage_epci<-etat_sage_epci %>% 
  mutate(surf_sage_intersect=st_area(the_geom)) %>% 
  st_drop_geometry() %>% 
  select(nom,code,lb_etat,siren_epci,nom_epci,surf_epci,surf_sage_intersect) %>%
  group_by(siren_epci,lb_etat) %>% 
  mutate(pourc=round(sum(surf_sage_intersect)/surf_epci*100,digits = 0)) %>% 
  ungroup() %>% 
  select(siren_epci,nom_epci,lb_etat,pourc) %>%
  unique() %>%
  group_by(siren_epci) %>% 
  mutate(difference=as_units(100)-sum(pourc)) %>% 
  mutate(pourc=ifelse(difference<as_units(0) & lb_etat=="mis_en_oeuvre",pourc+difference,pourc)) %>%
  mutate(difference=ifelse(difference<as_units(0),as_units(0),difference)) %>%
  ungroup()

indicateur_etat_sage_epci<-bind_rows(indicateur_etat_sage_epci,
                                     n_epci_zsup_r52 %>% 
                                       st_drop_geometry() %>% 
                                       select(siren_epci,nom_epci) %>% 
                                       mutate(lb_etat="hors_sage") %>% 
                                       left_join(indicateur_etat_sage_epci %>%
                                                   select(siren_epci,difference) %>% 
                                                   unique())
                                     ) 

indicateur_etat_sage_epci<-indicateur_etat_sage_epci %>% 
  group_by(siren_epci) %>% 
  mutate(pourc=ifelse(is.na(pourc),difference,pourc)) %>% 
  ungroup() %>% 
  select(-difference) %>%
  filter(pourc>0) %>%
  mutate(TypeZone="Epci") %>% 
  rename(CodeZone = siren_epci) %>%
  select(-nom_epci) %>% 
  mutate_if(is.factor,as.character)


# intersection départements ------------------
etat_sage_departements<-st_intersection(st_buffer(n_sage_r52,0),st_buffer(n_departement_exp_r52,0))
# mapview(etat_sage_departements)

indicateur_etat_sage_departements<-etat_sage_departements %>% 
  mutate(surf_sage_intersect=st_area(the_geom)) %>% 
  st_drop_geometry() %>%  
  select(nom,code,lb_etat,insee_dep,surf_departement,nom_dep,surf_sage_intersect) %>% 
  group_by(insee_dep,lb_etat) %>%
  mutate(pourc=round(sum(surf_sage_intersect)/surf_departement*100,digits = 0)) %>% 
  ungroup() %>% 
  select(insee_dep,nom_dep,lb_etat,pourc) %>% 
  unique() %>% 
  group_by(insee_dep) %>%
  mutate(difference=as_units(100)-sum(pourc)) %>%
  mutate(pourc=ifelse(difference<as_units(0) & lb_etat=="mis_en_oeuvre",pourc+difference,pourc)) %>% 
  mutate(difference=ifelse(difference<as_units(0),as_units(0),difference)) %>%
  ungroup()

indicateur_etat_sage_departements<-bind_rows(indicateur_etat_sage_departements,
                                             n_departement_exp_r52 %>% 
                                               st_drop_geometry() %>% 
                                               select(insee_dep,nom_dep) %>% 
                                               mutate(lb_etat="hors_sage") %>% 
                                               left_join(indicateur_etat_sage_departements %>%
                                                           select(insee_dep,difference) %>%
                                                           unique())
                                             ) 

indicateur_etat_sage_departements<-indicateur_etat_sage_departements %>% 
  group_by(insee_dep) %>% 
  mutate(pourc=ifelse(is.na(pourc),difference,pourc)) %>% 
  ungroup() %>% 
  select(-difference) %>%
  filter(pourc>0) %>% 
  mutate(TypeZone = "Départements") %>% 
  rename(CodeZone = insee_dep) %>%
  select(-nom_dep) %>% 
  mutate_if(is.factor,as.character)


# intersection région -------------
etat_sage_regions<-st_intersection(st_buffer(n_sage_r52,0),st_buffer(n_region_exp_r52,0))
# mapview(etat_sage_regions)!

indicateur_etat_sage_regions<-etat_sage_regions %>% 
  mutate(surf_sage_intersect = st_area(the_geom)) %>% 
  st_drop_geometry() %>% 
  select(nom,code,lb_etat,insee_reg,surf_region,surf_sage_intersect) %>% 
  group_by(lb_etat) %>% 
  mutate(pourc = round(sum(surf_sage_intersect)/surf_region*100,digits = 0)) %>% 
  ungroup() %>%
  select(insee_reg,lb_etat,pourc) %>%
  unique() %>%
  mutate(difference = as_units(100)-sum(pourc))

indicateur_etat_sage_regions<-bind_rows(indicateur_etat_sage_regions,
                                        n_region_exp_r52 %>% 
                                          st_drop_geometry() %>% 
                                          select(insee_reg) %>% 
                                          mutate(lb_etat="hors_sage") %>% 
                                          left_join(indicateur_etat_sage_regions %>%
                                                      select(insee_reg,difference) %>%
                                                      unique())
                                        ) 

indicateur_etat_sage_regions<-indicateur_etat_sage_regions %>% 
  mutate(pourc=ifelse(is.na(pourc),difference,pourc)) %>% 
  select(-difference) %>%
  mutate(TypeZone = "Régions") %>%
  rename(CodeZone = insee_reg) %>% 
  mutate_if(is.factor,as.character) %>% 
  filter(!is.na(lb_etat))


# addition des tables --------
indicateur_couverture_sage<-bind_rows(indicateur_etat_sage_communes,
                                      indicateur_etat_sage_epci,
                                      indicateur_etat_sage_departements,
                                      indicateur_etat_sage_regions) %>% 
  mutate_if(is.character,as.factor) %>%
  mutate(date=as.Date("2022-01-01")) %>%
  rename(variable = lb_etat, valeur = pourc)

indicateur_couverture_sage<-mutate(indicateur_couverture_sage,variable=case_when(variable=="mis_en_oeuvre"~ "pourcentage_territoire_couvert_par_sage_mis_en_oeuvre",
                                                                                 variable=="elaboration"~"pourcentage_territoire_couvert_par_sage_en_cours_d_elaboration",
                                                                                 variable=="premiere_revision"~"pourcentage_territoire_couvert_par_sage_en_premiere_revision",
                                                                                 variable=="hors_sage"~"pourcentage_territoire_hors_sage")) %>% 
  mutate_if(is.character,as.factor)

# selon SIGLOIRE, mise à jour en continue (tâche planifiée se déclenche tous les 1er du mois), donc 2022-01-01
# Zones d'application des Schémas d'aménagement et de gestion des eaux (SAGE) en Pays de la Loire
# https://catalogue.sigloire.fr/geonetwork/srv/fre/catalog.search;jsessionid=4BFDBE635A3699F7CC8151B1827679CE#/metadata/98864cf0-d06b-11de-b18a-00004f6210c3


rm(indicateur_etat_sage_communes,
   indicateur_etat_sage_epci,
   indicateur_etat_sage_departements,
   indicateur_etat_sage_regions)


# ajout du champs Zone avec COGiter ------------
communes_pdl<-communes %>% 
  filter(REG== '52') %>% 
  select(DEPCOM,NOM_DEPCOM,EPCI) %>% 
  select(DEPCOM,NOM_DEPCOM) %>% 
  rename(CodeZone=DEPCOM,Zone=NOM_DEPCOM) # 1238 obs

epci_pdl<-epci %>% 
  unnest(REGIONS_DE_L_EPCI) %>% 
  filter(REGIONS_DE_L_EPCI == '52') %>% 
  select(EPCI,NOM_EPCI) %>% 
  rename(CodeZone=EPCI,Zone=NOM_EPCI) # 71 obs

departements_pdl<-departements %>% 
  filter(REG=='52') %>% 
  select(DEP,NOM_DEP) %>% 
  rename(CodeZone=DEP,Zone=NOM_DEP)

region_pdl<-regions %>% 
  filter(REG=='52') %>% 
  select(REG,NOM_REG) %>% 
  rename(CodeZone=REG,Zone=NOM_REG)

territoire_pdl<-bind_rows(communes_pdl,
                          departements_pdl,
                          epci_pdl,
                          region_pdl) %>% 
  mutate_if(is.factor,as.character)

indicateur_couverture_sage<-left_join(indicateur_couverture_sage,territoire_pdl) %>% 
  mutate_if(is.character,as.factor) %>% 
  select(TypeZone,CodeZone,Zone,date,variable,valeur) %>% 
  filter(!is.na(variable))

specifique_couverture_sage<-indicateur_couverture_sage %>%
  pivot_wider(names_from = variable,values_from = valeur, values_fill = 0) %>% 
  mutate(pourcentage_territoire_couvert_par_sage_mis_en_oeuvre = ifelse(is.na(pourcentage_territoire_couvert_par_sage_mis_en_oeuvre),0,pourcentage_territoire_couvert_par_sage_mis_en_oeuvre),
         pourcentage_territoire_couvert_par_sage_en_cours_d_elaboration = ifelse(is.na(pourcentage_territoire_couvert_par_sage_en_cours_d_elaboration),0,pourcentage_territoire_couvert_par_sage_en_cours_d_elaboration),
         # pourcentage_territoire_couvert_par_sage_en_premiere_revision = ifelse(is.na(pourcentage_territoire_couvert_par_sage_en_premiere_revision),0,pourcentage_territoire_couvert_par_sage_en_premiere_revision),
         pourcentage_territoire_hors_sage = ifelse(is.na(pourcentage_territoire_hors_sage),0,pourcentage_territoire_hors_sage)) %>% 
  mutate(pourcentage_territoire_couvert_par_sage_en_premiere_revision = 0)


# table de passage territoire/SAGE ----------

ref_table_passage_communes_sage<-etat_sage_communes %>%  
  st_drop_geometry() %>% 
  mutate_if(is.factor,as.character) %>% 
  mutate(TypeZone = "Communes") %>%
  select(TypeZone,insee_com,nom_com,code,nom,lb_etat) %>% 
  rename(CodeZone = insee_com,
         Zone = nom_com,
         code_sage = code,
         nom_sage = nom,
         etat_d_avancement_sage = lb_etat)

ref_table_passage_epci_sage<-etat_sage_epci  %>% 
  st_drop_geometry() %>% 
  mutate_if(is.factor,as.character) %>% 
  mutate(TypeZone = "Epci") %>%
  select(TypeZone,siren_epci,nom_epci,code,nom,lb_etat) %>% 
  rename(CodeZone = siren_epci,
         Zone = nom_epci,
         code_sage = code,
         nom_sage = nom,
         etat_d_avancement_sage = lb_etat)

ref_table_passage_departements_sage<-etat_sage_departements %>%
  st_drop_geometry() %>% 
  mutate_if(is.factor,as.character) %>% 
  mutate(TypeZone = "Départements") %>%
  select(TypeZone,insee_dep,nom_dep,code,nom,lb_etat) %>% 
  rename(CodeZone = insee_dep,
         Zone = nom_dep,
         code_sage = code,
         nom_sage = nom,
         etat_d_avancement_sage = lb_etat)

ref_table_passage_regions_sage<-etat_sage_regions %>%
  st_drop_geometry() %>% 
  mutate_if(is.factor,as.character) %>% 
  mutate(TypeZone = "Régions") %>%
  select(TypeZone,insee_reg,code,nom,lb_etat) %>% 
  mutate(Zone = "Pays de la Loire") %>% 
  rename(CodeZone = insee_reg,
         code_sage = code,
         nom_sage = nom,
         etat_d_avancement_sage = lb_etat) %>%
  select(TypeZone,CodeZone,Zone,everything())

ref_table_passage_territoire_sage<-bind_rows(ref_table_passage_communes_sage,
                                             ref_table_passage_epci_sage,
                                             ref_table_passage_departements_sage,
                                             ref_table_passage_regions_sage) %>% 
  mutate_if(is.character,as.factor) %>% 
  mutate(date=as.Date("2022-01-01"))

rm(etat_sage_epci,
   etat_sage_communes,
   etat_sage_departements,
   etat_sage_regions,
   ref_table_passage_communes_sage,
   ref_table_passage_epci_sage,
   ref_table_passage_departements_sage,
   ref_table_passage_regions_sage)


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = specifique_couverture_sage,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "specifique_couverture_sage",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("TypeZone", "CodeZone", "Zone", "date"), # déclaration d'une clé primaire sur la table postée
            user = "does")


# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(specifique_couverture_sage), c("TypeZone", "CodeZone", "Zone", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, 
               table = "specifique_couverture_sage", 
               schema = "portrait_territoires",
               db = "datamart",
               user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table)

## commentaires de la table
commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "specifique_couverture_sage", 
                user = "does")


# versement de la table de passage et métadonnées ----------------
poster_data(data = ref_table_passage_territoire_sage,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "specifique_table_passage_territoire_sage",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("TypeZone", "CodeZone", "Zone", "code_sage", "nom_sage", "date"), # déclaration d'une clé primaire sur la table postée
            user = "does")

var <- setdiff(names(ref_table_passage_territoire_sage), c("TypeZone", "CodeZone", "Zone", "date"))
nom_script_sce <- "specifique_table_passage_territoire_sage"

metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  filter(source == nom_script_sce) %>% 
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, 
               table = "specifique_table_passage_territoire_sage", 
               schema = "portrait_territoires",
               db = "datamart",
               user = "does")

## Récupération des métadonnées de la source
nom_sce <- "table_passage_territoire_sage"

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table)

## commentaires de la table
commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "specifique_table_passage_territoire_sage", 
                user = "does")
