# specifique_gestion_durable_foret

# librairies -------
library(readxl)
library(tidyverse)
library(lubridate)
library(mefa4)
library(COGiter)
library(datalibaba)

rm(list = ls())


# chargement des données du CRPF ----------------
# données élaborées par le Centre Régional de la Propriété Forestière (CRPF) à partir d'une requête spatiale EPCI

# Au titre du Code Forestier 5 documents sont considérés comme des Documents de Gestion Durable. 
# En l'occurrence, pour l'exercice demandé, il est donc légitime de les additionner.

# PSG = plan simple de gestion (pour les forêts > 25 ha) --> garantie de gestion durable
# PSG volontaire = idem pour forêts de 10 à 25 ha --> garantie de gestion durable
# RTG = règlement type de gestion, càd pour des surfaces < 25 ha 
# adhésion à un règlement type établi par un gestionnaire habilité pour cela,
# la plupart du temps une coopérative --> garantie de gestion durable
# CBPS = code de bonnes pratiques sylvicoles (forêts < 25 ha) : adhésion à des principes de gestion durable
# devant être respectés --> présomption de garantie de gestion durable
# CBPS+ = idem assorti d'un programme de coupes et travaux spécifique à la forêt concernée --> présomption de garantie de gestion durable

# Les chiffres ne concernent donc que la forêt privée. Celle-ci représente 90% de la forêt des Pays de la Loire.
# Les forêts publiques sont, sauf exception, gérées par l'ONF sur la base d'un aménagement forestier,
# constituant, lui aussi, une garantie de gestion durable. 

# Le pourcentage de gestion durable en forêt publique est 
# donc proche de 100% (aux forêts en cours de renouvellement d'aménagement si latence, 
# ou aux forêts nouvellement acquises par des collectivités près).

# La surface forestière de référence retenue, nécessaire pour obtenir un pourcentage, 
# est celle de la BD Forêt de l'IGN du moment, même si l'on sait qu'elle est fluctuante.

# Corrections à la main de la ligne 271 du fichier .xlsx : 
# de la ligne 271 : CBPS+ au lieu de CBPS déjà renseigné pour CC du Val de Sarthe
# et de la ligne 91 : Obligatoire (plus de 25 ha) au lieu de PSG - nouveau seuil 2011 pour CC Châteaubriant-Derval

crpf_dgd_epci<-read_excel(path = "extdata/DGDpar EPCI_Copie de stat_pdl_epci.xlsx")


# traitement des données ----------
crpf_dgd_epci_total<-crpf_dgd_epci %>% 
  filter(!is.na(`Proportion de forêt sous DGD (%)`)) %>% 
  rename(NOM_EPCI=EPCI,
         surface_gestion_durable = `Surface DGD (ha)`,
         surface_totale_foret = `Surface forêt (BD Forêt v2) (ha)`,
         pourcentage_foret_geree_durablement = `Proportion de forêt sous DGD (%)`)

liste_EPCI<-crpf_dgd_epci_total %>% 
  select(NOM_EPCI)

crpf_dgd_epci_detail<-crpf_dgd_epci %>% 
  select(-c(`Surface forêt (BD Forêt v2) (ha)`,`Proportion de forêt sous DGD (%)`)) %>%
  mutate(EPCI=case_when(EPCI=="Volontaire (moins de 25 ha)"~"PSG_volontaire",
                        EPCI=="Obligatoire (plus de 25 ha)"~"PSG_obligatoire",
                        T~EPCI)) %>% 
  filter(EPCI!="PSG") %>% 
  rename(surface_ha=`Surface DGD (ha)`) %>% 
  mutate(NOM_EPCI=ifelse(EPCI %in% unique(liste_EPCI$NOM_EPCI),EPCI,NA)) %>% 
  mutate(NOM_EPCI=ifelse(is.na(NOM_EPCI),lag(NOM_EPCI),NOM_EPCI)) %>% # pas très élégant
  mutate(NOM_EPCI=ifelse(is.na(NOM_EPCI),lag(NOM_EPCI),NOM_EPCI)) %>% 
  mutate(NOM_EPCI=ifelse(is.na(NOM_EPCI),lag(NOM_EPCI),NOM_EPCI)) %>% 
  mutate(NOM_EPCI=ifelse(is.na(NOM_EPCI),lag(NOM_EPCI),NOM_EPCI)) %>% 
  mutate(NOM_EPCI=ifelse(is.na(NOM_EPCI),lag(NOM_EPCI),NOM_EPCI)) %>% 
  filter(EPCI %notin% unique(liste_EPCI$NOM_EPCI)) %>% 
  rename(document_gestion_durable=EPCI) %>%
  complete(document_gestion_durable,NOM_EPCI,fill = list(surface_ha =0)) %>%
  pivot_wider(names_from = document_gestion_durable,values_from = surface_ha)

crpf_dgd_epci<-left_join(crpf_dgd_epci_detail,crpf_dgd_epci_total)


# renommage des EPCI en référence aux EPCI du package COGiter ----------
epci_pdl<-epci %>% filter(grepl(52,REGIONS_DE_L_EPCI))
x<-inner_join(liste_EPCI,epci) # 60 obs
y<-anti_join(liste_EPCI,epci) # 10 obs

crpf_dgd_epci<-crpf_dgd_epci %>% 
  mutate(NOM_EPCI=case_when(NOM_EPCI=="CA Agglomération du Choletais"~ "CA du Choletais",
                            NOM_EPCI=="CA de la Presqu'île de Guérande Atlantique (CAP ATLANTIQUE)"~"CA de la Presqu'île de Guérande Atlantique (Cap Atlantique)",
                            NOM_EPCI=="CA La Roche sur Yon - Agglomération"~"CA La Roche-sur-Yon Agglomération",
                            NOM_EPCI=="CA Laval Agglomération"~"CA de Laval Agglomération",
                            NOM_EPCI=="CC du Pays de Fontenay-Vendée"~"CC Pays de Fontenay-Vendée",
                            NOM_EPCI=="CC du Pays de Pontchâteau St-Gildas-des-Bois"~"CC du Pays de Pontchâteau Saint-Gildas-des-Bois",
                            NOM_EPCI=="CC du Pays de St Gilles-Croix-de-Vie"~"CC du Pays de Saint-Gilles-Croix-de-Vie",
                            NOM_EPCI=="CC du Sud Estuaire"~"CC du Sud-Estuaire",
                            NOM_EPCI=="CC Maine Coeur de Sarthe"~"CC Maine Cœur de Sarthe",
                            NOM_EPCI=="CC Terres de Montaigu, CC Montaigu-Rocheservière"~"CC Terres-de-Montaigu, communauté de communes Montaigu-Rocheservière",
                            T~NOM_EPCI))

x<-semi_join(crpf_dgd_epci,epci_pdl) # 70 obs
y<-anti_join(epci_pdl,crpf_dgd_epci) # CC de l'Île de Noirmoutier


# ajout de l'EPCI CC de l'Île de Noirmoutier -------- 
# consultation du sgdb avec QGIS : consultation/foret/n_foret_prive_dgd_s_r52 et n_foret_publique_2009_s_r52
# aucune forêt privée (avec un document de gestion forestière durable) ou publique pour CC de l'Île de Noirmoutier

specifique_gestion_durable_foret<-left_join(epci_pdl %>% select(EPCI,NOM_EPCI),crpf_dgd_epci)


# finalisation de la table en format large ----------
specifique_gestion_durable_foret<-crpf_dgd_epci %>%
  left_join(epci_pdl) %>% 
  gather(key = "variable",value = "valeur",CBPS:pourcentage_foret_geree_durablement) %>%
  mutate(valeur=ifelse(is.na(valeur),0,valeur)) %>% 
  mutate(TypeZone="Epci") %>% 
  rename(CodeZone = EPCI,Zone=NOM_EPCI) %>% 
  mutate(date = dmy("01-01-2021")) %>% 
  mutate_if(is.character,as.factor) %>% 
  select(TypeZone,Zone,CodeZone,date,variable,valeur) %>% 
  pivot_wider(names_from = variable,values_from = valeur)


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = specifique_gestion_durable_foret, 
            table = "specifique_gestion_durable_foret",
            schema = "portrait_territoires",
            db = "datamart",
            user = "does", 
            overwrite = TRUE)


# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(specifique_gestion_durable_foret), c("TypeZone", "CodeZone", "Zone", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, 
               table = "specifique_gestion_durable_foret", 
               schema = "portrait_territoires",
               db = "datamart",
               user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table)

## commentaires de la table
commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "specifique_gestion_durable_foret", 
                user = "does")
