
# indicateur_captage_prioritaire_protection_action

# librairies ----------
library(datalibaba)
library(tidyverse)
library(sf)
library(lubridate)
library(googlesheets4)

rm(list=ls())


# limites administratives ----------

n_commune_exp_r52<-importer_data(db = "referentiels",
                                 schema = "adminexpress",
                                 table = "n_commune_exp_r52") %>%
  select(insee_com, nom_com = nom) %>%
  mutate(surf_commune = st_area(the_geom))

n_epci_zsup_r52<-importer_data(db = "consultation",
                               schema = "donnee_generique",
                               table = "n_epci_zsup_r52") %>%
  select(siren_epci, nom_epci) %>% 
  mutate(surf_epci = st_area(the_geom))

n_departement_exp_r52<-importer_data(db = "referentiels",
                                     schema = "adminexpress",
                                     table = "n_departement_exp_r52") %>%
  select(insee_dep, nom_dep = nom) %>% 
  mutate(surf_departement = st_area(the_geom))

n_region_exp_r52<-importer_data(db = "referentiels",
                                schema = "adminexpress",
                                table = "n_region_exp_r52") %>% 
  select(insee_reg, nom_reg) %>%
  mutate(surf_region = st_area(the_geom))


# protection des captages --------------
r_ppcaptages_s_r52 <- importer_data(db = "si_eau",
                                    schema = "eau_potable",
                                    table = "r_ppcaptages_s_r52") # 878 obs
protection_captage <- summarise(st_buffer(r_ppcaptages_s_r52, 0), do_union = TRUE)


# intersection protection et territoires ----------

intersection_protection_captage_commune <- st_intersection(st_buffer(protection_captage, 0), st_buffer(n_commune_exp_r52, 0))

intersection_protection_captage_commune_2 <- intersection_protection_captage_commune %>% 
  mutate(surf_protection_captage = st_area(geom)) %>% 
  st_drop_geometry() %>% 
  group_by(insee_com, nom_com) %>% 
  mutate(part_protection_captage = round(surf_protection_captage/surf_commune*100, digits = 2)) %>% 
  ungroup() %>%
  right_join(n_commune_exp_r52 %>% st_drop_geometry()) %>% 
  select(insee_com, nom_com, part_protection_captage) %>% 
  mutate(part_protection_captage = ifelse(is.na(part_protection_captage), 0, part_protection_captage)) %>% 
  mutate(TypeZone = "Communes", date = today()) %>% 
  rename(CodeZone = insee_com, Zone = nom_com)

intersection_protection_captage_epci <- st_intersection(st_buffer(protection_captage, 0), st_buffer(n_epci_zsup_r52, 0))

intersection_protection_captage_epci_2 <- intersection_protection_captage_epci %>% 
  mutate(surf_protection_captage = st_area(geom)) %>% 
  st_drop_geometry() %>% 
  group_by(siren_epci, nom_epci) %>% 
  mutate(part_protection_captage = round(surf_protection_captage/surf_epci*100, digits = 2)) %>% 
  ungroup() %>% 
  right_join(n_epci_zsup_r52 %>% st_drop_geometry()) %>% 
  select(siren_epci, nom_epci, part_protection_captage) %>% 
  mutate(part_protection_captage = ifelse(is.na(part_protection_captage), 0, part_protection_captage)) %>% 
  mutate(TypeZone = "Epci", date=today()) %>% 
  rename(CodeZone = siren_epci, Zone = nom_epci)

intersection_protection_captage_departement <- st_intersection(st_buffer(protection_captage, 0), st_buffer(n_departement_exp_r52, 0))

intersection_protection_captage_departement_2 <- intersection_protection_captage_departement %>% 
  mutate(surf_protection_captage = st_area(geom)) %>% 
  st_drop_geometry() %>% 
  group_by(insee_dep, nom_dep) %>% 
  mutate(part_protection_captage = round(surf_protection_captage/surf_departement*100, digits = 2)) %>% 
  ungroup() %>%
  right_join(n_departement_exp_r52 %>% st_drop_geometry()) %>% 
  select(insee_dep, nom_dep, part_protection_captage) %>% 
  mutate(part_protection_captage = ifelse(is.na(part_protection_captage), 0, part_protection_captage)) %>% 
  mutate(TypeZone="Départements", date=today()) %>% 
  rename(CodeZone = insee_dep, Zone = nom_dep)

intersection_protection_captage_region <- st_intersection(st_buffer(protection_captage, 0), st_buffer(n_region_exp_r52, 0))

intersection_protection_captage_region_2 <- intersection_protection_captage_region %>% 
  mutate(surf_protection_captage = st_area(geom)) %>% 
  st_drop_geometry() %>%  
  mutate(part_protection_captage = round(surf_protection_captage/surf_region*100, digits = 2)) %>% 
  select(insee_reg, nom_reg, part_protection_captage) %>% 
  mutate(TypeZone="Régions", date=today()) %>% 
  mutate(part_protection_captage = as.numeric(part_protection_captage)) %>% 
  rename(CodeZone = insee_reg, Zone = nom_reg)

intersection_protection_captage_territoire<-bind_rows(intersection_protection_captage_commune_2,
                                                      intersection_protection_captage_epci_2,
                                                      intersection_protection_captage_departement_2,
                                                      intersection_protection_captage_region_2) %>% 
  select(TypeZone, CodeZone, Zone, date, part_protection_captage)


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = intersection_protection_captage_territoire,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "indicateur_captage_prioritaire_protection_action",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("TypeZone", "Zone", "CodeZone", "date"), # déclaration d'une clé primaire sur la table postée
            user = "does")


# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(intersection_protection_captage_territoire), c("TypeZone", "Zone", "CodeZone", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour depcom et date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, 
               table = "indicateur_captage_prioritaire_protection_action", 
               schema = "portrait_territoires",
               db = "datamart", 
               user = "does")

## récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table)

## commentaires de la table
commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "indicateur_captage_prioritaire_protection_action", 
                user = "does")
