
# ocsge_comparaison_auran_ddtm85

# comparaison entre nomenclatures ddtm 85 et auran

# librairies ------
library(DBI)
library(RPostgreSQL)
library(dplyr)
library(COGiter)
library(tidyr)

rm(list = ls())

# chargement data ----------
drv <- dbDriver("PostgreSQL")
con_datamart <- dbConnect(drv, 
                          dbname="datamart", 
                          host=Sys.getenv("server"), 
                          port=Sys.getenv("port"),
                          user=Sys.getenv("userid"),
                          password=Sys.getenv("pwd_does"))
postgresqlpqExec(con_datamart, "SET client_encoding = 'windows-1252'") 

cogifiee_ocsge_ddtm85<-dbReadTable(con_datamart,c("portrait_territoires","cogifiee_ocsge"))

cogifiee_ocsge_auran<-dbReadTable(con_datamart,c("portrait_territoires","cogifiee_ocsge_auran"))


# comparaison espaces artificialisés ---------
espace_artificialise_ddtm85<-select(cogifiee_ocsge_ddtm85,TypeZone,Zone,CodeZone,date,
                                    espace_artificialise_ddtm85=espace_artificialise)

espace_artificialise_auran<-cogifiee_ocsge_auran %>%
  group_by(TypeZone,Zone,CodeZone,date) %>% 
  mutate(espace_artificialise=type_1+type_2+type_3+type_4+type_5) %>% 
  ungroup() %>% 
  select(TypeZone,Zone,CodeZone,date,espace_artificialise_auran=espace_artificialise)

comparaison_espace_espace_artificialise_auran_ddtm85<-inner_join(espace_artificialise_auran,
                                                                 espace_artificialise_ddtm85) %>% 
  mutate(espace_artificialise_auran_ha=round(espace_artificialise_auran/10000,digits = 2), # conversion en ha
         espace_artificialise_ddtm85_ha=round(espace_artificialise_ddtm85/10000,digits = 2)) %>% 
  mutate(difference_ha = espace_artificialise_auran_ha - espace_artificialise_ddtm85_ha) %>%
  select(-espace_artificialise_auran,-espace_artificialise_ddtm85) %>% 
  filter(TypeZone != "France") %>% 
  mutate_if(is.character,as.factor)


# comparaison espaces agricoles ----------
espace_agricole_ddtm85<-select(cogifiee_ocsge_ddtm85,TypeZone,Zone,CodeZone,date,
                                    espace_agricole_ddtm85=espace_agricole)

espace_agricole_auran<-select(cogifiee_ocsge_auran,TypeZone,Zone,CodeZone,date,
                               espace_agricole_auran=type_6)

comparaison_espace_agricole_auran_ddtm85<-inner_join(espace_agricole_auran,
                                                     espace_agricole_ddtm85) %>% 
  mutate(espace_agricole_auran_ha=round(espace_agricole_auran/10000,digits = 2), # conversion en ha
         espace_agricole_ddtm85_ha=round(espace_agricole_ddtm85/10000,digits = 2)) %>% 
  mutate(difference_ha = espace_agricole_auran_ha - espace_agricole_ddtm85_ha) %>%
  select(-espace_agricole_auran,-espace_agricole_ddtm85) %>% 
  filter(TypeZone != "France") %>% 
  mutate_if(is.character,as.factor)


# comparaison espaces naturels boisés --------------
espace_naturel_boise_ddtm85<-select(cogifiee_ocsge_ddtm85,TypeZone,Zone,CodeZone,date,
                               espace_naturel_boise_ddtm85=surface_naturelle_boisee)

espace_naturel_boise_auran<-select(cogifiee_ocsge_auran,TypeZone,Zone,CodeZone,date,
                                   espace_naturel_boise_auran=type_7)

comparaison_espace_naturel_boise_auran_ddtm85<-inner_join(espace_naturel_boise_auran,
                                                          espace_naturel_boise_ddtm85) %>% 
  mutate(espace_naturel_boise_auran_ha=round(espace_naturel_boise_auran/10000,digits = 2), # conversion en ha
         espace_naturel_boise_ddtm85_ha=round(espace_naturel_boise_ddtm85/10000,digits = 2)) %>% 
  mutate(difference_ha = espace_naturel_boise_auran_ha - espace_naturel_boise_ddtm85_ha) %>%
  select(-espace_naturel_boise_auran,-espace_naturel_boise_ddtm85) %>% 
  filter(TypeZone != "France") %>% 
  mutate_if(is.character,as.factor)


# comparaison autres espaces naturels -------------
autre_espace_naturel_ddtm85<-select(cogifiee_ocsge_ddtm85,TypeZone,Zone,CodeZone,date,
                                    autre_espace_naturel_ddtm85=autre_surface_naturelle)

autre_espace_naturel_auran<-select(cogifiee_ocsge_auran,TypeZone,Zone,CodeZone,date,
                                   autre_espace_naturel_auran=type_8)

comparaison_autre_espace_naturel_auran_ddtm85<-inner_join(autre_espace_naturel_auran,
                                                          autre_espace_naturel_ddtm85) %>% 
  mutate(autre_espace_naturel_auran_ha=round(autre_espace_naturel_auran/10000,digits = 2), # conversion en ha
         autre_espace_naturel_ddtm85_ha=round(autre_espace_naturel_ddtm85/10000,digits = 2)) %>% 
  mutate(difference_ha = autre_espace_naturel_auran_ha - autre_espace_naturel_ddtm85_ha) %>%
  select(-autre_espace_naturel_auran,-autre_espace_naturel_ddtm85) %>% 
  filter(TypeZone != "France") %>% 
  mutate_if(is.character,as.factor)


# comparaison surfaces en eau -----------
surface_en_eau_ddtm85<-select(cogifiee_ocsge_ddtm85,TypeZone,Zone,CodeZone,date,
                              surface_en_eau_ddtm85=surface_en_eau)

surface_en_eau_auran<-select(cogifiee_ocsge_auran,TypeZone,Zone,CodeZone,date,
                             surface_en_eau_auran=type_9)

comparaison_surface_en_eau_auran_ddtm85<-inner_join(surface_en_eau_auran,
                                                    surface_en_eau_ddtm85) %>% 
  mutate(surface_en_eau_auran_ha=round(surface_en_eau_auran/10000,digits = 2), # conversion en ha
         surface_en_eau_ddtm85_ha=round(surface_en_eau_ddtm85/10000,digits = 2)) %>% 
  mutate(difference_ha = surface_en_eau_auran_ha - surface_en_eau_ddtm85_ha) %>%
  select(-surface_en_eau_auran,-surface_en_eau_ddtm85) %>% 
  filter(TypeZone != "France") %>% 
  mutate_if(is.character,as.factor)


# sauvegarde ----------
save(comparaison_espace_espace_artificialise_auran_ddtm85,
     comparaison_espace_agricole_auran_ddtm85,
     comparaison_espace_naturel_boise_auran_ddtm85,
     comparaison_autre_espace_naturel_auran_ddtm85,
     comparaison_surface_en_eau_auran_ddtm85,
     file = "sysdata/ocsge_comparaison_auran_ddtm85.RData")


# graphiques niveau régional ------------
ocsge_ddtm85<-pivot_longer(cogifiee_ocsge_ddtm85,
                          cols = a_definir:surface_naturelle_boisee,
                          names_to = "variable",
                          values_to = "valeur") %>%
  filter(variable != "a_definir")

ocsge_auran<-cogifiee_ocsge_auran %>% 
  group_by(TypeZone,Zone,CodeZone,date) %>% 
  mutate(espace_artificialise=type_1+type_2+type_3+type_4+type_5) %>% 
  ungroup() %>% 
  select(-c(type_1,type_2,type_3,type_4,type_5)) %>% 
  rename(espace_agricole=type_6,
         surface_naturelle_boisee=type_7,
         autre_surface_naturelle=type_8,
         surface_en_eau=type_9) %>% 
  select(-type_0) %>%
  select(TypeZone,Zone,CodeZone,date,
         autre_surface_naturelle,
         espace_agricole,
         espace_artificialise,
         surface_en_eau,
         surface_naturelle_boisee) %>% 
  gather(key = "variable",value = "valeur",autre_surface_naturelle:surface_naturelle_boisee)

#  donut de la typologie de l'ocsge
library(leaflet)
library(highcharter)
library(htmlwidgets)

typologie_ocsge<- ocsge_ddtm85 %>% 
  select(variable) %>%
  unique()

factpal_ocsge_typologie <- colorFactor(palette = c("green", "#FFFF00", "#FF9900", "blue","#006600"),
                                       levels = typologie_ocsge$variable,
                                       reverse = FALSE)
# Levels: 
# autre surface naturelle,
# espace agricole, 
# espace artificialisé, 
# surface en eau, 
# surface naturelle boisée

couleur_ocsge_typologie<-factpal_ocsge_typologie(typologie_ocsge$variable)

mil<-2013
modele<-"auran"

if(modele=="ddtm85"){
  ocsge_modele<-ocsge_ddtm85
}
if(modele=="auran"){
  ocsge_modele<-ocsge_auran
}

data_donut_oscge<-ocsge_modele %>%
  group_by(TypeZone,Zone,CodeZone,date) %>%
  mutate(somme_superficie_typologie = sum(valeur)) %>%
  ungroup() %>%
  mutate(pourcentage_superficie_typologie = round(valeur/somme_superficie_typologie*100,digits = 1)) %>%
  filter(date ==paste0(mil,"-06-30")) %>%
  select(-c(valeur,somme_superficie_typologie)) %>%
  rename(valeur = pourcentage_superficie_typologie) %>%
  filter(TypeZone == "Régions") %>%
  filter(CodeZone == "52")

hc<-hchart(data_donut_oscge,
         type = "pie",
         hcaes(x = variable,y = valeur)) %>%
    hc_title(text = paste0("Typologie de l'occupation des sols selon modèle ",modele),align = "left") %>%
    hc_subtitle(text = paste0("au 30 juin ",mil),align = "left") %>%
    hc_tooltip(headerFormat = '',
               pointFormat = '<b>{point.variable}<b><br/>{point.y} %') %>%
    hc_plotOptions(pie = list(innerSize = '50%')) %>%
    hc_colors(colors = couleur_ocsge_typologie) %>%
    hc_exporting(enabled = TRUE,
                 buttons = list(contextButton = list(menuItems = c("downloadPNG", "downloadJPEG","downloadPDF", "downloadCSV" )))
                 )
hc

saveWidget(hc, file=paste0("extdata/donut_ocsge_",modele,"_",mil,".html"), selfcontained=FALSE)
  
  
  
  
