
# specifique_protection_naturelle

# librairies ----------
library(datalibaba)
library(tidyverse)
library(sf)
# library(mapview)
library(COGiter)
library(googlesheets4)

rm(list=ls())


# chargement des données du SGBD ------
n_enp_rnn_s_r52 <- importer_data(db = "consultation",
                               schema = "nature_paysage_biodiversite",
                               table = "n_enp_rnn_s_r52")
n_enp_rnr_s_r52 <- importer_data(db = "consultation",
                               schema = "nature_paysage_biodiversite",
                               table = "n_enp_rnr_s_r52")
n_enp_rb_s_r52 <- importer_data(db = "consultation",
                              schema = "nature_paysage_biodiversite",
                              table = "n_enp_rb_s_r52")
n_enp_apb_s_r52 <- importer_data(db = "consultation",
                              schema = "nature_paysage_biodiversite",
                              table = "n_enp_apb_s_r52")
n_enp_apg_s_r52 <- importer_data(db = "consultation",
                               schema = "nature_paysage_biodiversite",
                               table = "n_enp_apg_s_r52")
n_enp_rcfs_s_r52 <- importer_data(db = "consultation",
                                 schema = "nature_paysage_biodiversite",
                                 table = "n_enp_rcfs_s_r52")
n_enp_scl_s_r52 <- importer_data(db = "consultation",
                                  schema = "nature_paysage_biodiversite",
                                  table = "n_enp_scl_s_r52")
n_enp_pnr_s_r52 <- importer_data(db = "consultation",
                                 schema = "nature_paysage_biodiversite",
                                 table = "n_enp_pnr_s_r52")
n_enp_pnr_s_r52 <- importer_data(db = "consultation",
                                 schema = "nature_paysage_biodiversite",
                                 table = "r_site_natura_2000_table_r52")
n_enp_ramsar_s_r52 <- importer_data(db = "consultation",
                                 schema = "nature_paysage_biodiversite",
                                 table = "n_enp_ramsar_s_r52")

r_patrimoine_mondial_r52 <- importer_data(db = "consultation",
                                    schema = "site_paysage",
                                    table = "r_patrimoine_mondial_r52")

# limites administratives
n_region_exp_r52<-importer_data(db = "referentiels",
                                schema = "adminexpress",
                                table = "n_region_exp_r52") %>% 
  select(insee_reg,nom_reg) %>%
  mutate(surf_region=st_area(the_geom))

n_departement_exp_r52<-importer_data(db = "referentiels",
                                     schema = "adminexpress",
                                     table = "n_departement_exp_r52") %>%
  select(insee_dep,nom) %>% 
  rename(nom_dep = nom) %>% 
  mutate(surf_departement=st_area(the_geom))

n_commune_exp_r52<-importer_data(db = "referentiels",
                                 schema = "adminexpress",
                                 table = "n_commune_exp_r52") %>%
  select(insee_com,nom,siren_epci) %>% 
  rename(nom_com = nom) %>% 
  mutate(surf_commune=st_area(the_geom))

n_epci_zsup_r52<-importer_data(db = "consultation",
                               schema = "donnee_generique",
                               table = "n_epci_zsup_r52") %>%
  select(siren_epci,dep_epci,nom_epci) %>% 
  mutate(surf_epci=st_area(the_geom))


# import de shp pour sites CEN -------------
# courriel de Thomas OBE du 2021-01-28 :les sites acquis et gérés des CEN ne remontent pas obligatoirement par la base DREAL,
# ils vont directement sur la base INPN du Museum. On les trouve sur leur site avec les surfaces correspondantes. 
# On peut faire une demande pour obtenir les couches SIG. 
# Ou alors directement au CEN, le directeur est Franck Boitard : f.boitard@cenpaysdelaloire.fr
# Envoie de la couche nationale (shp) disponible fin 2020 sur le site INPN, mais peut-être pas tout à fait complète
# (quelques sites peuvent avoir été ajoutés en 2020 et non encore saisis dans la base, à la marge).

download.file(url = "https://inpn.mnhn.fr/docs/Shape/cen.zip", destfile = "extdata/cen.zip")
unzip(zipfile = 'extdata/cen.zip',exdir = "extdata")
n_epn_scen_s_000 <- st_read(dsn="extdata/scen2018_12",layer='N_ENP_SCEN_S_000')


# protections fortes ---------
x<-st_union(n_enp_rnn_s_r52 %>% select(id_local),n_enp_rnr_s_r52 %>% select(id_local))
x <- summarise(x,do_union = TRUE)
x<-st_union(x,n_enp_rb_s_r52 %>% select(id_local))
x <- summarise(x,do_union = TRUE)
x<-st_union(x,n_enp_apb_s_r52%>% select(id_local))
x <- summarise(x,do_union = TRUE)
protection_forte<-st_union(x,n_enp_apg_s_r52 %>% select(id_local))
protection_forte <- summarise(protection_forte, do_union = TRUE)
rm(x)


# protections 'élargies' ---------
x<-st_union(protection_forte,n_enp_rcfs_s_r52 %>% select(id_local))
x <- summarise(x,do_union = TRUE)
x<-st_union(x,st_buffer(n_enp_scl_s_r52%>% select(id_local),0))
x <- summarise(x,do_union = TRUE)
x<-st_union(x,st_buffer(n_epn_scen_s_000 %>% select(ID_LOCAL),0))
x <- summarise(x,do_union = TRUE)
x<-st_union(x,n_enp_pnr_s_r52 %>% select(id_local))
x <- summarise(x,do_union = TRUE)
x<-st_union(x,r_site_natura_2000_table_r52 %>% select(id_mnhn))
x <- summarise(x,do_union = TRUE) # très très long
x<-st_union(x,n_enp_ramsar_s_r52 %>% select(id_local))
x <- summarise(x,do_union = TRUE)
protection_elargie<-st_union(x,r_patrimoine_mondial_r52 %>% select(id_bien))
protection_elargie <- summarise(protection_elargie,do_union = TRUE)
rm(x)


# intersection des protections fortes et des territoires ---------
indicateur_protection_forte_commune <- st_intersection(st_buffer(protection_forte, 0),
                                                       st_buffer(n_commune_exp_r52, 0)) %>% 
  mutate(surf_protection_forte = st_area(the_geom)) %>% 
  mutate(part_protection_forte = round(surf_protection_forte/surf_commune*100, digits = 2)) %>% 
  st_drop_geometry() %>% 
  right_join(n_commune_exp_r52 %>% 
               st_drop_geometry() %>% 
               select(insee_com, nom_com, surf_commune)) %>% 
  select(insee_com, nom_com, part_protection_forte) %>% 
  mutate(part_protection_forte = ifelse(is.na(part_protection_forte), 0, part_protection_forte)) %>% 
  rename(CodeZone = insee_com, Zone = nom_com, valeur = part_protection_forte) %>% 
  mutate(TypeZone = "Communes", date = as.Date("2022-01-01"), variable="part_protection_forte")

indicateur_protection_forte_epci <- st_intersection(st_buffer(protection_forte,0),
                                                    st_buffer(n_epci_zsup_r52,0)) %>% 
  mutate(surf_protection_forte = st_area(the_geom)) %>% 
  mutate(part_protection_forte = round(surf_protection_forte/surf_epci*100, digits = 2)) %>% 
  st_drop_geometry() %>% 
  right_join(n_epci_zsup_r52 %>% 
               st_drop_geometry() %>% 
               select(siren_epci, nom_epci, surf_epci)) %>% 
  select(siren_epci, nom_epci, part_protection_forte) %>% 
  mutate(part_protection_forte = ifelse(is.na(part_protection_forte), 0, part_protection_forte)) %>% 
  rename(CodeZone = siren_epci, Zone = nom_epci, valeur = part_protection_forte) %>% 
  mutate(TypeZone = "Epci", date=as.Date("2022-01-01"), variable = "part_protection_forte")

indicateur_protection_forte_departement <- st_intersection(st_buffer(protection_forte, 0),
                                                         st_buffer(n_departement_exp_r52, 0)) %>% 
  mutate(surf_protection_forte = st_area(the_geom)) %>% 
  mutate(part_protection_forte = round(surf_protection_forte/surf_departement*100, digits = 2)) %>% 
  st_drop_geometry() %>% 
  right_join(n_departement_exp_r52 %>% 
               st_drop_geometry() %>% 
               select(insee_dep, nom_dep, surf_departement)) %>% 
  select(insee_dep, nom_dep, part_protection_forte) %>% 
  mutate(part_protection_forte = ifelse(is.na(part_protection_forte), 0, part_protection_forte)) %>% 
  rename(CodeZone = insee_dep, Zone = nom_dep, valeur = part_protection_forte) %>% 
  mutate(TypeZone = "Départements", date = as.Date("2022-01-01"), variable = "part_protection_forte")

indicateur_protection_forte_region <- st_intersection(st_buffer(protection_forte, 0),
                                                      st_buffer(n_region_exp_r52, 0)) %>% 
  mutate(surf_protection_forte = st_area(the_geom)) %>% 
  mutate(part_protection_forte = round(surf_protection_forte/surf_region*100, digits = 2)) %>% 
  st_drop_geometry() %>% 
  right_join(n_region_exp_r52 %>% 
               st_drop_geometry() %>% 
               select(insee_reg, nom_reg, surf_region)) %>% 
  select(insee_reg, nom_reg, part_protection_forte) %>% 
  mutate(part_protection_forte = ifelse(is.na(part_protection_forte), 0, part_protection_forte)) %>% 
  rename(CodeZone = insee_reg, Zone = nom_reg, valeur = part_protection_forte) %>% 
  mutate(TypeZone = "Régions", date = as.Date("2022-01-01"), variable = "part_protection_forte")


# intersection des protections élargies et des territoires ---------
indicateur_protection_elargie_commune <- st_intersection(st_buffer(protection_elargie, 0), 
                                                         st_buffer(n_commune_exp_r52, 0)) %>% 
  mutate(surf_protection_elargie = st_area(the_geom)) %>% 
  mutate(part_protection_elargie = round(surf_protection_elargie/surf_commune*100, digits = 2)) %>% 
  st_drop_geometry() %>% 
  right_join(n_commune_exp_r52 %>% 
               st_drop_geometry() %>% 
               select(insee_com, nom_com, surf_commune)) %>% 
  select(insee_com, nom_com, part_protection_elargie) %>% 
  mutate(part_protection_elargie = ifelse(is.na(part_protection_elargie), 0, part_protection_elargie)) %>% 
  rename(CodeZone = insee_com, Zone = nom_com, valeur = part_protection_elargie) %>% 
  mutate(TypeZone = "Communes", date = as.Date("2022-01-01"), variable = "part_protection_elargie")

indicateur_protection_elargie_epci <- st_intersection(st_buffer(protection_elargie, 0),
                                                      st_buffer(n_epci_zsup_r52, 0)) %>% 
  mutate(surf_protection_elargie = st_area(the_geom)) %>% 
  mutate(part_protection_elargie = round(surf_protection_elargie/surf_epci*100, digits = 2)) %>% 
  st_drop_geometry() %>% 
  right_join(n_epci_zsup_r52 %>% 
               st_drop_geometry() %>% 
               select(siren_epci, nom_epci, surf_epci)) %>% 
  select(siren_epci, nom_epci, part_protection_elargie) %>% 
  mutate(part_protection_elargie = ifelse(is.na(part_protection_elargie), 0, part_protection_elargie)) %>% 
  rename(CodeZone = siren_epci, Zone = nom_epci, valeur = part_protection_elargie) %>% 
  mutate(TypeZone = "Epci", date = as.Date("2022-01-01"), variable = "part_protection_elargie")

indicateur_protection_elargie_departement <- st_intersection(st_buffer(protection_elargie, 0),
                                                             st_buffer(n_departement_exp_r52, 0)) %>%
  mutate(surf_protection_elargie = st_area(the_geom)) %>%
  mutate(part_protection_elargie = round(surf_protection_elargie/surf_departement*100, digits = 2)) %>%
  st_drop_geometry() %>%
  right_join(n_departement_exp_r52 %>%
               st_drop_geometry() %>%
               select(insee_dep, nom_dep, surf_departement)) %>%
  select(insee_dep, nom_dep, part_protection_elargie) %>%
  mutate(part_protection_elargie = ifelse(is.na(part_protection_elargie), 0, part_protection_elargie)) %>%
  rename(CodeZone = insee_dep, Zone = nom_dep, valeur = part_protection_elargie) %>%
  mutate(TypeZone = "Départements", date = as.Date("2022-01-01"), variable = "part_protection_elargie")

indicateur_protection_elargie_region <- st_intersection(st_buffer(protection_elargie, 0),
                                                        st_buffer(n_region_exp_r52, 0)) %>% 
  mutate(surf_protection_elargie = st_area(the_geom)) %>% 
  mutate(part_protection_elargie = round(surf_protection_elargie/surf_region*100, digits = 2)) %>% 
  st_drop_geometry() %>% 
  right_join(n_region_exp_r52 %>% 
               st_drop_geometry() %>% 
               select(insee_reg, nom_reg, surf_region)) %>% 
  select(insee_reg, nom_reg, part_protection_elargie) %>% 
  mutate(part_protection_elargie = ifelse(is.na(part_protection_elargie), 0, part_protection_elargie)) %>% 
  rename(CodeZone = insee_reg, Zone = nom_reg, valeur=part_protection_elargie) %>% 
  mutate(TypeZone = "Régions", date = as.Date("2022-01-01"), variable="part_protection_elargie")


# compilation -------
indicateur_protection_naturelle<-bind_rows(indicateur_protection_forte_commune,
                                           indicateur_protection_forte_epci,
                                           indicateur_protection_forte_departement,
                                           indicateur_protection_forte_region,
                                           indicateur_protection_elargie_commune,
                                           indicateur_protection_elargie_epci,
                                           indicateur_protection_elargie_departement,
                                           indicateur_protection_elargie_region) %>% 
  mutate_if(is.character,as.factor)


# correction/vérification du champs Zone avec COGiter ------------
communes_pdl <- communes %>% 
  filter(REG == '52') %>% 
  select(DEPCOM, NOM_DEPCOM) %>% 
  rename(CodeZone = DEPCOM, Zone = NOM_DEPCOM) # 1235 obs

epci_pdl <- epci %>% 
  unnest(REGIONS_DE_L_EPCI) %>% 
  filter(REGIONS_DE_L_EPCI == '52') %>% 
  select(EPCI, NOM_EPCI) %>% 
  rename(CodeZone = EPCI, Zone = NOM_EPCI) # 71 obs

departements_pdl <- departements %>% 
  filter(REG == '52') %>% 
  select(DEP, NOM_DEP) %>% 
  rename(CodeZone = DEP, Zone = NOM_DEP)

region_pdl <- regions %>% 
  filter(REG == '52') %>% 
  select(REG, NOM_REG) %>% 
  rename(CodeZone = REG, Zone = NOM_REG)

territoire_pdl <- bind_rows(communes_pdl,
                            departements_pdl,
                            epci_pdl,
                            region_pdl) %>% 
  mutate_if(is.factor,as.character)

specifique_protection_naturelle<-indicateur_protection_naturelle %>% 
  select(-Zone) %>% 
  left_join(territoire_pdl) %>% 
  mutate_if(is.character,as.factor) %>% 
  select(TypeZone, CodeZone, Zone, variable, valeur, date)

specifique_protection_naturelle <- pivot_wider(specifique_protection_naturelle,
                                               names_from = variable,
                                               values_from = valeur)


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = specifique_protection_naturelle,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "specifique_protection_naturelle",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("TypeZone", "CodeZone", "Zone", "date"), # déclaration d'une clé primaire sur la table postée
            user = "does")


# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(specifique_protection_naturelle), c("TypeZone", "CodeZone", "Zone", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, 
               table = "specifique_protection_naturelle", 
               schema = "portrait_territoires",
               db = "datamart",
               user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table)

## commentaires de la table
commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "specifique_protection_naturelle", 
                user = "does")
