
# secret_filocom

# librairies ---------
library(dplyr)
library(tidyr)
library(lubridate)
library(COGiter)
library(DBI)
library(RPostgreSQL)

rm(list=ls())


# chargement data -------------
drv <- dbDriver("PostgreSQL")
con_datamart <- dbConnect(drv, 
                          dbname="datamart", 
                          host=Sys.getenv("server"), 
                          port=Sys.getenv("port"),
                          user=Sys.getenv("userid"),
                          password=Sys.getenv("pwd_does"))
postgresqlpqExec(con_datamart, "SET client_encoding = 'windows-1252'") 

cogifiee_filocom<-dbReadTable(con_datamart,c("portrait_territoires","cogifiee_filocom"))

data_cogifiee<-pivot_longer(cogifiee_filocom,
                            cols = nb_lgts_collectif : revenu_brut_total,
                            names_to = "variable",
                            values_to = "valeur")

tranches <- read.csv2('metadata/table_liens_indicateurs.csv', as.is = TRUE, encoding = "UTF-8" ) %>% 
  filter(source=="chargement_filocom") %>%
  select(famille,sous_indicateur,prise_en_compte_famille_pour_secret) %>%
  rename(variable=sous_indicateur) %>%
  mutate(lign=as.character(row_number()))
tranches$famille<-case_when(
  tranches$prise_en_compte_famille_pour_secret == 0 ~ tranches$lign ,  #numérote les cellules qui ne sont pas dans des familles pour qu'elles soient toutes différentes les unes des autres
  TRUE ~ tranches$famille)


# enlèvement des zonages inutiles ----------
data_filocom <- data_cogifiee %>%
  # mutate(date=as.character(year(date))) %>%
  filter(Zone!="Ille-et-Vilaine") %>% 
  filter(Zone!="Orne") %>% 
  filter(Zone!="Morbihan") %>% 
  filter(Zone!="Bretagne") %>% 
  filter(Zone!="Normandie") %>%
  #enleve les EPCI hors région
  left_join(epci%>% rename("CodeZone"="EPCI")) %>% 
  select(-NATURE_EPCI,-NOM_EPCI) %>% 
  filter(REGIONS_DE_L_EPCI!="28") %>% 
  filter(REGIONS_DE_L_EPCI!="53") %>% 
  select(-REGIONS_DE_L_EPCI,-DEPARTEMENTS_DE_L_EPCI) %>%
  #enlève les communes hors EPCI région
  left_join(communes %>% rename("CodeZone"="DEPCOM")) %>% 
  select(TypeZone,Zone,CodeZone,date,variable,valeur,EPCI,NOM_EPCI,REGIONS_DE_L_EPCI) %>% 
  filter(REGIONS_DE_L_EPCI!="28") %>% 
  filter(REGIONS_DE_L_EPCI!="53") %>% 
  select(-REGIONS_DE_L_EPCI) %>%
  mutate(TypeZone=as.character(TypeZone),
         Zone=as.character(Zone),
         NOM_EPCI=as.character(NOM_EPCI),
         CodeZone=as.character(CodeZone),
         EPCI=as.character(EPCI)) %>%
  left_join(tranches)

# ajout du nom et du code EPCI pour les EPCI ----------
data_filocom$NOM_EPCI<-case_when(
  data_filocom$TypeZone=="Régions" ~ "",
  data_filocom$TypeZone=="Départements" ~ "",
  data_filocom$TypeZone=="Epci" ~ data_filocom$Zone,
  TRUE ~ data_filocom$NOM_EPCI)
data_filocom$EPCI<-case_when(
  data_filocom$TypeZone=="Régions" ~ "",
  data_filocom$TypeZone=="Départements" ~ "",
  data_filocom$TypeZone=="Epci" ~ data_filocom$CodeZone,
  TRUE ~ data_filocom$EPCI)


# secretisation des communes -----------
secret_communes<-data_filocom %>% 
  filter(TypeZone=="Communes")

#secret induit, pour une meme variable et un meme epci, pour ne pas retrouver la valeur d'une commune
#en faisant la somme des communes

secret_communes<-secret_communes %>% 
  group_by(variable,EPCI,date) %>%
  mutate(A_nb_inf11=length(which(valeur<11))) %>% #compte combien inférieur à 11
  mutate(A_rang=rank(valeur, ties.method = "first")) #classe pour repérer les 2 plus petites valeurs
secret_communes$A_sec<-case_when(
  secret_communes$valeur<11 ~ 1,      #secret pour toutes les valeurs inférieures à 11
  secret_communes$A_nb_inf11== 0 ~ 0,   #enlève le secret si aucune des communes rang 1 et 2 inférieur à 11
  secret_communes$A_rang<3 ~ 1,         #secret sur les 2 communes avec valeurs les plus basses
  TRUE ~ 0)

#secret induit, pour une meme famille et une meme commune, pour ne pas retrouver la valeur d'une variable
#en faisant la somme des variables de la commune

secret_communes<-secret_communes %>%
  group_by(famille,Zone,date) %>%
  mutate(B_nb_inf11=length(which(valeur<11))) %>% #compte combien inférieur à 11
  mutate(B_rang=rank(valeur, ties.method = "first")) #classe pour repérer les 2 plus petites valeurs
secret_communes$B_sec<-case_when(
  secret_communes$B_nb_inf11== 0 ~ 0,   #enlève le secret si aucune des communes rang 1 et 2 inférieur à 11
  secret_communes$B_rang<3 ~ 1,         #secret sur les 2 communes avec valeurs les plus basses
  TRUE ~ 0)  

# regroupement des secrets, masquage des valeurs
secret_communes<-secret_communes %>%
  mutate(valeur=as.character(valeur))
secret_communes$valeur<-case_when(
  secret_communes$B_sec== 1 ~ "nc",         #remplace valeur par "nc" si secret stat
  secret_communes$A_sec== 1 ~ "nc",         #remplace valeur par "nc" si secret stat
  TRUE ~ secret_communes$valeur)
secret_communes<-secret_communes %>%
  ungroup() %>%
  select(TypeZone,Zone,CodeZone,date,variable,valeur,EPCI,NOM_EPCI)


# secretisation des EPCI ---------
secret_epci<- data_filocom %>%
  filter(TypeZone =="Epci")

#secret induit, pour une meme famille et un meme epci, pour ne pas retrouver la valeur d'une variable
#en faisant la somme des variables de l'Epci

secret_epci<-secret_epci %>%
  group_by(famille,Zone,date) %>%
  mutate(B_nb_inf11=length(which(valeur<11))) %>% #compte combien inférieur à 11
  mutate(B_rang=rank(valeur, ties.method = "first")) #classe pour repérer les 2 plus petites valeurs
secret_epci$B_sec<-case_when(
  secret_epci$valeur<11 ~ 1,      #secret pour toutes les valeurs inférieures à 11  
  secret_epci$B_nb_inf11== 0 ~ 0,   #enlève le secret si aucune des communes rang 1 et 2 inférieur à 11
  secret_epci$B_rang<3 ~ 1,         #secret sur les 2 communes avec valeurs les plus basses
  TRUE ~ 0)  

# regroupement des secrets, masquage des valeurs
secret_epci<-secret_epci %>%
  mutate(valeur=as.character(valeur))
secret_epci$valeur<-case_when(
  secret_epci$B_sec== 1 ~ "nc",         #remplace valeur par "nc" si secret stat
  TRUE ~ secret_epci$valeur)
secret_epci<-secret_epci %>%
  ungroup() %>%
  select(TypeZone,Zone,CodeZone,date,variable,valeur,EPCI,NOM_EPCI)


# secretisation des départements et régions ----------
secret_region_departements<- data_filocom %>%
  filter(TypeZone %in% c("Régions","Départements"))
secret_region_departements$A_sec<-case_when(
  secret_region_departements$valeur < 11 ~ 1,      #secret pour toutes les valeurs inférieures à 11 
  TRUE ~ 0)
secret_region_departements<-secret_region_departements %>%
  mutate(valeur=as.character(valeur))
secret_region_departements$valeur<-case_when(
  secret_region_departements$A_sec== 1 ~ "nc",         #remplace valeur par "nc" si secret stat
  TRUE ~ secret_region_departements$valeur)
secret_region_departements<-secret_region_departements %>%
  ungroup() %>%
  select(TypeZone,Zone,CodeZone,date,variable,valeur,EPCI,NOM_EPCI)


# regroupement des zonages --------------
filocom_secretise<-bind_rows(secret_region_departements,secret_epci,secret_communes) %>%
  mutate(code_date=paste(CodeZone,date))  #création d'une colonne pour identifier zone et année


# selection des zones avec revenu renseigné, de moins de 11 ménages ou secrétisé ------------
# par secret induit, pour secretisation du montant
revenu_secret<-filocom_secretise %>%
  filter(variable=="nb_men_fisc_avec_revenu_brut_rens",valeur=="nc") %>%
  pull(code_date)


# secretisation du montant des revenus quand moins de 11 ménages ----------
filocom_secretise$valeur<-case_when(
  filocom_secretise$code_date %in% revenu_secret ~ "nc", #remplace valeur par "nc" si secret stat
  TRUE ~ filocom_secretise$valeur)


# remplace "nc" par NA    
filocom_secretise$valeur<-na_if(filocom_secretise$valeur,"nc")

data_cogifiee <- filocom_secretise %>%
  mutate(valeur=as.numeric(valeur)) %>%
  mutate_if(is.character,as.factor) %>% 
  select(-EPCI,-NOM_EPCI,-code_date)  #enleve les colonnes inutiles


# versement dans le sgbd/datamart.portrait_territoires -------------
secretise_filocom<-data_cogifiee %>% 
  pivot_wider(names_from = variable,values_from = valeur)

dbWriteTable(con_datamart, c("portrait_territoires","secretise_filocom"),
             secretise_filocom, row.names=FALSE, overwrite=TRUE)

dbDisconnect(con_datamart)

rm(list=ls())
