
# chargement_pop_rgp_insee

# population INSEE
# doc INSEE disponible à https://www.insee.fr/fr/statistiques/6456153?sommaire=6456166 pour 2019
# doc et fichiers INSEE disponibles sur https://www.insee.fr/fr/statistiques/7632446?sommaire=7632456 pour 2020

# librairies ---------------
library(dplyr)
library(tidyr)
library(purrr)
library(stringr)
library(lubridate)
library(readxl)
library(xlsx)
library(readODS)
library(forcats)
library(COGiter)

rm(list=ls())


# paramètres -----------
# mil <- c(2019, 2013, 2008) # mettre le plus récent en premier
# var_mil <- c(paste0("P", mil, "_"), paste0("C", mil, "_")) %>% gsub("20", "", .)
# url <- "https://www.insee.fr/fr/statistiques/fichier/6456153/base-ccx-evol-struct-pop-2019.zip"
# fic <- "base-cc-evol-struct-pop-2019"
mil <- c(2020, 2014, 2009) # mettre le plus récent en premier
mil2 <- c(20, 14, "09")
var_mil <- c(paste0("P", mil2, "_"), paste0("C", mil2, "_"))
url <- "https://www.insee.fr/fr/statistiques/fichier/7632446/base-cc-evol-struct-pop-2020_xlsx.zip"
fic <- "base-cc-evol-struct-pop-2020"


# chargement data ---------
download.file(url, destfile = "extdata/pop_RGP_INSEE.zip")
unzip("extdata/pop_RGP_INSEE.zip", exdir="extdata")


# lecture méthodes xlsx et calcul ----------
pop_actu <- read_xlsx(path = paste0("extdata/", fic,".xlsx"), sheet = paste0("COM_", mil[1]), skip = 5) %>%
  mutate(date = as.character(mil[1])) %>% 
  rename_with(~sub(paste0("^", var_mil[1]), "", .x)) %>% 
  rename_with(~sub(paste0("^", var_mil[4]), "", .x)) 

pop_old <- read_xlsx(path = paste0("extdata/", fic,".xlsx"), sheet = paste0("COM_", mil[2]), skip = 5) %>%
  mutate(date = as.character(mil[2])) %>% 
  rename_with(~sub(paste0("^", var_mil[2]), "", .x)) %>% 
  rename_with(~sub(paste0("^", var_mil[5]), "", .x))

pop_very_old <- read_xlsx(path = paste0("extdata/", fic,".xlsx"), sheet = paste0("COM_", mil[3]), skip = 5) %>%
  mutate(date = as.character(mil[3])) %>% 
  rename_with(~sub(paste0("^", var_mil[3]), "", .x)) %>% 
  # retrait des variables en doublon entre exploitations principale et complémentaire :
  # select(-C08_POP1524, -C08_POP2554, -C08_POP55P) %>%
  rename_with(~sub(paste0("^", var_mil[6]), "", .x))

# retrait des variables de l'exploitation complémentaire qui sont absentes de l'exploitation principale
nom_var_pop_very_old_a_oter <- setdiff(names(pop_very_old), names(pop_actu))
pop_very_old <- pop_very_old %>% 
  select(-all_of(nom_var_pop_very_old_a_oter))


# renommer à la main les libellés de colonnes et assembler les deux millésimes ------------
lib_var <- read_ods(path = "metadata/Insee_RGP_pop_lib_variable.ods", col_types = NA) %>%
  filter(variable_deb %in% names(pop_actu)) %>%
  mutate_all(as.factor) 

pop <- bind_rows(pop_actu, pop_old, pop_very_old) %>%
  select(date, depcom = CODGEO, everything(), -REG, -DEP, -LIBGEO) %>%
  pivot_longer(cols = -c(date, depcom), names_to = "variable_deb", values_to = "valeur") %>%
  left_join(lib_var, by = "variable_deb") %>%
  select(-variable_deb, -lib_insee) %>% 
  mutate_if(is_character, as.factor) %>% 
  mutate_if(is.factor, fct_drop) %>% 
  unique() %>%
  mutate(date = make_date(as.character(date), 12, 31))

# on enlève les lignes communales Paris Lyon et Marseille si elles doublonnent les lignes d'arrondissement
if(all(c("75056","75101") %in% pop$depcom)) {
  pop <-  filter(pop, !(depcom %in% c("75056", "13055", "69123")))
}

# on vérifie que toutes les variables ont bien un nom :
filter(pop, is.na(variable)) %>% nrow() == 0 # TRUE attendu

pop <- pop %>% 
  # on met les valeurs manquantes à NA, cela concerne le millésime le plus ancien pour lequel il manque des variables
  complete(depcom, date, variable, fill = list(valeur = NA_real_)) %>% 
  pivot_wider(names_from = variable, values_from = valeur)

# save(pop, file = ".RData")  # load(".RData")

# versement dans le sgbd/datamart.portrait_territoires et documentation-------------

source("R/poster_documenter_data.R", encoding = "UTF-8")
poster_documenter_it(df = pop,
                     nom_table_sgbd = "source_pop_rgp_insee", 
                     comm_source_en_plus = "doc INSEE disponible à https://www.insee.fr/fr/statistiques/4515532?sommaire=4516107")
