# chargement_siclop

# Observations des loyers de la région par scrapping du site Ouest France immo
# On récupère les données individuelles nettoyées du projet SICLOP. La cogification se fait toutes les semaines lors de la collecte automatisée donc pas d'étape de cogification dans SGBD Datamart 
# (Si COGiter est bien à jour sur le serveur de dataviz.......)
# scripts de collecte et nettoyage : https://gitlab-forge.din.developpement-durable.gouv.fr/dreal-pdl/csd/siclop/-/tree/main/scripts

rm(list=ls())

## librairies ----------
library(dplyr)
library(tidyr)
library(lubridate)
library(datalibaba)
library(COGiter)

rm(list = ls())

## Lecture des données individuelles dans le SGBD base datamart du projet siclop ----------------------
siclop_exploitation <- importer_data(table = "dprep_siclop_exploitation", schema = "sial_siclop", db = "datamart")


## fonction de création des tables d'indicateurs calculés par zone aux différents niveaux--------------

data_prep <- function(typzon) {
  
  if (typzon == "REG") {
    zones_de_la_region <- "52"
    zonag <- "Régions"
    nom_zon <- "NOM_REG"
  } else if (typzon == "DEPCOM") {
    zones_de_la_region <- COGiter::list_com_in_reg("52")
    zonag <- "Communes"
    nom_zon <- "NOM_DEPCOM"
  } else if (typzon == "DEP") {
    zones_de_la_region <- COGiter::list_dep_in_reg("52")
    zonag <- "Départements"
    nom_zon <- "NOM_DEP"
  } else if (typzon == "EPCI") {
    zones_de_la_region <- COGiter::list_epci_in_reg("52")
    zonag <- "Epci"
    nom_zon <- "NOM_EPCI"
  }
  
  data_prep_indic0 <- siclop_exploitation %>%
    select(id_annonce, type_logement, nombre_pieces, surf_habitable, loyer_hc, {typzon}, {nom_zon}, annee_annonce) %>%
    rename(codezone = {typzon}) %>% 
    # on ne garde que les années complètes
    filter(annee_annonce != as.character(year(today())))
  # total pour l'ensemble
  data_prep_indic1 <- data_prep_indic0 %>%
    group_by(codezone, annee_annonce) %>%
    summarise(nombre_annonces_ensemble = length(id_annonce),
              loy_hc_moyen_ensemble = round(mean(loyer_hc, na.rm = T), 2),
              surf_habitable_moyenne_ensemble = round(mean(surf_habitable, na.rm = T), 2),
              loy_hc_mediane_ensemble = round(median(loyer_hc, na.rm = T), 2)
    ) %>%
    ungroup() %>%
    complete(codezone, annee_annonce, fill = list(nombre_annonces_ensemble = 0)) %>%
    filter(codezone %in% zones_de_la_region)
  # total pour appartements
  data_prep_indic2 <- data_prep_indic0 %>%
    filter(type_logement == "appartement") %>%
    group_by(codezone, annee_annonce) %>%
    summarise(nombre_annonces_appart = length(id_annonce),
              loy_hc_moyen_appart = round(mean(loyer_hc, na.rm = T), 2),
              surf_habitable_moyenne_appart = round(mean(surf_habitable, na.rm = T), 2),
              loy_hc_mediane_appart = round(median(loyer_hc, na.rm = T), 2)
    ) %>%
    ungroup() %>%
    complete(codezone, annee_annonce, fill = list(nombre_annonces_appart = 0))
  # appartements par nombre de pieces
  data_prep_indic3 <- data_prep_indic0 %>%
    filter(type_logement == "appartement") %>%
    group_by(codezone, annee_annonce, nombre_pieces) %>%
    summarise(nombre_annonces_appart = length(id_annonce),
              loy_hc_moyen_appart = round(mean(loyer_hc, na.rm = T), 2),
              surf_habitable_moyenne_appart = round(mean(surf_habitable, na.rm = T), 2),
              loy_hc_mediane_appart = round(median(loyer_hc, na.rm = T), 2)) %>%
    pivot_wider(names_from = nombre_pieces,
                values_from = c(nombre_annonces_appart, loy_hc_moyen_appart, surf_habitable_moyenne_appart, loy_hc_mediane_appart)) %>%
    ungroup() %>%
    complete(codezone, annee_annonce, fill = list(nombre_annonces_appart_T1 = 0,
                                                  nombre_annonces_appart_T2 = 0,
                                                  nombre_annonces_appart_T3 = 0,
                                                  nombre_annonces_appart_T4 = 0,
                                                  nombre_annonces_appart_T5 = 0,
                                                  `nombre_annonces_appart_T6 et +` = 0))
  
  # total pour maisons
  data_prep_indic4 <- data_prep_indic0 %>%
    filter(type_logement == "maison") %>%
    group_by(codezone, annee_annonce) %>%
    summarise(nombre_annonces_maison = length(id_annonce),
              loy_hc_moyen_maison = round(mean(loyer_hc, na.rm = T), 2),
              surf_habitable_moyenne_maison = round(mean(surf_habitable, na.rm = T), 2),
              loy_hc_mediane_maison = round(median(loyer_hc, na.rm = T), 2)
    ) %>%
    ungroup() %>%
    complete(codezone, annee_annonce, fill = list(nombre_annonces_appart = 0))
  # maisons par nombre de pieces
  data_prep_indic5 <- data_prep_indic0 %>%
    filter(type_logement == "maison") %>%
    group_by(codezone, annee_annonce, nombre_pieces) %>%
    summarise(nombre_annonces_maison = length(id_annonce),
              loy_hc_moyen_maison = round(mean(loyer_hc, na.rm = T), 2),
              surf_habitable_moyenne_maison = round(mean(surf_habitable, na.rm = T), 2),
              loy_hc_mediane_maison = round(median(loyer_hc, na.rm = T), 2)) %>%
    pivot_wider(names_from = nombre_pieces,
                values_from = c(nombre_annonces_maison, loy_hc_moyen_maison, surf_habitable_moyenne_maison, loy_hc_mediane_maison)) %>%
    ungroup() %>%
    complete(codezone, annee_annonce, fill = list(nombre_annonces_maison_T1 = 0,
                                                  nombre_annonces_maison_T2 = 0,
                                                  nombre_annonces_maison_T3 = 0,
                                                  nombre_annonces_maison_T4 = 0,
                                                  nombre_annonces_maison_T5 = 0,
                                                  `nombre_annonces_maison_T6 et +` = 0)) 
  
  # regroupement des données
  data_prep_indic <- data_prep_indic1 %>%
    left_join(data_prep_indic2, by = c("codezone", "annee_annonce")) %>%
    left_join(data_prep_indic3, by = c("codezone", "annee_annonce")) %>%
    left_join(data_prep_indic4, by = c("codezone", "annee_annonce")) %>%
    left_join(data_prep_indic5, by = c("codezone", "annee_annonce")) %>%
    mutate(date = make_date(annee_annonce, 12, 31)) %>%
    rename(CodeZone = codezone, nombre_annonces_appart_T6_et_plus = "nombre_annonces_appart_T6 et +",
           surf_habitable_moyenne_appart_T6_et_plus = "surf_habitable_moyenne_appart_T6 et +",
           loy_hc_moyen_appart_T6_et_plus = "loy_hc_moyen_appart_T6 et +",
           loy_hc_mediane_appart_T6_et_plus = "loy_hc_mediane_appart_T6 et +",
           nombre_annonces_maison_T6_et_plus = "nombre_annonces_maison_T6 et +",
           surf_habitable_moyenne_maison_T6_et_plus = "surf_habitable_moyenne_maison_T6 et +",
           loy_hc_moyen_maison_T6_et_plus = "loy_hc_moyen_maison_T6 et +",
           loy_hc_mediane_maison_T6_et_plus = "loy_hc_mediane_maison_T6 et +"
    ) %>%
    # mutate (TypeZone = colnames(siclop_exploitation[{zonag}]) ) %>%
    mutate(TypeZone = zonag) %>%
    select(TypeZone, CodeZone, date, nombre_annonces_ensemble, nombre_annonces_appart, nombre_annonces_maison,
           nombre_annonces_appart_T1,
           nombre_annonces_appart_T2, nombre_annonces_appart_T3, nombre_annonces_appart_T4,
           nombre_annonces_appart_T5, nombre_annonces_appart_T6_et_plus,
           nombre_annonces_maison_T1,
           nombre_annonces_maison_T2, nombre_annonces_maison_T3, nombre_annonces_maison_T4,
           nombre_annonces_maison_T5, nombre_annonces_maison_T6_et_plus,
           surf_habitable_moyenne_ensemble,
           surf_habitable_moyenne_appart, surf_habitable_moyenne_appart_T1, surf_habitable_moyenne_appart_T2,
           surf_habitable_moyenne_appart_T3, surf_habitable_moyenne_appart_T4, surf_habitable_moyenne_appart_T5,
           surf_habitable_moyenne_appart_T6_et_plus,
           surf_habitable_moyenne_maison, surf_habitable_moyenne_maison_T1, surf_habitable_moyenne_maison_T2,
           surf_habitable_moyenne_maison_T3, surf_habitable_moyenne_maison_T4, surf_habitable_moyenne_maison_T5,
           surf_habitable_moyenne_maison_T6_et_plus,           
           loy_hc_moyen_ensemble,
           loy_hc_moyen_appart, loy_hc_moyen_appart_T1,
           loy_hc_moyen_appart_T2, loy_hc_moyen_appart_T3, loy_hc_moyen_appart_T4, loy_hc_moyen_appart_T5,
           loy_hc_moyen_appart_T6_et_plus,
           loy_hc_moyen_maison, loy_hc_moyen_maison_T1,
           loy_hc_moyen_maison_T2, loy_hc_moyen_maison_T3, loy_hc_moyen_maison_T4, loy_hc_moyen_maison_T5,
           loy_hc_moyen_maison_T6_et_plus,           
           loy_hc_mediane_ensemble,
           loy_hc_mediane_appart, loy_hc_mediane_appart_T1,
           loy_hc_mediane_appart_T2, loy_hc_mediane_appart_T3, loy_hc_mediane_appart_T4, loy_hc_mediane_appart_T5,
           loy_hc_mediane_appart_T6_et_plus,
           loy_hc_mediane_maison, loy_hc_mediane_maison_T1,
           loy_hc_mediane_maison_T2, loy_hc_mediane_maison_T3, loy_hc_mediane_maison_T4, loy_hc_mediane_maison_T5,
           loy_hc_mediane_maison_T6_et_plus
    )
  return(data_prep_indic)
}

## fin de fonction

## Création des tables d'indicateurs par niveau géo ----------------------------------------------------
data1 <- data_prep(typzon = "DEPCOM")
data2 <- data_prep(typzon = "EPCI")
data3 <- data_prep(typzon = "DEP")
data4 <- data_prep(typzon = "REG")

data_prep_indic <- bind_rows(data1, data2, data3, data4) %>%
  left_join(liste_zone %>% select(TypeZone, CodeZone, Zone), by = c("TypeZone", "CodeZone")) %>%
  relocate(ncol(.), .before = 3)%>%  # deplace la dernière colonne avant la 3e
  mutate_if(is.factor,as.character)

# verif pas de doublons - TRUE attendu
data_prep_indic %>% 
  dplyr::count(CodeZone, TypeZone, date) %>% 
  dplyr::filter(n>1) %>% 
  nrow() == 0

# versement dans le sgbd/datamart.portrait_territoires + documentation -------------
source("R/poster_documenter_ind.R")
poster_documenter_ind(df = data_prep_indic, nom_table_sgbd = "cogifiee_siclop", 
                      comm_source_en_plus = "Observations des loyers de la région par scrapping du site Ouest France immo.\nScripts de collecte et nettoyage : https://gitlab-forge.din.developpement-durable.gouv.fr/dreal-pdl/csd/siclop/-/tree/main/scripts")

rm(list=ls())
