
# cogification_agri

library(magrittr)

rm(list=ls())

source("R/cogifier_it.R")
source("R/poster_doc_post_cogifier.R")

# cogification et versement dans le sgbd/datamart.portrait_territoires -------
cogifier_it(nom_source = "agri")

#  commentaire de la table cogifiée et de ses variables ----------
poster_documenter_post_cogifier(source = "agri")


# correction de la cogification en l'occurrence pour les niveaux départemental et régional -----------
cogifiee_agri <- datalibaba::importer_data(
  db = "datamart",
  schema = "portrait_territoires",
  table = "cogifiee_agri"
)

agri_2020_dep <- openxlsx::read.xlsx(
  xlsxFile = "extdata/agreste_geoclip_ra_2020_2024-02-20_dep.xlsx", 
  sheet = "Data", 
  startRow = 4 
) %>% 
  dplyr::select(
    CodeZone = Code,
    superficie_agricole_utilisee_siege = "SAU.en.2020",
    nbre_exploitation = "Nombre.d&apos;exploitations.en.2020",
    unite_gros_betail_tous_aliments = "Nombre.d&apos;UGB,.2020",
    part_prairie_permanente =  "Part.des.prairies.permanentes.dans.la.SAU,.2020",
    part_culture_permanente = "Part.des.cultures.permanentes.dans.la.SAU,.2020"
  ) %>% 
  dplyr::mutate(
    part_prairie_permanente = ifelse(part_prairie_permanente == "N/A - secret statistique", "NA", part_prairie_permanente),
    superficie_culture_permanente = part_culture_permanente*superficie_agricole_utilisee_siege/100,
    superficie_toujours_en_herbe = as.numeric(part_prairie_permanente)*superficie_agricole_utilisee_siege/100
  ) %>% 
  dplyr::mutate(
    date = as.Date("2020-01-01"),
    TypeZone = "Départements"
    ) %>% 
  dplyr::select(TypeZone, CodeZone, date, tidyselect::everything()) %>% 
  dplyr::select(-part_prairie_permanente, -part_culture_permanente)

agri_2020_reg <- openxlsx::read.xlsx(
  xlsxFile = "extdata/agreste_geoclip_ra_2020_2024-02-20_reg.xlsx", 
  sheet = "Data", 
  startRow = 4 
) %>% 
  dplyr::select(
    CodeZone = Code,
    superficie_agricole_utilisee_siege = "SAU.en.2020",
    nbre_exploitation = "Nombre.d&apos;exploitations.en.2020",
    unite_gros_betail_tous_aliments = "Nombre.d&apos;UGB,.2020",
    part_prairie_permanente =  "Part.des.prairies.permanentes.dans.la.SAU,.2020",
    part_culture_permanente = "Part.des.cultures.permanentes.dans.la.SAU,.2020"
  ) %>% 
  dplyr::mutate(
    part_prairie_permanente = ifelse(part_prairie_permanente == "N/A - secret statistique", "NA", part_prairie_permanente),
    superficie_culture_permanente = part_culture_permanente*superficie_agricole_utilisee_siege/100,
    superficie_toujours_en_herbe = as.numeric(part_prairie_permanente)*superficie_agricole_utilisee_siege/100
  ) %>% 
  dplyr::mutate(
    date = as.Date("2020-01-01"),
    TypeZone = "Régions"
    ) %>% 
  dplyr::select(TypeZone, CodeZone, date, tidyselect::everything()) %>% 
  dplyr::select(-part_prairie_permanente, -part_culture_permanente)

cogifiee_agri_filtre <- cogifiee_agri %>% 
  dplyr::filter(date == "2020-01-01" & TypeZone %in% c("Départements", "Régions"))

anti_join <- dplyr::anti_join(cogifiee_agri, cogifiee_agri_filtre, by = c("TypeZone", "CodeZone", "date"))

agri_dep_reg_2020 <- dplyr::bind_rows(
  agri_2020_dep,
  agri_2020_reg
) %>% 
  dplyr::left_join(
    cogifiee_agri %>% dplyr::select(TypeZone:CodeZone) %>% unique()
  )

cogifiee_agri_2 <- dplyr::bind_rows(
  anti_join,
  agri_dep_reg_2020
)


# nouveau versement dans le sgbd et commentaire de la table et des variables -----
datalibaba::poster_data(
  data = cogifiee_agri_2,
  db = "datamart",
  schema = "portrait_territoires", 
  table = "cogifiee_agri",
  pk = c("TypeZone", "Zone", "CodeZone", "date"),
  post_row_name = FALSE, 
  overwrite = TRUE,
  droits_schema = TRUE,
  user = "does"
  ) 

poster_documenter_post_cogifier(source = "agri")

rm(list=ls())
