
# indicateur_agri

library(magrittr)

rm(list = ls())

cogifiee_agri <- datalibaba::importer_data(
  db = "datamart",
  schema = "portrait_territoires",
  table = "cogifiee_agri"
  ) 

# données du package COGiter ----
commune <- COGiter::communes_geo %>%
  sf::st_drop_geometry() %>% 
  dplyr::rename(CodeZone = DEPCOM, SurfaceZone = AREA) %>% 
  dplyr::mutate(TypeZone = "Communes")
departement <- COGiter::departements_geo %>%
  sf::st_drop_geometry()%>% 
  dplyr::rename(CodeZone = DEP, SurfaceZone = AREA) %>% 
  dplyr::mutate(TypeZone = "Départements")
epci <- COGiter::epci_geo %>% 
  sf::st_drop_geometry()%>% 
  dplyr::rename(CodeZone = EPCI, SurfaceZone = AREA) %>% 
  dplyr::mutate(TypeZone = "Epci")
region <- COGiter::regions_geo %>%
  sf::st_drop_geometry() %>%
  dplyr::rename(CodeZone = REG, SurfaceZone = AREA) %>% 
  dplyr::mutate(TypeZone = "Régions")

territoires <- dplyr::bind_rows(
  commune, 
  departement,
  epci,
  region
  ) %>%
  dplyr::mutate(SurfaceZone = SurfaceZone/10000) # conversion des m² en ha en cohérence avec cogifiee_agri
territoires$SurfaceZone <- units::drop_units(territoires$SurfaceZone) # suppression de la mention de l'unité

# calcul de l'indicateur --------
indicateur_agri <- dplyr::left_join(cogifiee_agri, territoires) %>%
  dplyr::group_by(TypeZone, Zone, CodeZone, date) %>% 
  dplyr::mutate(
    part_sau_siege_surf_commune = round(
      superficie_agricole_utilisee_siege/SurfaceZone*100, 
      digits = 2
      ),
    repartition_unite_travail_annuel_sau_siege = round(
      unite_travail_annuel/superficie_agricole_utilisee_siege, 
      digits = 2
      ),
    repartition_unite_gros_betail_tous_aliments_sau_siege = round(
      unite_gros_betail_tous_aliments/superficie_agricole_utilisee_siege, 
      digits = 2
      )
    ) %>%
  dplyr::ungroup() %>% 
  dplyr::select(-c(nbre_exploitation:SurfaceZone))

# chargement des indicateurs calculés et des commentaires ---------
source("R/poster_documenter_ind.R")
poster_documenter_ind(
  df = indicateur_agri, 
  nom_table_sgbd = "indicateur_agri",
  nom_script_sce = "indicateur_agri",
  comm_source_en_plus = ""
  )

rm(list=ls())
