
# specifique_agriculture_bio est devenu zz_agriculture_bio depuis le 24/06/2022 pour être archivé

# indicateur du CRTE

# le site de l'Agence Bio permet de télécharger des données à l'EPCI de 2010 jusqu'à l'année n-2,
# en l'occurrence 2019

# librairies ------
library(readxl)
library(tidyverse)
library(lubridate)
library(COGiter)
library(datalibaba)
library(googlesheets4)


# chargement des données et calcul ------------
download.file(url = "https://www.agencebio.org/wp-content/uploads/2020/07/Donnees_EPCI_AgenceBio_2019.xlsx", 
              destfile = "extdata/Donnees_EPCI_AgenceBio_2019.xlsx")

agri_bio_EPCI_2010_2019<-read_excel(path = "extdata/Donnees_EPCI_AgenceBio_2019.xlsx",sheet="PV_Evolution",
                                    col_types = c("numeric","text","text","text",
                                                  "numeric","numeric","numeric","numeric","numeric","numeric","numeric")
                                    ) %>% 
  filter(groupe_code=="ALL") %>%
  select(-groupe_code,-groupe_libelle) %>% 
  rename(nb_exploitation_engagee_bio = nb_exp,
         surface_terme_conversion_bio = SurfAB,
         surface_conversion_1e_annee_bio = SurfC1,
         surface_conversion_2e_annee_bio = SurfC2,
         surface_conversion_3e_annee_bio = SurfC3,
         surface_totale_conversion_bio = SurfC123,
         surface_totale_engagee_bio = SurfBio) %>% 
  gather(key = "variable",value = "valeur",nb_exploitation_engagee_bio :surface_totale_engagee_bio) %>%
  mutate(TypeZone="Epci") %>% 
  rename(date = annee,CodeZone = zone) %>% 
  mutate(date = dmy(paste("31-12",date,sep = "-"))) %>% 
  left_join(epci %>% select(EPCI,NOM_EPCI) %>% rename(CodeZone=EPCI,Zone=NOM_EPCI)) %>%
  filter(!is.na(Zone)) %>% 
  mutate_if(is.character,as.factor)

agri_bio_departement_2011_2019<-read_excel(path = "extdata/Donnees_Surfaces_Dept_depuis2011_AgenceBio.xlsx",sheet="DATA départements",
                                           col_types = c("numeric","text","text","text","text","text","text",
                                                         "numeric","numeric","numeric","numeric","numeric","numeric","numeric")
                                           ) %>% 
  filter(Code=="ALL") %>%
  select(-Code,-Libelle,-Numero_Region,-libelle_Region) %>% 
  rename(nb_exploitation_engagee_bio = nb_exp,
         surface_terme_conversion_bio = SurfAB,
         surface_conversion_1e_annee_bio = SurfC1,
         surface_conversion_2e_annee_bio = SurfC2,
         surface_conversion_3e_annee_bio = SurfC3,
         surface_totale_conversion_bio = SurfC123,
         surface_totale_engagee_bio = SurfBio) %>% 
  gather(key = "variable",value = "valeur",nb_exploitation_engagee_bio :surface_totale_engagee_bio) %>%
  mutate(TypeZone="Départements") %>% 
  rename(date = Annee,CodeZone = Numero_Dept,Zone=Libelle_Dept) %>% 
  mutate(date = dmy(paste("31-12",date,sep = "-"))) %>% 
  mutate_if(is.character,as.factor)

agri_bio_region_2011_2019<-read_excel(path = "extdata/Donnees_Surfaces_Dept_depuis2011_AgenceBio.xlsx",sheet="DATA régions",
                                      col_types = c("numeric","text","text","text","text",
                                                    "numeric","numeric","numeric","numeric","numeric","numeric","numeric")
                                      ) %>% 
  filter(Code=="ALL") %>%
  select(-Code,-Libelle) %>% 
  rename(nb_exploitation_engagee_bio = nb_exp,
         surface_terme_conversion_bio = SurfAB,
         surface_conversion_1e_annee_bio = SurfC1,
         surface_conversion_2e_annee_bio = SurfC2,
         surface_conversion_3e_annee_bio = SurfC3,
         surface_totale_conversion_bio = SurfC123,
         surface_totale_engagee_bio = SurfBio) %>% 
  gather(key = "variable",value = "valeur",nb_exploitation_engagee_bio :surface_totale_engagee_bio) %>%
  mutate(TypeZone="Régions") %>% 
  rename(date = Annee,CodeZone = Numero_Region,Zone=libelle_Region) %>% 
  mutate(date = dmy(paste("31-12",date,sep = "-"))) %>% 
  mutate_if(is.character,as.factor)

indicateur_agriculture_bio<-bind_rows(agri_bio_EPCI_2010_2019,
                                      agri_bio_departement_2011_2019,
                                      agri_bio_region_2011_2019) %>% 
  select(TypeZone,CodeZone,Zone,variable,valeur,date) %>% 
  mutate(valeur=ifelse(is.na(valeur),0,valeur)) %>% 
  pivot_wider(names_from = variable,values_from = valeur)


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = indicateur_agriculture_bio,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "specifique_agriculture_bio",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("TypeZone", "CodeZone", "Zone", "date"), # déclaration d'une clé primaire sur la table postée
            user = "does")

# Descriptif de la source -------------

# Le descriptif de la source dans l'onglet sources du ggoglesheet du projet des indicateurs territoriaux était la suivant :
# Ces données de surfaces sont issues des contrôles annuels disponibles depuis 2011 que les organismes certificateurs agréés,
# réalisent dans les fermes et les entreprises de transformation, distribution engagées en bio. 
# Comme une commune sur deux est concernée par le secret statistique des données (disposer d’au moins 3 exploitations), 
# les données communales disponibles depuis 2019 ne sont pas prises en compte. 
# Au niveau des EPCI, seules 2 sont couvertes par le secret statistique.

# Nouveau descriptif : 
# Ces données de surfaces sont issues des contrôles annuels disponibles depuis 2011 que les organismes certificateurs agréés,
# réalisent dans les fermes et les entreprises de transformation, distribution engagées en bio.
# Depuis la mise à jour du 6 décembre 2021, les données communales brutes sont disponibles. 
# Deux sortes de table cohabitent donc sur le sgbd/datamart/portrait_territoires : 
# - celles issue de chargment des données communales brutes à partir du millésime 2019 ;
# - celle issue des données à l'EPCI', au département ou à la région du millésime 2011 à 2019 (specifique_agriculture_bio) pour laquelle le secret statistique était invoqué.

# Descriptif définitif depuis archivage sous le nom de zz_agriculture_bio.R
# Ces données de surfaces sont issues des contrôles annuels disponibles depuis 2011 que les organismes certificateurs agréés,
# réalisent dans les fermes et les entreprises de transformation, distribution engagées en bio.
# Depuis la mise à jour du 6 décembre 2021, les données communales brutes sont disponibles. 
# Deux sortes de table cohabitent donc sur le sgbd/datamart/portrait_territoires : 
#   - celles issue de chargment des données communales brutes à partir du millésime 2019 ;
# - celle issue des données à l'EPCI', au département ou à la région du millésime 2011 à 2019 (zz_agriculture_bio) pour laquelle le secret statistique était invoqué au niveau communal et qui sont archivées de ce fait.


# METADONNEES (partie uniquement valable pour specifique_agriculture_bio) ------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(indicateur_agriculture_bio), c("TypeZone", "CodeZone", "Zone", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>%
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>%
  select(variable, libelle_variable) %>%
  # ajout des libellés pour date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur,
               table = "specifique_agriculture_bio",
               schema = "portrait_territoires",
               db = "datamart",
               user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>%
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>%
  pull(com_table)  %>%
  # ajout de complement sur la généalogie
  paste0(".\n", "T\u00e9l\u00e9chargement depuis le site de l\'Agence Bio https://www.agencebio.org/vos-outils/les-chiffres-cles/#-Allerplusloin")

## commentaires de la table

commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "specifique_agriculture_bio",
                user = "does")
